<?php
/* VMware Virtualization CONFIG WIZARD */

/* Required include */
include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

/* Run the initialization function */
vmwarevirtualizationwizard_configwizard_init();

function vmwarevirtualizationwizard_configwizard_init() {
	
	/* Name / ID for config wizard */
	$name = 'vmwarevirtualizationwizard';
	
	/* Relevant info for wizard */
	$args = array(
		CONFIGWIZARD_NAME => $name,
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => 'Monitor resources of a VMware vCenter Server or ESX(i) Host.<br/>This wizard offloads the VMware checks to a vSphere Management Assistance (vMA) appliance.',
		CONFIGWIZARD_DISPLAYTITLE => 'VMware Virtualization Wizard',
		CONFIGWIZARD_FUNCTION => $name.'_configwizard_func',
		CONFIGWIZARD_PREVIEWIMAGE => 'vmware3.png',
		CONFIGWIZARD_VERSION => '2014-10-23',
		CONFIGWIZARD_DATE => '2014-10-23',
		CONFIGWIZARD_AUTHOR => 'Troy Lea, Nagios Enterprises, LLC',
		);
	/* Register wizard with XI */
	register_configwizard($name,$args);
	} /* End function vmwarevirtualizationwizard_configwizard_init(){ */


/* This function is automatically called by the XI wizard framework when the wizard is run */
function vmwarevirtualizationwizard_configwizard_func($mode = '',$inargs = null,&$outargs,&$result) {
	/* Define the wizard name */
	$wizard_name = 'vmwarevirtualizationwizard';

	/* Initialize return code and output */
	$result = 0;
	$output = '';
	
	/* Initialize output args - pass back the same data we got -> used by XI framework, don't change */
	$outargs[CONFIGWIZARD_PASSBACK_DATA] = $inargs;

	/* Main Wizard Stage switch */
	switch ($mode) {
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
			/* This defines $back variable, used for determining if the Back button */
			/* was clicked when the user was on CONFIGWIZARD_MODE_GETSTAGE2HTML */
			$back = htmlentities(grab_array_var($_POST,'backButton',false),ENT_QUOTES); 
			
			/* This defines $nextstep variable, used for determining if the user did not */
			/* provide correct information when the user was on CONFIGWIZARD_MODE_GETSTAGE1HTML */
			$nextstep = htmlentities(grab_array_var($_POST,'nextstep',false),ENT_QUOTES); 
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />post CONFIGWIZARD_MODE_GETSTAGE1HTML<br />'); 
			//print_r($_POST); 
			//print_r('<br /><br />'); 
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session CONFIGWIZARD_MODE_GETSTAGE1HTML<br />'); 
			//print_r($_SESSION); 
			//print_r('<br /><br />'); 
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session[vmwarevirtualizationwizard] CONFIGWIZARD_MODE_GETSTAGE1HTML<br />'); 
			//print_r($_SESSION[$wizard_name]); 
			//print_r('<br /><br />'); 
			
			/* Determine if this is the first wizard run */
			if ($nextstep == '') {
				/* Clear the session array to be sure it is blank */
				unset($_SESSION[$wizard_name]); 
				} /* End if ($nextstep == '') { */
			
			/* Check to see if we are coming back from CONFIGWIZARD_MODE_GETSTAGE2HTML */
			if ($back == 'Back') {
				/* User pressed Back button on CONFIGWIZARD_MODE_GETSTAGE2HTML */
				/* The following line can be enabled for debugging purposes */
				//print_r('<br />User pressed Back button on CONFIGWIZARD_MODE_GETSTAGE2HTML<br />'); 
				
				/* Back was clicked when user was on CONFIGWIZARD_MODE_GETSTAGE2HTML so we need to define some variables */
				
				/* Get the settings from the VMware Settings Manager component */		
				$vma_settings = unserialize(get_option('vmwarevmasettingsmanager_component_options'));

				/* These are the vMA Hosts */
				$vma_hosts_list = grab_array_var($vma_settings,'vma_hosts_list','');
				
				$vma_hosts_defined = 1;
				$vma_host_select = $_SESSION[$wizard_name]['vma_host_select'];
				$vma_host_object_select_setting = $_SESSION[$wizard_name]['vma_host_object_select'];
				$vma_host_settings_list_serial = $_SESSION[$wizard_name]['vma_host_settings_list_serial'];
				$vma_default_host_address = $_SESSION[$wizard_name]['vma_default_host_address'];

				/* Get the Default vmware object radio list */
				$vmware_object_radio_list = grab_array_var($vma_settings,'vmware_object_radio_list','');
				$vmware_object_radio_list_serial = urlencode(base64_encode(serialize($vmware_object_radio_list)));

				$vmware_check_type_setting = $_SESSION[$wizard_name]['vmware_check_type'];

				$nagios_object_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['nagios_object'])));
				$nagios_object_existing_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['nagios_object_existing'])));
				$nagios_object_new_name_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['nagios_object_new_name'])));
				$nagios_object_new_address_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['nagios_object_new_address'])));
						
				/* Check type determines the options */
				switch ($vmware_check_type_setting) {
					case 'datastores':
						$datastore_checkbox_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['datastore_checkbox'])));
						$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_datastores\')</script>';
						break; /* End case 'datastores': */

					case 'guests':
						$guest_checkbox_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['guest_checkbox'])));
						$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_guests\')</script>';
						break; /* End case 'guests': */

					case 'host':
						$host_checkbox_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['host_checkbox'])));
						$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_hosts\')</script>';
						break;

					case 'vcenter':
						$vcenter_checkbox_settings_serial = urlencode(base64_encode(serialize($_SESSION[$wizard_name]['vcenter_checkbox'])));
						$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_vcenter\')</script>';
						break;

					} /* End switch ($vmware_check_type_setting) { */
				} /* End if ($back == 'Back') { */
			else {
				/* Fresh Wizard Run */
				/* OR */
				/* Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE1DATA due to user error */
				
				if (!isset($_POST['vma_default_host_address'])) {
					/* Fresh Wizard Run */
					/* The following line can be enabled for debugging purposes */
					//print_r('<br/><br/>Fresh Wizard Run<br/><br/>');
					
					/* Define the session array to hold data from different stages */
					$_SESSION[$wizard_name] = array(); 
					
					/* Get the settings from the VMware Settings Manager component */
					$vma_settings_raw = get_option('vmwarevmasettingsmanager_component_options');
					if($vma_settings_raw == '') {
						/* There are currently no settings so define an array */
						$vma_hosts_defined = 0;
						$vma_settings = array();
						} /* End if($settings_raw == '') { */
					else {
						/* Settings are defined so unserialize them */
						$vma_settings = unserialize($vma_settings_raw);

						/* These are the vMA Hosts */
						$vma_hosts_list = grab_array_var($vma_settings,'vma_hosts_list','');

						/* These are the Settings FOR the vMA Hosts */
						$vma_host_settings_list = grab_array_var($vma_settings,'vma_host_settings_list','');
						$vma_host_settings_list_serial = urlencode(base64_encode(serialize($vma_host_settings_list)));

						/* Get the Default vmware object radio list */
						$vmware_object_radio_list = grab_array_var($vma_settings,'vmware_object_radio_list','');
						$vmware_object_radio_list_serial = urlencode(base64_encode(serialize($vmware_object_radio_list)));
						
						/* Check to see if any vMA hosts have been defined */
						if (count($vma_hosts_list) == 0) {
							//print_r('You have not yet added any vMA servers using the VMware vMA Settings Manager component<br/>');
							$vma_hosts_defined = 0;
							$vma_default_host_address = '';
							$vma_host_object_select_setting = '';
							$vmware_check_type_setting = '';
							} /* End if (count($vma_hosts_list) == 0) { */
						else {
							/* Get the default vMA Host */
							$vma_default_host_address = grab_array_var($vma_settings,'vma_default_host','');
							if ($vma_default_host_address == '') {
								/* Can't find a default, just use the first vMA host */
								$vma_default_host_address = $vma_hosts_list[0][0];
								} /* End if ($vma_default_host_address = '') { */
							
							/* See if any vMA settings have been defined */
							if (isset($vma_host_settings_list[$vma_default_host_address])) {
								$vma_hosts_defined = 1;

								/* Define these variables to prevent coding errors */
								$vma_host_object_select_setting = '';
								$vmware_check_type_setting = '';
								$datastore_checkbox_settings_serial = urlencode(base64_encode(serialize('')));
								$guest_checkbox_settings_serial = urlencode(base64_encode(serialize('')));
								$host_checkbox_settings_serial = urlencode(base64_encode(serialize('')));
								$vcenter_checkbox_settings_serial = urlencode(base64_encode(serialize('')));
								$nagios_object_settings_serial = urlencode(base64_encode(serialize('')));
								$nagios_object_existing_settings_serial = urlencode(base64_encode(serialize('')));
								$nagios_object_new_name_settings_serial = urlencode(base64_encode(serialize('')));
								$nagios_object_new_address_settings_serial = urlencode(base64_encode(serialize('')));
								} /* End if (isset($vma_host_settings_list[$vma_default_host_address])) { */
							else {
								//print_r('You have not yet added any vMA servers using the VMware vMA Settings Manager component<br/>');
								$vma_hosts_defined = 0;
								} /* End else { */
							} /* End else { */

						
						} /* End else { */
					} /* End if (!isset($_POST['vma_default_host_address'])) { */
				else {
					/* Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE1DATA due to user error */
					/* The following line can be enabled for debugging purposes */
					//print_r('<br />Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE1DATA due to user error<br />'); 
					
					
					/* Get the settings from the VMware Settings Manager component */		
					$vma_settings = unserialize(get_option('vmwarevmasettingsmanager_component_options'));

					/* These are the vMA Hosts */
					$vma_hosts_list = grab_array_var($vma_settings,'vma_hosts_list','');

					/* Check to see if any vMA hosts have been defined */
					if (count($vma_hosts_list) == 0) {
						//print_r('You have not yet added any vMA servers using the VMware vMA Settings Manager component<br/>');
						$vma_hosts_defined = 0;
						$vma_default_host_address = '';
						$vma_host_object_select_setting = '';
						$vmware_check_type_setting = '';
						} /* End if (count($vma_hosts_list) == 0) { */
					else {
						/* These are the Settings FOR the vMA Hosts */
						$vma_host_settings_list = grab_array_var($vma_settings,'vma_host_settings_list','');
						$vma_host_settings_list_serial = urlencode(base64_encode(serialize($vma_host_settings_list)));

						$vma_hosts_defined = 1;

						/* Grab user data already provided from CONFIGWIZARD_MODE_GETSTAGE1HTML */
						$vma_host_select = grab_array_var($inargs,'vma_host_select','');
						$vma_host_object_select_setting = grab_array_var($inargs,'vma_host_object_select','');
						$vmware_check_type_setting = grab_array_var($inargs,'vmware_check_type','');
						$vma_default_host_address = grab_array_var($inargs,'vma_host_select','');

						/* Get the Default vmware object radio list */
						$vmware_object_radio_list = grab_array_var($vma_settings,'vmware_object_radio_list','');
						$vmware_object_radio_list_serial = urlencode(base64_encode(serialize($vmware_object_radio_list)));

						$nagios_object_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'nagios_object',array()))));
						$nagios_object_existing_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'nagios_object_existing',array()))));
						$nagios_object_new_name_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'nagios_object_new_name',array()))));
						$nagios_object_new_address_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'nagios_object_new_address',array()))));
						
						/* Check type determines the options */
						switch ($vmware_check_type_setting) {
							case 'datastores':
								$datastore_checkbox_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'datastore_checkbox',array()))));
								$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_datastores\')</script>';
								break; /* End case 'datastores': */

							case 'guests':
								$guest_checkbox_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'guest_checkbox',array()))));
								$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_guests\')</script>';
								break; /* End case 'guests': */

							case 'host':
								$host_checkbox_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'host_checkbox',array()))));
								$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_hosts\')</script>';
								break;

							case 'vcenter':
								$vcenter_checkbox_settings_serial = urlencode(base64_encode(serialize(grab_array_var($inargs,'vcenter_checkbox',array()))));
								$auto_retrieve = '<script>'.$wizard_name.'_get_objects(\''.$wizard_name.'-retrieve-results:retrieve_vcenter\')</script>';
								break;
							} /* End switch ($vmware_check_type_setting) { */
						} /* End else { */
					} /* End else { */
				} /* End else { */
			
			
			/* Now we are creating the HTML for CONFIGWIZARD_MODE_GETSTAGE1HTML */ 
			$output = '
				<link href="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.css" rel="stylesheet" type="text/css" />
				<script type="text/javascript" src="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.js"></script>

				<input type="hidden" name="vma_default_host_address" value="'.$vma_default_host_address.'">
				<input type="hidden" name="vma_host_object_select_setting" id="id_vma_host_object_select_setting" value="'.$vma_host_object_select_setting.'">
				<input type="hidden" name="vmware_check_type_setting" id="id_vmware_check_type_setting" value="'.$vmware_check_type_setting.'">
				';

			switch ($vmware_check_type_setting) {
				case 'datastores':
				case 'guests':
				case 'host':
				case 'vcenter':
				$output .= '
					<input type="hidden" name="nagios_object_settings_serial" id="id_nagios_object_settings_serial" value="'.$nagios_object_settings_serial.'">
					<input type="hidden" name="nagios_object_existing_settings_serial" id="id_nagios_object_existing_settings_serial" value="'.$nagios_object_existing_settings_serial.'">
					<input type="hidden" name="nagios_object_new_name_settings_serial" id="id_nagios_object_new_name_settings_serial" value="'.$nagios_object_new_name_settings_serial.'">
					<input type="hidden" name="nagios_object_new_address_settings_serial" id="id_nagios_object_new_address_settings_serial" value="'.$nagios_object_new_address_settings_serial.'">
					';
				switch ($vmware_check_type_setting) {
					case 'datastores':
						$output .= '
							<input type="hidden" name="datastore_checkbox_settings_serial" id="id_datastore_checkbox_settings_serial" value="'.$datastore_checkbox_settings_serial.'">
							';
						break; /* End case 'datastores': */

					case 'guests':
						$output .= '
							<input type="hidden" name="guest_checkbox_settings_serial" id="id_guest_checkbox_settings_serial" value="'.$guest_checkbox_settings_serial.'">
							';
						break; /* End case 'guests': */

					case 'host':
						$output .= '
							<input type="hidden" name="host_checkbox_settings_serial" id="id_host_checkbox_settings_serial" value="'.$host_checkbox_settings_serial.'">
							';
						break; /* End case 'host': */

					case 'vcenter':
						$output .= '
							<input type="hidden" name="vcenter_checkbox_settings_serial" id="id_vcenter_checkbox_settings_serial" value="'.$vcenter_checkbox_settings_serial.'">
							';
						break; /* End case 'vcenter': */
					} /* End switch ($vmware_check_type_setting) { */
					break; /* End case 'datastores': case 'guests': case 'host': case 'vcenter': */
				} /* End switch ($vmware_check_type_setting) { */

			$output .= '
				
				<p>
				<div>
					<input type="button" class="'.$wizard_name.'-button01" onclick="'.$wizard_name.'_toggleMe(\'overview\')" value="Overview">
				</div>
				<div id="overview" class="'.$wizard_name.'-width500" style="display:none">
					<div class="'.$wizard_name.'-spacer10"> </div>
					Welcome to the VMware Virtualization Wizard.
					<div class="'.$wizard_name.'-spacer10"> </div>
					This wizard monitors your VMware virtual environment by offloading the VMware checks to a vSphere Management Assistance (vMA) appliance.
					<div class="'.$wizard_name.'-spacer10"> </div>
					This is achieved by utilizing the plugin <b>box293_check_vmware</b>, it has been written specifically for use on the vMA. The plugin and manual can be downloaded from the <a href="http://exchange.nagios.org/directory/Plugins/Operating-Systems/*-Virtual-Environments/VMWare/box293_check_vmware/details" target="_blank"><b>Nagios Exchange</b></a>.
					<div class="'.$wizard_name.'-spacer20"> </div>
					Before you can use this wizard, you will need to have:
					<div class="'.$wizard_name.'-spacer10"> </div>
					<ul>
						<li>
							Deployed the vMA appliance as per the instructions in the manual
							<ul><li>Located on the <a href="http://exchange.nagios.org/directory/Plugins/Operating-Systems/*-Virtual-Environments/VMWare/box293_check_vmware/details" target="_blank"><b>Nagios Exchange</b></a></li></ul>
						</li>
						<li>
							Installed and Configured the <b>VMware vMA Settings Manager</b> component for Nagios XI
							<ul><li>This can be downloaded from the <a href="http://exchange.nagios.org/directory/Addons/Components/VMware-vMA-Settings-Manager/details" target="_blank"><b>Nagios Exchange</b></a></li></ul>
						</li>
					</ul>
					It has been detected that these pre-requisites
				';
			if ($vma_hosts_defined == 0) {
				$output .= ' have <b>NOT</b> ';
				} /* End if ($vma_hosts_defined == 0) { */
			else {
				$output .= ' <b>have</b> ';
				} /* End else { */
			$output .= '
					been fulfilled.
					<div class="'.$wizard_name.'-spacer10"> </div>

					<div>
						<input type="button" class="'.$wizard_name.'-button02" onclick="'.$wizard_name.'_toggleMe(\'what-is-vma\')" value="What is vMA?">
					</div>

					<div id="what-is-vma" class="'.$wizard_name.'-width500" style="display:none">
						vMA is a virtual appliance provided by VMware (free of charge) to help manage your VMware based virtual infrastructure.
						<div class="'.$wizard_name.'-spacer10"> </div>
						It came into existance when VMware released ESXi. ESXi is the hypervisor platform that replaced their original ESX hypervisor.
						<div class="'.$wizard_name.'-spacer10"> </div>
						ESXi is a locked down operating system, which is why VMware created vMA to help manage ESXi (it also manages ESX).
						<div class="'.$wizard_name.'-spacer10"> </div>
						An example diagram of how Nagios uses vMA is shown below:
						<div class="'.$wizard_name.'-spacer10"> </div>
						<img src="../includes/configwizards/'.$wizard_name.'/logos/vma_diagram.png">
						<div class="'.$wizard_name.'-spacer10"> </div>
					</div>

					<div>
						<input type="button" class="'.$wizard_name.'-button02" onclick="'.$wizard_name.'_toggleMe(\'why-use-vma\')" value="Why use vMA?">
					</div>

					<div id="why-use-vma" class="'.$wizard_name.'-width500" style="display:none">
						Why isn\'t the box293_check_vmware plugin run directly on my Nagios Host?
						<div class="'.$wizard_name.'-spacer10"> </div>
						<ul>
							<li>
								VMware SDK will easily overload your Nagios host
								<ul>
									<li>This Plugin uses the VMware Software Development Kit (SDK) for Perl API</li>
									<li>This is a very powerful API however it is also very resource intensive, consuming all the CPU resources it can get it\'s hands on (it likes memory too)</li>
									<li>If the VMware SDK is installed on your Nagios host, then the checks executed by this plugin can easily cause your Nagios host to become slow and unresponsive, in turn crippling your Nagios monitoring solution</li>
									<li>Hence by offloading the checks to a vMA appliance your Nagios monitoring solution is not affected</li>
								</ul>
							</li>
							<li>
								vMA is a ready to go platform
								<ul>
									<li>Simply download the latest version of the vMA appliance and deploy it into your VMware Infrastructure</li>
									<li>This includes everything required for the plugin to work straight away</li>
									<li>No wasting time with confusing installation procedures and pre-requisites</li>
									<li>Allows you to get your VMware monitoring solution up and working straight away</li>
								</ul>
							</li>
						</ul>
						<div class="'.$wizard_name.'-spacer10"> </div>
					</div>

					<div>
						<input type="button" class="'.$wizard_name.'-button02" onclick="'.$wizard_name.'_toggleMe(\'troubleshooting\')" value="Troubleshooting">
					</div>

					<div id="troubleshooting" class="'.$wizard_name.'-width500" style="display:none">
						<ul>
							<li>
								The service detail output appears cut off for some services like Guest Disk Performance
								<ul>
									<li>The box293_check_vmware plugin produces a lot of output for some of it\'s services, which get cut off by Nagios XI</li>
									<li>To fix the problem please do the following:</li>
									<li>Establish an SSH session to this Nagios XI host as user <b>root</b><br/></li>
									<li>The next four lines of code are each one continual line, just copy and paste into the SSH session and press <b>Enter</b></li>
									<li><b><pre>echo "use nagios;alter table nagios_servicestatus modify output varchar(65535) not null;alter table nagios_servicestatus modify long_output varchar(65535) not null;alter table nagios_servicestatus modify perfdata varchar(65535) not null;" | mysql -pnagiosxi</pre></b></li>
									<li><b><pre>echo "use nagios;alter table nagios_hoststatus modify output varchar(65535) not null;alter table nagios_servicestatus modify long_output varchar(65535) not null;alter table nagios_servicestatus modify perfdata varchar(65535) not null;" | mysql -pnagiosxi</pre></b></li>
									<li><b><pre>echo "use nagios;alter table nagios_servicechecks modify output varchar(65535) not null;alter table nagios_servicestatus modify long_output varchar(65535) not null;alter table nagios_servicestatus modify perfdata varchar(65535) not null;" | mysql -pnagiosxi</pre></b></li>
									<li><b><pre>echo "use nagios;alter table nagios_hostchecks modify output varchar(65535) not null;alter table nagios_servicestatus modify long_output varchar(65535) not null;alter table nagios_servicestatus modify perfdata varchar(65535) not null;" | mysql -pnagiosxi</pre></b></li>
									<li>The changes are immediate and the next time one of these service checks executes it will display the full output</li>
								</ul>
							</li>
						</ul>
						<div class="'.$wizard_name.'-spacer10"> </div>
					</div>
					
				</div> 
				
				<div class="sectionTitle">vMA and VMware Detected Settings</div>
				';

			/* Detecting if vMA Component is installed and configured */
			if ($vma_hosts_defined == 0) {
				$output .= '
					vMA Component Not Installed OR you have not yet added any vMA Servers OR any vMA Settings
					<div class="'.$wizard_name.'-spacer10"> </div>
					Please install and configure the <b>VMware vMA Settings Manager</b> component for Nagios XI
					<div class="'.$wizard_name.'-spacer10"> </div>
					This can be downloaded from the <a href="http://exchange.nagios.org/directory/Addons/Components/VMware-vMA-Settings-Manager/details" target="_blank"><b>Nagios Exchange</b></a>.
					<div class="'.$wizard_name.'-spacer10"> </div>
					Please Upload and Configure the VMware vMA Settings Manager component via Admin -> System Extenstions -> Manage Components
					<div class="'.$wizard_name.'-spacer10"> </div>
					';
				} /* End if ($vma_hosts_defined == 0) { */
			else {
				$output .= '
					<table>
						<tr>
							<td class="'.$wizard_name.'-align-right '.$wizard_name.'-width170">vMA Host:</td>
							<td class="'.$wizard_name.'-width10"></td>
							<td class="'.$wizard_name.'-align-left">
								<select name="vma_host_select" id="id_vma_host_select" title="vMA Host" onChange="'.$wizard_name.'_vma_host_select(\''.$vma_host_settings_list_serial.'\')">
					';
				foreach ($vma_hosts_list as $vma_host) {
					$output .= '<option value="'.$vma_host[0].'"'; if ($vma_host[0] == $vma_default_host_address) $output .= ' selected'; $output .= '>'.$vma_host[1].'</option>';
					} /* End foreach ($vma_hosts_list as $vma_host) { */
				$output .= '
								</select>
							</td>
						</tr>

						<tr>
							<td class="'.$wizard_name.'-align-right '.$wizard_name.'-width170">vCenter Server OR ESX(i) Host:</td>
							<td class="'.$wizard_name.'-width10"></td>
							<td class="'.$wizard_name.'-align-left">
								<div id="'.$wizard_name.'-display-host" style="display:none">
									<!-- This will be populated when a host is selected from the list -->
								</div>
							</td>
						</tr>
					</table>

					<div id="'.$wizard_name.'-display-check-type" style="display:none">
						<!-- This will be populated when a vMA host is selected from the list -->
					</div>

					<input type="hidden" name="vmware_object_radio_list_serial" id="vmware_object_radio_list_serial" value="'.$vmware_object_radio_list_serial.'">
					
					<input type="hidden" name="vma_host_settings_list_serial" id="vma_host_settings_list_serial" value="'.$vma_host_settings_list_serial.'">

					<script>'.$wizard_name.'_vma_host_select(\''.$vma_host_settings_list_serial.'\')</script>
								
					<div id="'.$wizard_name.'-retrieve-results" style="display:none" class="'.$wizard_name.'-width700">
						<!-- This will be populated when a check type is selected from the list -->
					</div>

					';
				} /* End else { */

			$output .= '
			
				<input type="hidden" name="vma_hosts_defined" id="vma_hosts_defined" value="'.$vma_hosts_defined.'">

				<div class="'.$wizard_name.'-spacer20"> </div>

				<p>
				Click <b>Next</b> to continue.
				</p>
				';

			/* If we've come back due to a user error, start the retrieve process */
			if (isset($auto_retrieve)) {
				$output .= $auto_retrieve;
				} /* End if (isset($auto_retrieve)) { */

			/* The next line ends CONFIGWIZARD_MODE_GETSTAGE1HTML */
			break;

			
		/* Form validation for CONFIGWIZARD_MODE_GETSTAGE1HTML */
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:		
			/* This defines $back variable, used for determining if the Back button */
			/* was clicked when the user was on CONFIGWIZARD_MODE_GETSTAGE2HTML */
			$back = htmlentities(grab_array_var($_POST,'backButton',false),ENT_QUOTES); 	
			
			/* If the user came back from CONFIGWIZARD_MODE_GETSTAGE3HTML then we don't need to revalidate and check for errors */
			if ($back) break;	
			
			/* Get variables that were passed to us */
				/* NOTE: grab_array_var is an XI wrapper function to fetch values 'if they exist' */
				/* USAGE: grab_array_var($array, $variable, $defaultValue) */
			$vma_hosts_defined = grab_array_var($inargs,'vma_hosts_defined','');
			$vma_host_select = grab_array_var($inargs,'vma_host_select','');
			$vma_host_object_select = grab_array_var($inargs,'vma_host_object_select','');
			$vmware_check_type = grab_array_var($inargs,'vmware_check_type','');

			/* Now lets check for errors before proceeding to CONFIGWIZARD_MODE_GETSTAGE2HTML*/
			/* Set the error count to 0 */
			$errors = 0;
			/* Create the error messages array */
			$errmsg = array();

			/* Make sure the vMA has been configured */
			if ($vma_hosts_defined == 0) {
				/* Not configured, add an error message to the array and increment the $errors count */
				$errmsg[$errors++] = 'vMA Component Not Installed OR you have not yet added any vMA Hosts OR any VMware Servers';
				} /* End if ($vma_hosts_defined == 0) { */
			else {
				/* Get variables that were passed to us */
				$nagios_object = grab_array_var($inargs,'nagios_object',array());
				$nagios_object_existing = grab_array_var($inargs,'nagios_object_existing',array());
				$nagios_object_new_name = grab_array_var($inargs,'nagios_object_new_name',array());
				$nagios_object_new_address = grab_array_var($inargs,'nagios_object_new_address',array());
				
				/* Check type determines the options */
				switch ($vmware_check_type) {
					case 'datastores':
						/* Get variables that were passed to us */
						$datastore_checkbox = grab_array_var($inargs,'datastore_checkbox',array());
						$datastore_counter = grab_array_var($inargs,'datastore_counter','');

						/* Find what datastores were selected */
						$datastore_checkbox_flag = 0;
						for ($d = 1; $d <= $datastore_counter; $d++) {
							/* Check to see if this array object exists */
							if (isset($datastore_checkbox[$d])) {
								$datastore_checkbox_flag = 1;
								} /* End if (isset($datastore_checkbox[$d])) { */
							} /* End for ($d = 0; $d <= $datastore_counter; $d++) { */

						/* Check to make sure at least one datastore was selected */
						if ($datastore_checkbox_flag == 0) {
							$errmsg[$errors++] = 'You did not select any datastores to monitor!';
							} /* End if ($datastore_checkbox_flag == 1) { */
							
						/* Check to make sure a Nagios object was defined for the vCenter Server */
						/* Check to see if a new object will be created or use an existing object */
						switch ($nagios_object[0]) {
							case 'new':
								if ($nagios_object_new_name[0] == '') {
									$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Name\' for the NEW vCenter Server / ESX(i) Host \''.$datastore_checkbox[0].'\'!';
									} /* End if ($nagios_object_new_name[0] == '') {  */
								else {
									if(is_valid_host_name($nagios_object_new_name[0]) == false) {
										$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Name\' for the NEW vCenter Server / ESX(i) Host \''.$datastore_checkbox[0].'\'!';
										} /* End if(is_valid_host_name($nagios_object_new_name[0])==false) */
									else {
										if ($nagios_object_new_address[0] == '') {
											$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Address\' for the NEW vCenter Server / ESX(i) Host \''.$datastore_checkbox[0].'\'!';
											} /* End if ($nagios_object_new_address[0] == '') {  */
										else {
											if (!valid_ip($nagios_object_new_address[0])) {
												$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Address\' for the NEW vCenter Server / ESX(i) Host \''.$datastore_checkbox[0].'\'!';
												} /* End if (!valid_ip($nagios_object_new_address[0])) { */
											} /* End else { */
										} /* End else { */
									} /* End else { */
								break; /* End case 'new': */

							case 'existing':
								if ($nagios_object_existing[0] == '') {
									$errmsg[$errors++] = 'You did not select an EXISTING Nagios Object Host for the NEW vCenter Server / ESX(i) Host!';
									} /* End if ($nagios_object_new_name[0] == '') {  */
								break; /* End case 'existing': */
							} /* End switch ($nagios_object[0]) { */
						break; /* End case 'datastores': */

						
					case 'guests':
						/* Get variables that were passed to us */
						$guest_checkbox = grab_array_var($inargs,'guest_checkbox',array());
						$guest_counter = grab_array_var($inargs,'guest_counter','');
						
						/* Find what guests were selected */
						$guest_checkbox_flag = 0;
						for ($g = 0; $g <= $guest_counter; $g++) {
							/* Check to see if this array object exists */
							if (isset($guest_checkbox[$g])) {
								$guest_checkbox_flag = 1;
								/* Check to see if a new object will be created or use an existing object */
								switch ($nagios_object[$g]) {
									case 'new':
										if ($nagios_object_new_name[$g] == '') {
											$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Name\' for the NEW guest \''.$guest_checkbox[$g].'\'!';
											} /* End if ($nagios_object_new_name[$g] == '') {  */
										else {
											if(is_valid_host_name($nagios_object_new_name[$g]) == false) {
												$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Name\' for the NEW guest \''.$guest_checkbox[$g].'\'!';
												} /* End if(is_valid_host_name($nagios_object_new_name[$g])==false) */
											else {
												if ($nagios_object_new_address[$g] == '') {
													$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Address\' for the NEW guest \''.$guest_checkbox[$g].'\'!';
													} /* End if ($nagios_object_new_address[$g] == '') {  */
												else {
													if (!valid_ip($nagios_object_new_address[$g])) {
														$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Address\' for the NEW guest \''.$guest_checkbox[$g].'\'!';
														} /* End if (!valid_ip($nagios_object_new_address[$g])) { */
													} /* End else { */
												} /* End else { */
											} /* End else { */
										break; /* End case 'new': */

									case 'existing':
										if ($nagios_object_existing[$g] == '') {
											$errmsg[$errors++] = 'You did not select an EXISTING Nagios Object Host for the guest \''.$guest_checkbox[$g].'\'!';
											} /* End if ($nagios_object_new_name[$g] == '') {  */
										break; /* End case 'existing': */
									} /* End switch ($nagios_object[$g]) { */
								} /* End if (isset($guest_checkbox[$g])) { */
							} /* End for ($g = 0; $g <= $guest_counter; $g++) { */
						
						/* Check to make sure at least one guest was selected */
						if ($guest_checkbox_flag == 0) {
							$errmsg[$errors++] = 'You did not select any guests to monitor!';
							} /* End if ($guest_checkbox_flag == 1) { */
						break; /* End case 'guests': */


					case 'host':
						/* Get variables that were passed to us */
						$host_checkbox = grab_array_var($inargs,'host_checkbox',array());
						$host_counter = grab_array_var($inargs,'host_counter','');

						/* Find what hosts were selected */
						$host_checkbox_flag = 0;
						for ($h = 0; $h <= $host_counter; $h++) {
							/* Check to see if this array object exists */
							if (isset($host_checkbox[$h])) {
								$host_checkbox_flag = 1;
								/* Check to see if a new object will be created or use an existing object */
								switch ($nagios_object[$h]) {
									case 'new':
										if ($nagios_object_new_name[$h] == '') {
											$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Name\' for the NEW host \''.$host_checkbox[$h].'\'!';
											} /* End if ($nagios_object_new_name[$h] == '') {  */
										else {
											if(is_valid_host_name($nagios_object_new_name[$h]) == false) {
												$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Name\' for the NEW host \''.$host_checkbox[$h].'\'!';
												} /* End if(is_valid_host_name($nagios_object_new_name[$h])==false) */
											else {
												if ($nagios_object_new_address[$h] == '') {
													$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Address\' for the NEW host \''.$host_checkbox[$h].'\'!';
													} /* End if ($nagios_object_new_address[$h] == '') {  */
												else {
													if (!valid_ip($nagios_object_new_address[$h])) {
														$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Address\' for the NEW host \''.$host_checkbox[$h].'\'!';
														} /* End if (!valid_ip($nagios_object_new_address[$h])) { */
													} /* End else { */
												} /* End else { */
											} /* End else { */
										break; /* End case 'new': */

									case 'existing':
										if ($nagios_object_existing[$h] == '') {
											$errmsg[$errors++] = 'You did not select an EXISTING Nagios Object Host for the host \''.$host_checkbox[$h].'\'!';
											} /* End if ($nagios_object_new_name[$h] == '') {  */
										break; /* End case 'existing': */
									} /* End switch ($nagios_object[$h]) { */
								} /* End if (isset($host_checkbox[$h])) { */
							} /* End for ($h = 0; $h <= $host_counter; $h++) { */

						/* Check to make sure at least one host was selected */
						if ($host_checkbox_flag == 0) {
							$errmsg[$errors++] = 'You did not select any hosts to monitor!';
							} /* End if ($host_checkbox_flag == 1) { */
						break; /* End case 'host': */


					case 'vcenter':
						/* Get variables that were passed to us */
						$vcenter_checkbox = grab_array_var($inargs,'vcenter_checkbox',array());
						$vcenter_counter = grab_array_var($inargs,'vcenter_counter','');

						/* Check to make sure a Nagios object was defined for the vCenter Server */
						/* Check to see if a new object will be created or use an existing object */
						switch ($nagios_object[0]) {
							case 'new':
								if ($nagios_object_new_name[0] == '') {
									$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Name\' for the NEW vCenter Object \''.$vcenter_checkbox[0].'\'!';
									} /* End if ($nagios_object_new_name[0] == '') {  */
								else {
									if(is_valid_host_name($nagios_object_new_name[0]) == false) {
										$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Name\' for the NEW vCenter Object \''.$vcenter_checkbox[0].'\'!';
										} /* End if(is_valid_host_name($nagios_object_new_name[0])==false) */
									else {
										if ($nagios_object_new_address[0] == '') {
											$errmsg[$errors++] = 'You CANNOT provide a BLANK Nagios Object Host \'Address\' for the NEW vCenter Object \''.$vcenter_checkbox[0].'\'!';
											} /* End if ($nagios_object_new_address[0] == '') {  */
										else {
											if (!valid_ip($nagios_object_new_address[0])) {
												$errmsg[$errors++] = 'You did not provide a VALID Nagios Object Host \'Address\' for the NEW vCenter Object \''.$vcenter_checkbox[0].'\'!';
												} /* End if (!valid_ip($nagios_object_new_address[0])) { */
											} /* End else { */
										} /* End else { */
									} /* End else { */
								break; /* End case 'new': */

							case 'existing':
								if ($nagios_object_existing[0] == '') {
									$errmsg[$errors++] = 'You did not select an EXISTING Nagios Object Host for the vCenter Object \''.$vcenter_checkbox[0].'\'!';
									} /* End if ($nagios_object_new_name[0] == '') {  */
								break; /* End case 'existing': */
							} /* End switch ($nagios_object[0]) { */
						break; /* End case 'vcenter': */
					} /* End switch ($vmware_check_type) { */
				} /* End else { */

			/* Check to see if the $errors array contains errors */
			if ($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
				$result = 1;
				} /* End if ($errors>0){ */
			
			/* The next line ends CONFIGWIZARD_MODE_VALIDATESTAGE1DATA */
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
			/* This defines $back variable, used for determining if the Back button */
			/* was clicked when the user was on CONFIGWIZARD_MODE_GETSTAGE3HTML */
			$back = htmlentities(grab_array_var($_POST,'backButton',false),ENT_QUOTES); 		
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />post CONFIGWIZARD_MODE_GETSTAGE2HTML<br />'); 
			//print_r($_POST); 
			//print_r('<br /><br />'); 

			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session CONFIGWIZARD_MODE_GETSTAGE2HTML<br />'); 
			//print_r($_SESSION); 
			//print_r('<br /><br />'); 
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session[vmwarevirtualizationwizard] CONFIGWIZARD_MODE_GETSTAGE2HTML<br />'); 
			//print_r($_SESSION[$wizard_name]); 
			//print_r('<br /><br />'); 
			
			/* Check to see if we are coming back from CONFIGWIZARD_MODE_GETSTAGE3HTML */
			if ($back == 'Back') {
				/* User pressed Back button on CONFIGWIZARD_MODE_GETSTAGE3HTML */
				/* The following line can be enabled for debugging purposes */
				//print_r('<br />User pressed Back button on CONFIGWIZARD_MODE_GETSTAGE3HTML<br />'); 
				
				/* Back was clicked when user was on CONFIGWIZARD_MODE_GETSTAGE3HTML so we need to define some variables */
				$vma_host_select = $_SESSION[$wizard_name]['vma_host_select'];
				$vma_host_object_select = $_SESSION[$wizard_name]['vma_host_object_select'];
				$vma_host_object_type = $_SESSION[$wizard_name]['vma_host_object_type'];
				$vmware_check_type = $_SESSION[$wizard_name]['vmware_check_type'];
				$nagios_object = $_SESSION[$wizard_name]['nagios_object'];
				$nagios_object_existing = $_SESSION[$wizard_name]['nagios_object_existing'];
				$nagios_object_new_name = $_SESSION[$wizard_name]['nagios_object_new_name'];
				$nagios_object_new_address = $_SESSION[$wizard_name]['nagios_object_new_address'];
				
				/* Specific to the vmware_check_type */
				switch ($vmware_check_type) {
					case 'datastores':
						$datastore_results_decoded = $_SESSION[$wizard_name]['datastore_results_decoded'];
						$datastore_checkbox = $_SESSION[$wizard_name]['datastore_checkbox'];
						$datastore_counter = $_SESSION[$wizard_name]['datastore_counter'];
						$datastore_check_options = $_SESSION[$wizard_name]['datastore_check_options'];
						break; /* End case 'datastores': */
					
					case 'guests':
						$guest_results_decoded = $_SESSION[$wizard_name]['guest_results_decoded'];
						$guest_checkbox = $_SESSION[$wizard_name]['guest_checkbox'];
						$guest_counter = $_SESSION[$wizard_name]['guest_counter'];
						$guest_check_options = $_SESSION[$wizard_name]['guest_check_options'];
						break; /* End case 'guests': */
					
					case 'host':
						$host_results_decoded = $_SESSION[$wizard_name]['host_results_decoded'];
						$host_checkbox = $_SESSION[$wizard_name]['host_checkbox'];
						$host_counter = $_SESSION[$wizard_name]['host_counter'];
						$host_check_options = $_SESSION[$wizard_name]['host_check_options'];
						break; /* End case 'host': */

					case 'vcenter':
						$vcenter_results_decoded = $_SESSION[$wizard_name]['vcenter_results_decoded'];
						$vcenter_checkbox = $_SESSION[$wizard_name]['vcenter_checkbox'];
						$vcenter_counter = $_SESSION[$wizard_name]['vcenter_counter'];
						$vcenter_check_options = $_SESSION[$wizard_name]['vcenter_check_options'];
						break; /* End case 'vcenter': */
					} /* End switch ($vmware_check_type) { */
				} /* End if ($back == 'Back') { */
			else {
				/* Continuing from CONFIGWIZARD_MODE_GETSTAGE1HTML */
				/* OR */
				/* Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE2DATA due to user error */
				
				if (isset($_POST['vmware_check_type'])) {
					/* Continuing from CONFIGWIZARD_MODE_GETSTAGE1HTML */
					/* The following line can be enabled for debugging purposes */
					//print_r('<br />Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE1DATA<br />'); 
					
					/* Grab array variables from CONFIGWIZARD_MODE_GETSTAGE1HTML */
					$vma_default_host_address = grab_array_var($inargs,'vma_default_host_address','');
					$vma_host_select = grab_array_var($inargs,'vma_host_select','');
					$vma_host_object_select = grab_array_var($inargs,'vma_host_object_select','');
					$vma_host_settings_list_serial = grab_array_var($inargs,'vma_host_settings_list_serial','');
					$vma_host_settings_list = unserialize(base64_decode($vma_host_settings_list_serial));
					$nagios_object = grab_array_var($inargs,'nagios_object',array());
					$nagios_object_existing = grab_array_var($inargs,'nagios_object_existing',array());
					$nagios_object_new_name = grab_array_var($inargs,'nagios_object_new_name',array());
					$nagios_object_new_address = grab_array_var($inargs,'nagios_object_new_address',array());
					
					/* We will save these to the session variable array for later use */
					$_SESSION[$wizard_name]['vma_default_host_address'] = $vma_default_host_address; 
					$_SESSION[$wizard_name]['vma_host_select'] = $vma_host_select; 
					$_SESSION[$wizard_name]['vma_host_object_select'] = $vma_host_object_select; 
					$_SESSION[$wizard_name]['vma_host_settings_list_serial'] = $vma_host_settings_list_serial; 
					$_SESSION[$wizard_name]['nagios_object'] = $nagios_object;
					$_SESSION[$wizard_name]['nagios_object_existing'] = $nagios_object_existing;
					$_SESSION[$wizard_name]['nagios_object_new_name'] = $nagios_object_new_name;
					$_SESSION[$wizard_name]['nagios_object_new_address'] = $nagios_object_new_address;
					
					/* Determine the vMA object type */
					foreach ($vma_host_settings_list[$vma_host_select] as $vmware_object) {
						if ($vmware_object[0] == $vma_host_object_select) {
							$vma_host_object_type = $vmware_object[1];
							$_SESSION[$wizard_name]['vma_host_object_type'] = $vma_host_object_type; 
							} /* End if ($vmware_object[0] == $vma_host_object_select) { */
						} /* End foreach ($vma_host_settings_list[$vma_host_select] as $vmware_object) { */

					$vmware_check_type = grab_array_var($inargs,'vmware_check_type','');
					$_SESSION[$wizard_name]['vmware_check_type'] = $vmware_check_type; 

					/* Specific to the vmware_check_type */
					switch ($vmware_check_type) {
						case 'datastores':
							/* grab array variables from CONFIGWIZARD_MODE_GETSTAGE1HTML */
							$datastore_results_encoded = grab_array_var($inargs,'datastore_results_encoded','');
							$datastore_results_decoded = json_decode(base64_decode($datastore_results_encoded),true);
							$datastore_checkbox = grab_array_var($inargs,'datastore_checkbox',array());
							$datastore_counter = grab_array_var($inargs,'datastore_counter','');
					
							/* We will save these to the session variable array for later use */
							$_SESSION[$wizard_name]['datastore_results_decoded'] = $datastore_results_decoded;
							$_SESSION[$wizard_name]['datastore_checkbox'] = $datastore_checkbox;
							$_SESSION[$wizard_name]['datastore_counter'] = $datastore_counter;

							/* There is a chance we have already been to stage 2 before and proceeded to stage 3 */
							if (isset($_SESSION[$wizard_name]['datastore_check_options'])) {
								$datastore_check_options = $_SESSION[$wizard_name]['datastore_check_options'];
								} /* End if (isset($_SESSION[$wizard_name]['datastore_check_options'])) { */
							else {
								/* Define these variables to prevent coding errors */
								$datastore_check_options = '';
								} /* End else { */
							break; /* End case 'datastores': */


						case 'guests':
							/* grab array variables from CONFIGWIZARD_MODE_GETSTAGE1HTML */
							$guest_results_encoded = grab_array_var($inargs,'guest_results_encoded','');
							$guest_results_decoded = json_decode(base64_decode($guest_results_encoded),true);
							$guest_checkbox = grab_array_var($inargs,'guest_checkbox',array());
							$guest_counter = grab_array_var($inargs,'guest_counter','');
					
							/* We will save these to the session variable array for later use */
							$_SESSION[$wizard_name]['guest_results_decoded'] = $guest_results_decoded;
							$_SESSION[$wizard_name]['guest_checkbox'] = $guest_checkbox;
							$_SESSION[$wizard_name]['guest_counter'] = $guest_counter;

							/* There is a chance we have already been to stage 2 before and proceeded to stage 3 */
							if (isset($_SESSION[$wizard_name]['guest_check_options'])) {
								$guest_check_options = $_SESSION[$wizard_name]['guest_check_options'];
								} /* End if (isset($_SESSION[$wizard_name]['guest_check_options'])) { */
							else {
								/* Define these variables to prevent coding errors */
								$guest_check_options = '';
								} /* End else { */
							break; /* End case 'guests': */


						case 'host': 
							/* grab array variables from CONFIGWIZARD_MODE_GETSTAGE1HTML */
							$host_results_encoded = grab_array_var($inargs,'host_results_encoded','');
							$host_results_decoded = json_decode(base64_decode($host_results_encoded),true);
							$host_checkbox = grab_array_var($inargs,'host_checkbox',array());
							$host_counter = grab_array_var($inargs,'host_counter','');
					
							/* We will save these to the session variable array for later use */
							$_SESSION[$wizard_name]['host_results_decoded'] = $host_results_decoded;
							$_SESSION[$wizard_name]['host_checkbox'] = $host_checkbox;
							$_SESSION[$wizard_name]['host_counter'] = $host_counter;

							/* There is a chance we have already been to stage 2 before and proceeded to stage 3 */
							if (isset($_SESSION[$wizard_name]['host_check_options'])) {
								$host_check_options = $_SESSION[$wizard_name]['host_check_options'];
								} /* End if (isset($_SESSION[$wizard_name]['host_check_options'])) { */
							else {
								/* Define these variables to prevent coding errors */
								$host_check_options = '';
								} /* End else { */
							break; /* End case 'host': */


						case 'vcenter': 
							/* grab array variables from CONFIGWIZARD_MODE_GETSTAGE1HTML */
							$vcenter_results_encoded = grab_array_var($inargs,'vcenter_results_encoded','');
							$vcenter_results_decoded = json_decode(base64_decode($vcenter_results_encoded),true);
							$vcenter_checkbox = grab_array_var($inargs,'vcenter_checkbox',array());
							$vcenter_counter = grab_array_var($inargs,'vcenter_counter','');
					
							/* We will save these to the session variable array for later use */
							$_SESSION[$wizard_name]['vcenter_results_decoded'] = $vcenter_results_decoded;
							$_SESSION[$wizard_name]['vcenter_checkbox'] = $vcenter_checkbox;
							$_SESSION[$wizard_name]['vcenter_counter'] = $vcenter_counter;

							/* There is a chance we have already been to stage 2 before and proceeded to stage 3 */
							if (isset($_SESSION[$wizard_name]['vcenter_check_options'])) {
								$vcenter_check_options = $_SESSION[$wizard_name]['vcenter_check_options'];
								} /* End if (isset($_SESSION[$wizard_name]['vcenter_check_options'])) { */
							else {
								/* Define these variables to prevent coding errors */
								$vcenter_check_options = '';
								} /* End else { */
							break; /* End case 'vcenter': */
						} /* End switch ($vmware_check_type) { */

					} /* End if (isset($_POST['vmware_check_type'])) { */
				else {
					/* Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE2DATA due to user error */
					/* The following line can be enabled for debugging purposes */
					//print_r('<br />Continuing from CONFIGWIZARD_MODE_VALIDATESTAGE2DATA due to user error<br />'); 
					
					/* Grab user data already provided from CONFIGWIZARD_MODE_GETSTAGE1HTML */
					$vma_host_select = $_SESSION[$wizard_name]['vma_host_select'];
					$vma_host_object_select = $_SESSION[$wizard_name]['vma_host_object_select'];
					$vma_host_object_type = $_SESSION[$wizard_name]['vma_host_object_type'];
					$vmware_check_type = $_SESSION[$wizard_name]['vmware_check_type'];
					$nagios_object = $_SESSION[$wizard_name]['nagios_object'];
					$nagios_object_existing = $_SESSION[$wizard_name]['nagios_object_existing'];
					$nagios_object_new_name = $_SESSION[$wizard_name]['nagios_object_new_name'];
					$nagios_object_new_address = $_SESSION[$wizard_name]['nagios_object_new_address'];
					
					/* Specific to the vmware_check_type */
					switch ($vmware_check_type) {
						case 'datastores':
							$datastore_results_decoded = $_SESSION[$wizard_name]['datastore_results_decoded'];
							$datastore_checkbox = $_SESSION[$wizard_name]['datastore_checkbox'];
							$datastore_counter = $_SESSION[$wizard_name]['datastore_counter'];
							$datastore_check_options = grab_array_var($inargs,'datastore_check_options',array());
							break; /* End case 'datastores': */
						
						case 'guests':
							$guest_results_decoded = $_SESSION[$wizard_name]['guest_results_decoded'];
							$guest_checkbox = $_SESSION[$wizard_name]['guest_checkbox'];
							$guest_counter = $_SESSION[$wizard_name]['guest_counter'];
							$guest_check_options = grab_array_var($inargs,'guest_check_options',array());
							break; /* End case 'guests': */
						
						case 'host':
							$host_results_decoded = $_SESSION[$wizard_name]['host_results_decoded'];
							$host_checkbox = $_SESSION[$wizard_name]['host_checkbox'];
							$host_counter = $_SESSION[$wizard_name]['host_counter'];
							$host_check_options = grab_array_var($inargs,'host_check_options',array());
							break; /* End case 'host': */

						case 'vcenter':
							$vcenter_results_decoded = $_SESSION[$wizard_name]['vcenter_results_decoded'];
							$vcenter_checkbox = $_SESSION[$wizard_name]['vcenter_checkbox'];
							$vcenter_counter = $_SESSION[$wizard_name]['vcenter_counter'];
							$vcenter_check_options = grab_array_var($inargs,'vcenter_check_options',array());
							break; /* End case 'vcenter': */
						} /* End switch ($vmware_check_type) { */
					} /* End else { */
				} /* End else { */
				
			/* Now we are creating the HTML for CONFIGWIZARD_MODE_GETSTAGE2HTML */ 
			$output = '
				<link href="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.css" rel="stylesheet" type="text/css" />
				<script type="text/javascript" src="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.js"></script>
				';
			
			$row_class = ' class="'.$wizard_name.'-table-row-clear"';
			$objects_used = array();
			switch ($vmware_check_type) {
				case 'datastores':
					/* Define some variables */
					$output_VMware_Host = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_Datastore_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Datastore_Usage = '<select name="propagate_options_Datastore_Usage" id="id_propagate_options_Datastore_Usage" title="Select Datastore to Propagate Common Options">';
			
					$vmware_host_new = 0;
					if ($nagios_object[0] == 'new') {
						$vmware_host_new = 1;
						
						$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'check_interval'), 0, $datastore_check_options, '5');
						$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'retry_interval'), 0, $datastore_check_options, '2');
						$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'number_retries'), 0, $datastore_check_options, '5');
						
						$output_VMware_Host .= '
							<tr class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top">
								<td class="'.$wizard_name.'-align-right">
									Nagios Object Name:<br/>
									Nagios Object Address:
								</td>
								<td class="'.$wizard_name.'-padding-left-right-10">
									<b>'.$nagios_object_new_name[0].'</b><br/>
									<b>'.$nagios_object_new_address[0].'</b>
								</td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="datastore_check_options[VMware_Host][check_interval][0]" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="datastore_check_options[VMware_Host][retry_interval][0]" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="datastore_check_options[VMware_Host][number_retries][0]" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
							</tr>
							';
						} /* End if ($nagios_object[0] == 'new') { */
					

					/* Now loop through to find the datastores selected to monitor */
					/* Starting at 1 because 0 is the vCenter server object itself */
					$row_flag = 0;
					for ($d = 1; $d <= $datastore_counter; $d++) {
						/* Was this datastore selected? */
						if (isset($datastore_checkbox[$d])) {
							/* Datastore Selected, now to create the different check lists */
							$output_propagate_select_Datastore_Usage .= '<option value="'.$d.'">'.$datastore_checkbox[$d].'</option>';
							
							$row_class = ($row_flag % 2 == 0) ? ' class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top"' : ' class="'.$wizard_name.'-table-row-silver '.$wizard_name.'-table-row-padding-top"';

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Datastore_Usage', 'monitor_me'), $d, $datastore_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'check_interval'), $d, $datastore_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'retry_interval'), $d, $datastore_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'number_retries'), $d, $datastore_check_options, '5');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Datastore_Usage', 'reporting_si', 'Disk_Size'), $d, $datastore_check_options, 'GB');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Datastore_Usage', 'datastore_free', 'warning_checkbox'), $d, $datastore_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'datastore_free', 'warning'), $d, $datastore_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Datastore_Usage', 'datastore_free', 'critical_checkbox'), $d, $datastore_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'datastore_free', 'critical'), $d, $datastore_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Datastore_Usage', 'datastore_used', 'warning_checkbox'), $d, $datastore_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'datastore_used', 'warning'), $d, $datastore_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Datastore_Usage', 'datastore_used', 'critical_checkbox'), $d, $datastore_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Datastore_Usage', 'datastore_used', 'critical'), $d, $datastore_check_options, '');

							$output_Datastore_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width80">Select<br/>Datastore</th><th class="'.$wizard_name.'-align-left">Datastore Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="datastore_check_options[Datastore_Usage][monitor_me]['.$d.']" value="'.$d.'" class="datastore-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$datastore_checkbox[$d].'</b></td>
									<td><input type="text" name="datastore_check_options[Datastore_Usage][check_interval]['.$d.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="datastore_check_options[Datastore_Usage][retry_interval]['.$d.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="datastore_check_options[Datastore_Usage][number_retries]['.$d.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr>
															<th colspan="2" class="'.$wizard_name.'-align-center">Datastore Info</td>
														</tr>
								';
							foreach ($datastore_results_decoded['datastores'] as $datastore_item) {
								if ($datastore_item['datastore_name'] == $datastore_checkbox[$d]) {
									$output_Datastore_Usage .= '
															<tr><td class="'.$wizard_name.'-align-right">Size: </td><td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><b>'.$datastore_item['datastore_size'].' GB</b></td></tr>
															<tr><td class="'.$wizard_name.'-align-right">Type: </td><td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><b>'.$datastore_item['datastore_type'].'</b></td></tr>
										';
									} /* End if ($datastore_item['datastore_name'] == $datastore_checkbox[$d]) { */
								} /* End foreach ($datastore_results_decoded['datastores'] as $item) { */

							$output_Datastore_Usage .= '
													</table>
												</td>

												<td class="'.$wizard_name.'-width40"></td>

												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10 class="'.$wizard_name.'-align-left"><select name="datastore_check_options[Datastore_Usage][reporting_si][Disk_Size]['.$d.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Datastore_Usage .= ' selected'; $output_Datastore_Usage .= '>EB</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td class="'.$wizard_name.'-align-center">	
													<table class="'.$wizard_name.'-table-align-right">
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td>Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="datastore_check_options[Datastore_Usage][datastore_free][warning_checkbox]['.$d.']" value="'.$d.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="datastore_check_options[Datastore_Usage][datastore_free][warning]['.$d.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="datastore_check_options[Datastore_Usage][datastore_free][critical_checkbox]['.$d.']" value="'.$d.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="datastore_check_options[Datastore_Usage][datastore_free][critical]['.$d.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td>Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="datastore_check_options[Datastore_Usage][datastore_used][warning_checkbox]['.$d.']" value="'.$d.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="datastore_check_options[Datastore_Usage][datastore_used][warning]['.$d.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="datastore_check_options[Datastore_Usage][datastore_used][critical_checkbox]['.$d.']" value="'.$d.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="datastore_check_options[Datastore_Usage][datastore_used][critical]['.$d.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
									</table>
									</td>
								</tr>
								';

							array_push($objects_used, $d);
							$row_flag++;
							} /* End if (isset($datastore_checkbox[$d])) { */
						} /* End for ($d = 0; $d <= $datastore_counter; $d++) { */

					$output_Datastore_Usage .= '</table>';
					$output_VMware_Host .= '</table>';

					$output_propagate_select_Datastore_Usage .= '</select>';

					$output .= '
						<h1>Datastore Checks</h1>
						<input type="hidden" name="objects_used" id="id_objects_used" value="'.json_encode($objects_used).'">
						';
					if ($vmware_host_new == 1) {
						$output .= '
						<div id="'.$wizard_name.'-menubar" class="'.$wizard_name.'-width550">
							<input type="button" class="'.$wizard_name.'-menuheading2" id="id-'.$wizard_name.'-Datastore-Host" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Datastore-Host\')" value="Datastore Host">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Datastores" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Datastores\')" value="Datastores">
						</div>
						
						<div id="'.$wizard_name.'-Datastore-Host" class="'.$wizard_name.'-togglediv">
							<div class="sectionTitle">Nagios Host Object Settings</div>
							<div class="'.$wizard_name.'-spacer10"> </div>
							On the previous screen, you selected to create a NEW Nagios Host object.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Here you can defined the individual check settings for the NEW host.
							<div class="'.$wizard_name.'-spacer20"> </div>
							'.$output_VMware_Host.'
							';
						} /* End if ($vmware_host_new == 1) { */
					else {
						$output .= '
						<div id="'.$wizard_name.'-menubar" class="'.$wizard_name.'-width550">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Datastore-Host" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Datastore-Host\')" value="Datastore Host">
							<input type="button" class="'.$wizard_name.'-menuheading2" id="id-'.$wizard_name.'-Datastores" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Datastores\')" value="Datastores">
						</div>
						
						<div id="'.$wizard_name.'-Datastore-Host" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Nagios Host Object Settings</div>
							<div class="'.$wizard_name.'-spacer10"> </div>
							The vCenter Server OR ESX(i) Host you have selected already has an existing Nagios HOST objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Hence there are no settings to define on this tab.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<div class="'.$wizard_name.'-spacer20"> </div>
							';
						} /* End else { */
					$output .= '
						</div>
						';
					if ($vmware_host_new == 1) {
						$output .= '
						<div id="'.$wizard_name.'-Datastores" class="'.$wizard_name.'-togglediv" style="display:none">
							';
						} /* End if ($vmware_host_new == 1) { */
					else {
						$output .= '
						<div id="'.$wizard_name.'-Datastores" class="'.$wizard_name.'-togglediv">
							';
						} /* End else { */
					$output .= '
							<div class="sectionTitle">Performance</div>
							Datastore Performance checks are specific to the host(s) they are connected to.
							<div class="'.$wizard_name.'-spacer5"> </div>
							You can add these via the Hosts section.

							<div class="sectionTitle">Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Datastore_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Datastore whose options you want to propagate to all other Datastores</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'datastore_check_options:Datastore_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Disk_Size]:select~[datastore_free][warning_checkbox]:checkbox~[datastore_free][warning]:text~[datastore_free][critical_checkbox]:checkbox~[datastore_free][critical]:text~[datastore_used][warning_checkbox]:checkbox~[datastore_used][warning]:text~[datastore_used][critical_checkbox]:checkbox~[datastore_used][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="datastore_usage_checkbox_all" id="id_datastore_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_datastore_usage_checkbox_all:datastore-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Datastores
															</td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width170"></td>
												
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Datastore_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Datastore_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Datastore_Usage,datastore_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer5"> </div>
							'.$output_Datastore_Usage.'
						</div>
						'; 
					break; /* End case 'datastores': */
					

				case 'guests':
					/* Define some variables */
					$output_Guests = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Guests = '<select name="propagate_options_Guests" id="id_propagate_options_Guests" title="Select Guest to Propagate Common Options">';
					$output_Guest_CPU_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_CPU_Info = '<select name="propagate_options_Guest_CPU_Info" id="id_propagate_options_Guest_CPU_Info" title="Select Guest to Propagate Common Options">';
					$output_Guest_CPU_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_CPU_Usage = '<select name="propagate_options_Guest_CPU_Usage" id="id_propagate_options_Guest_CPU_Usage" title="Select Guest to Propagate Common Options">';
					$output_Guest_Disk_Performance = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Disk_Performance = '<select name="propagate_options_Guest_Disk_Performance" id="id_propagate_options_Guest_Disk_Performance" title="Select Guest to Propagate Common Options">';
					$output_Guest_Disk_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Disk_Usage = '<select name="propagate_options_Guest_Disk_Usage" id="id_propagate_options_Guest_Disk_Usage" title="Select Guest to Propagate Common Options">';
					$output_Guest_Memory_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Memory_Info = '<select name="propagate_options_Guest_Memory_Info" id="id_propagate_options_Guest_Memory_Info" title="Select Guest to Propagate Common Options">';
					$output_Guest_Memory_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Memory_Usage = '<select name="propagate_options_Guest_Memory_Usage" id="id_propagate_options_Guest_Memory_Usage" title="Select Guest to Propagate Common Options">';
					$output_Guest_NIC_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_NIC_Usage = '<select name="propagate_options_Guest_NIC_Usage" id="id_propagate_options_Guest_NIC_Usage" title="Select Guest to Propagate Common Options">';
					$output_Guest_Snapshot = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Guest_Snapshot = '<select name="propagate_options_Guest_Snapshot" id="id_propagate_options_Guest_Snapshot" title="Select Guest to Propagate Common Options">';
					
					/* Now loop through to find the guests selected to monitor */
					$row_flag = 0;
					$guests_new = 0;
					for ($g = 0; $g <= $guest_counter; $g++) {
						/* Was this guest selected? */
						if (isset($guest_checkbox[$g])) {
							/* Guest Selected, now to create the different check lists */
							$select_option = '<option value="'.$g.'">'.$guest_checkbox[$g].'</option>';
							$output_propagate_select_CPU_Info .= $select_option;
							$output_propagate_select_CPU_Usage .= $select_option;
							$output_propagate_select_Disk_Performance .= $select_option;
							$output_propagate_select_Disk_Usage .= $select_option;
							$output_propagate_select_Memory_Info .= $select_option;
							$output_propagate_select_Memory_Usage .= $select_option;
							$output_propagate_select_NIC_Usage .= $select_option;
							$output_propagate_select_Guest_Snapshot .= $select_option;

							$row_class = ($row_flag % 2 == 0) ? ' class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top"' : ' class="'.$wizard_name.'-table-row-silver '.$wizard_name.'-table-row-padding-top"';

							if ($nagios_object[$g] == 'new') {
								$guests_new = 1;
								$output_propagate_select_Guests .= $select_option;
							
								$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guests', 'check_interval'), $g, $guest_check_options, '5');
								$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guests', 'retry_interval'), $g, $guest_check_options, '2');
								$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guests', 'number_retries'), $g, $guest_check_options, '5');
								
								$output_Guests .= '
									<tr'.$row_class.'>
										<td class="'.$wizard_name.'-align-right">
											Guest Name:<br/>
											Nagios Object Name:<br/>
											Nagios Object Address:
										</td>
										<td class="'.$wizard_name.'-padding-left-right-10">
											<b>'.$guest_checkbox[$g].'</b><br/>
											<b>'.$nagios_object_new_name[$g].'</b><br/>
											<b>'.$nagios_object_new_address[$g].'</b>
										</td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="guest_check_options[Guests][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="guest_check_options[Guests][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="guest_check_options[Guests][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
									</tr>
									';
								} /* End if ($nagios_object[$g] == 'new') { */
							

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Info', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'check_interval'), $g, $guest_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'retry_interval'), $g, $guest_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'number_retries'), $g, $guest_check_options, '3');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_CPU_Info', 'reporting_si', 'CPU_Speed'), $g, $guest_check_options, 'MHz');
							$reservation_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Info', 'cpu_reservation', 'checkbox'), $g, $guest_check_options, '');
							$reservation_woc_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_CPU_Info', 'cpu_reservation', 'warning_or_critical'), $g, $guest_check_options, 'critical');
							$reservation_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'cpu_reservation', 'warning'), $g, $guest_check_options, '');
							$reservation_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'cpu_reservation', 'critical'), $g, $guest_check_options, '');
							$limit_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Info', 'cpu_limit', 'checkbox'), $g, $guest_check_options, '');
							$limit_woc_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_CPU_Info', 'cpu_limit', 'warning_or_critical'), $g, $guest_check_options, 'warning');
							$limit_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'cpu_limit', 'warning'), $g, $guest_check_options, '');
							$limit_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Info', 'cpu_limit', 'critical'), $g, $guest_check_options, '');
							
							$output_Guest_CPU_Info .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Info][monitor_me]['.$g.']" value="'.$g.'" class="cpu-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Info][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Info][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Info][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-center">CPU</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_CPU_Info][reporting_si][CPU_Speed]['.$g.']" title="Return metric as">
																<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>Hz</option>
																<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>kHz</option>
																<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>MHz</option>
																<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>GHz</option>
																<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>THz</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>
												
												<td class="'.$wizard_name.'-align-center">	
													<table>
														<tr><th></th><th></th><th></th><th>Warning</th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Info][cpu_reservation][checkbox]['.$g.']" value="'.$g.'"'.$reservation_checkbox_value.'></td>
															<td class="'.$wizard_name.'-align-left">Reservation</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_CPU_Info][cpu_reservation][warning_or_critical]['.$g.']" title="Warning or Critical">
																<option value="warning"'; if ($reservation_woc_value == 'warning') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>Warning</option>
																<option value="critical"'; if ($reservation_woc_value == 'critical') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>Critical</option>
															</select></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Info][cpu_reservation][warning]['.$g.']" value="'.$reservation_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Info][cpu_reservation][critical]['.$g.']" value="'.$reservation_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Info][cpu_limit][checkbox]['.$g.']" value="'.$g.'"'.$limit_checkbox_value.'></td>
															<td class="'.$wizard_name.'-align-left">Limit</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_CPU_Info][cpu_limit][warning_or_critical]['.$g.']" title="Warning or Critical">
																<option value="warning"'; if ($limit_woc_value == 'warning') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>Warning</option>
																<option value="critical"'; if ($limit_woc_value == 'critical') $output_Guest_CPU_Info .= ' selected'; $output_Guest_CPU_Info .= '>Critical</option>
															</select></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Info][cpu_limit][warning]['.$g.']" value="'.$limit_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Info][cpu_limit][critical]['.$g.']" value="'.$limit_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'check_interval'), $g, $guest_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'retry_interval'), $g, $guest_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'number_retries'), $g, $guest_check_options, '5');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_CPU_Usage', 'reporting_si', 'CPU_Speed'), $g, $guest_check_options, 'MHz');
							$return_as_ready_time_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_CPU_Usage', 'reporting_si', 'Time'), $g, $guest_check_options, 'ms');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_free', 'warning_checkbox'), $g, $guest_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_free', 'warning'), $g, $guest_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_free', 'critical_checkbox'), $g, $guest_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_free', 'critical'), $g, $guest_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_used', 'warning_checkbox'), $g, $guest_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_used', 'warning'), $g, $guest_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_used', 'critical_checkbox'), $g, $guest_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_used', 'critical'), $g, $guest_check_options, '');
							$ready_time_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_ready_time', 'warning_checkbox'), $g, $guest_check_options, '');
							$ready_time_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_ready_time', 'warning'), $g, $guest_check_options, '');
							$ready_time_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_CPU_Usage', 'cpu_ready_time', 'critical_checkbox'), $g, $guest_check_options, '');
							$ready_time_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_CPU_Usage', 'cpu_ready_time', 'critical'), $g, $guest_check_options, '');
						
							$output_Guest_CPU_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][monitor_me]['.$g.']" value="'.$g.'" class="cpu-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Usage][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Usage][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_CPU_Usage][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">CPU</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_CPU_Usage][reporting_si][CPU_Speed]['.$g.']" title="Return metric as">
																<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Hz</option>
																<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>kHz</option>
																<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>MHz</option>
																<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>GHz</option>
																<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>THz</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Ready Time</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_CPU_Usage][reporting_si][Time]['.$g.']" title="Return metric as">
																<option value="us"'; if ($return_as_ready_time_value == 'us') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Microseconds</option>
																<option value="ms"'; if ($return_as_ready_time_value == 'ms') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Milliseconds</option>
																<option value="s"'; if ($return_as_ready_time_value == 's') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Seconds</option>
																<option value="m"'; if ($return_as_ready_time_value == 'm') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Minutes</option>
																<option value="h"'; if ($return_as_ready_time_value == 'h') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Hours</option>
																<option value="d"'; if ($return_as_ready_time_value == 'd') $output_Guest_CPU_Usage .= ' selected'; $output_Guest_CPU_Usage .= '>Days</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_free][warning_checkbox]['.$g.']" value="'.$g.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_free][warning]['.$g.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_free][critical_checkbox]['.$g.']" value="'.$g.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_free][critical]['.$g.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_used][warning_checkbox]['.$g.']" value="'.$g.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_used][warning]['.$g.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_used][critical_checkbox]['.$g.']" value="'.$g.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_used][critical]['.$g.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Ready Time</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_ready_time][warning_checkbox]['.$g.']" value="'.$g.'"'.$ready_time_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_ready_time][warning]['.$g.']" value="'.$ready_time_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_CPU_Usage][cpu_ready_time][critical_checkbox]['.$g.']" value="'.$g.'"'.$ready_time_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_CPU_Usage][cpu_ready_time][critical]['.$g.']" value="'.$ready_time_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';
							

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Performance', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'check_interval'), $g, $guest_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'retry_interval'), $g, $guest_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'number_retries'), $g, $guest_check_options, '5');
							$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Disk_Performance', 'reporting_si', 'Disk_Rate'), $g, $guest_check_options, 'kBps');
							$return_as_latency_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Disk_Performance', 'reporting_si', 'Time'), $g, $guest_check_options, 'default');
							$rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Performance', 'disk_rate', 'warning_checkbox'), $g, $guest_check_options, '');
							$rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'disk_rate', 'warning'), $g, $guest_check_options, '');
							$rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Performance', 'disk_rate', 'critical_checkbox'), $g, $guest_check_options, '');
							$rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'disk_rate', 'critical'), $g, $guest_check_options, '');
							$latency_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Performance', 'disk_latency', 'warning_checkbox'), $g, $guest_check_options, '');
							$latency_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'disk_latency', 'warning'), $g, $guest_check_options, '');
							$latency_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Performance', 'disk_latency', 'critical_checkbox'), $g, $guest_check_options, '');
							$latency_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Performance', 'disk_latency', 'critical'), $g, $guest_check_options, '');

							$output_Guest_Disk_Performance .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Performance][monitor_me]['.$g.']" value="'.$g.'" class="disk-performance-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Performance][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Performance][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Performance][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
									<table class="'.$wizard_name.'-table-align-right">
										<tr><th colspan="2">Return As</th><th class="'.$wizard_name.'-width20"></th><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
										<tr>
											<td class="'.$wizard_name.'-align-right">Rate</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_Disk_Performance][reporting_si][Disk_Rate]['.$g.']" title="Return metric as">
												<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Bps</option>
												<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>kBps</option>
												<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>MBps</option>
												<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>GBps</option>
												<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>TBps</option>
												<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>PBps</option>
												<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>EBps</option>
											</select></td>
											<td></td>
											<td class="'.$wizard_name.'-align-right">Rate</td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Performance][disk_rate][warning_checkbox]['.$g.']" value="'.$g.'"'.$rate_warning_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Disk_Performance][disk_rate][warning]['.$g.']" value="'.$rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Performance][disk_rate][critical_checkbox]['.$g.']" value="'.$g.'"'.$rate_critical_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Disk_Performance][disk_rate][critical]['.$g.']" value="'.$rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
										</tr>
										<tr>
											<td class="'.$wizard_name.'-align-right">Latency</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_Disk_Performance][reporting_si][Time]['.$g.']" title="Return metric as">
												<option value="default"'; if ($return_as_latency_value == 'default') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Default</option>
												<option value="us"'; if ($return_as_latency_value == 'us') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Microseconds</option>
												<option value="ms"'; if ($return_as_latency_value == 'ms') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Milliseconds</option>
												<option value="s"'; if ($return_as_latency_value == 's') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Seconds</option>
												<option value="m"'; if ($return_as_latency_value == 'm') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Minutes</option>
												<option value="h"'; if ($return_as_latency_value == 'h') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Hours</option>
												<option value="d"'; if ($return_as_latency_value == 'd') $output_Guest_Disk_Performance .= ' selected'; $output_Guest_Disk_Performance .= '>Days</option>
											</select></td>
											<td></td>
											<td class="'.$wizard_name.'-align-right">Latency</td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Performance][disk_latency][warning_checkbox]['.$g.']" value="'.$g.'"'.$latency_warning_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Disk_Performance][disk_latency][warning]['.$g.']" value="'.$latency_warning_value.'" class="'.$wizard_name.'-width50"></td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Performance][disk_latency][critical_checkbox]['.$g.']" value="'.$g.'"'.$latency_critical_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Disk_Performance][disk_latency][critical]['.$g.']" value="'.$latency_critical_value.'" class="'.$wizard_name.'-width50"></td>
										</tr>
									</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Usage', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'check_interval'), $g, $guest_check_options, rand(50, 70));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'retry_interval'), $g, $guest_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'number_retries'), $g, $guest_check_options, '3');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Disk_Usage', 'reporting_si', 'Disk_Size'), $g, $guest_check_options, 'GB');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Usage', 'disk_free', 'warning_checkbox'), $g, $guest_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'disk_free', 'warning'), $g, $guest_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Usage', 'disk_free', 'critical_checkbox'), $g, $guest_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'disk_free', 'critical'), $g, $guest_check_options, '');
							$total_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Usage', 'disk_total', 'warning_checkbox'), $g, $guest_check_options, '');
							$total_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'disk_total', 'warning'), $g, $guest_check_options, '');
							$total_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Disk_Usage', 'disk_total', 'critical_checkbox'), $g, $guest_check_options, '');
							$total_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Disk_Usage', 'disk_total', 'critical'), $g, $guest_check_options, '');

							$output_Guest_Disk_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Usage][monitor_me]['.$g.']" value="'.$g.'" class="disk-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Usage][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Usage][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Disk_Usage][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_Disk_Usage][reporting_si][Disk_Size]['.$g.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Guest_Disk_Usage .= ' selected'; $output_Guest_Disk_Usage .= '>EB</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Usage][disk_free][warning_checkbox]['.$g.']" value="'.$g.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Disk_Usage][disk_free][warning]['.$g.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Usage][disk_free][critical_checkbox]['.$g.']" value="'.$g.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Disk_Usage][disk_free][critical]['.$g.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Total</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Usage][disk_total][warning_checkbox]['.$g.']" value="'.$g.'"'.$total_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Disk_Usage][disk_total][warning]['.$g.']" value="'.$total_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Disk_Usage][disk_total][critical_checkbox]['.$g.']" value="'.$g.'"'.$total_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Disk_Usage][disk_total][critical]['.$g.']" value="'.$total_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';
								

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Info', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'check_interval'), $g, $guest_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'retry_interval'), $g, $guest_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'number_retries'), $g, $guest_check_options, '3');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Memory_Info', 'reporting_si', 'Memory_Size'), $g, $guest_check_options, 'MB');
							$reservation_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Info', 'memory_reservation', 'checkbox'), $g, $guest_check_options, '');
							$reservation_woc_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Memory_Info', 'memory_reservation', 'warning_or_critical'), $g, $guest_check_options, 'critical');
							$reservation_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'memory_reservation', 'warning'), $g, $guest_check_options, '');
							$reservation_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'memory_reservation', 'critical'), $g, $guest_check_options, '');
							$limit_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Info', 'memory_limit', 'checkbox'), $g, $guest_check_options, '');
							$limit_woc_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Memory_Info', 'memory_limit', 'warning_or_critical'), $g, $guest_check_options, 'warning');
							$limit_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'memory_limit', 'warning'), $g, $guest_check_options, '');
							$limit_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Info', 'memory_limit', 'critical'), $g, $guest_check_options, '');

							$output_Guest_Memory_Info .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Info][monitor_me]['.$g.']" value="'.$g.'" class="memory-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Info][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Info][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Info][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_Memory_Info][reporting_si][Memory_Size]['.$g.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>EB</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th></th><th>Warning</th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Info][memory_reservation][checkbox]['.$g.']" value="'.$g.'"'.$reservation_checkbox_value.'></td>
															<td class="'.$wizard_name.'-align-left">Reservation</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_Memory_Info][memory_reservation][warning_or_critical]['.$g.']" title="Warning or Critical">
																<option value="warning"'; if ($reservation_woc_value == 'warning') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>Warning</option>
																<option value="critical"'; if ($reservation_woc_value == 'critical') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>Critical</option>
															</select></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Info][memory_reservation][warning]['.$g.']" value="'.$reservation_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Info][memory_reservation][critical]['.$g.']" value="'.$reservation_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Info][memory_limit][checkbox]['.$g.']" value="'.$g.'"'.$limit_checkbox_value.'></td>
															<td class="'.$wizard_name.'-align-left">Limit</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_Memory_Info][memory_limit][warning_or_critical]['.$g.']" title="Warning or Critical">
																<option value="warning"'; if ($limit_woc_value == 'warning') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>Warning</option>
																<option value="critical"'; if ($limit_woc_value == 'critical') $output_Guest_Memory_Info .= ' selected'; $output_Guest_Memory_Info .= '>Critical</option>
															</select></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Info][memory_limit][warning]['.$g.']" value="'.$limit_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Info][memory_limit][critical]['.$g.']" value="'.$limit_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';
								

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'check_interval'), $g, $guest_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'retry_interval'), $g, $guest_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'number_retries'), $g, $guest_check_options, '5');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Memory_Usage', 'reporting_si', 'Memory_Size'), $g, $guest_check_options, 'MB');
							$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Memory_Usage', 'reporting_si', 'Memory_Rate'), $g, $guest_check_options, 'kBps');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_free', 'warning_checkbox'), $g, $guest_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_free', 'warning'), $g, $guest_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_free', 'critical_checkbox'), $g, $guest_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_free', 'critical'), $g, $guest_check_options, '');
							$consumed_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_consumed', 'warning_checkbox'), $g, $guest_check_options, '');
							$consumed_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_consumed', 'warning'), $g, $guest_check_options, '');
							$consumed_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_consumed', 'critical_checkbox'), $g, $guest_check_options, '');
							$consumed_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_consumed', 'critical'), $g, $guest_check_options, '');
							$ballooned_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_ballooned', 'warning_checkbox'), $g, $guest_check_options, '');
							$ballooned_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_ballooned', 'warning'), $g, $guest_check_options, '');
							$ballooned_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_ballooned', 'critical_checkbox'), $g, $guest_check_options, '');
							$ballooned_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_ballooned', 'critical'), $g, $guest_check_options, '');
							$swap_rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_swap_rate', 'warning_checkbox'), $g, $guest_check_options, '');
							$swap_rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_swap_rate', 'warning'), $g, $guest_check_options, '');
							$swap_rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Memory_Usage', 'memory_swap_rate', 'critical_checkbox'), $g, $guest_check_options, '');
							$swap_rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Memory_Usage', 'memory_swap_rate', 'critical'), $g, $guest_check_options, '');

							$output_Guest_Memory_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][monitor_me]['.$g.']" value="'.$g.'" class="memory-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Usage][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Usage][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Memory_Usage][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_Memory_Usage][reporting_si][Memory_Size]['.$g.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>EB</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Rate</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="guest_check_options[Guest_Memory_Usage][reporting_si][Memory_Rate]['.$g.']" title="Return metric as">
																<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>Bps</option>
																<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>kBps</option>
																<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>MBps</option>
																<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>GBps</option>
																<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>TBps</option>
																<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>PBps</option>
																<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Guest_Memory_Usage .= ' selected'; $output_Guest_Memory_Usage .= '>EBps</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_free][warning_checkbox]['.$g.']" value="'.$g.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_free][warning]['.$g.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_free][critical_checkbox]['.$g.']" value="'.$g.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_free][critical]['.$g.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Consumed</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_consumed][warning_checkbox]['.$g.']" value="'.$g.'"'.$consumed_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_consumed][warning]['.$g.']" value="'.$consumed_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_consumed][critical_checkbox]['.$g.']" value="'.$g.'"'.$consumed_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_consumed][critical]['.$g.']" value="'.$consumed_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Ballooned</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_ballooned][warning_checkbox]['.$g.']" value="'.$g.'"'.$ballooned_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_ballooned][warning]['.$g.']" value="'.$ballooned_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_ballooned][critical_checkbox]['.$g.']" value="'.$g.'"'.$ballooned_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_ballooned][critical]['.$g.']" value="'.$ballooned_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Swap Rate</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_swap_rate][warning_checkbox]['.$g.']" value="'.$g.'"'.$swap_rate_warning_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_swap_rate][warning]['.$g.']" value="'.$swap_rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Memory_Usage][memory_swap_rate][critical_checkbox]['.$g.']" value="'.$g.'"'.$swap_rate_critical_checkbox_value.'></td>
															<td><input type="text" name="guest_check_options[Guest_Memory_Usage][memory_swap_rate][critical]['.$g.']" value="'.$swap_rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';
								

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_NIC_Usage', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_NIC_Usage', 'check_interval'), $g, $guest_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_NIC_Usage', 'retry_interval'), $g, $guest_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_NIC_Usage', 'number_retries'), $g, $guest_check_options, '5');
							$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_NIC_Usage', 'reporting_si', 'NIC_Rate'), $g, $guest_check_options, 'kBps');
							$rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_NIC_Usage', 'nic_rate', 'warning_checkbox'), $g, $guest_check_options, '');
							$rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_NIC_Usage', 'nic_rate', 'warning'), $g, $guest_check_options, '');
							$rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_NIC_Usage', 'nic_rate', 'critical_checkbox'), $g, $guest_check_options, '');
							$rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_NIC_Usage', 'nic_rate', 'critical'), $g, $guest_check_options, '');
							
							$output_Guest_NIC_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_NIC_Usage][monitor_me]['.$g.']" value="'.$g.'" class="nic-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_NIC_Usage][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_NIC_Usage][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_NIC_Usage][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
									<table class="'.$wizard_name.'-table-align-right">
										<tr><th colspan="2">Return As</th><th class="'.$wizard_name.'-width20"></th><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
										<tr>
											<td>Rate</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="guest_check_options[Guest_NIC_Usage][reporting_si][NIC_Rate]['.$g.']" title="Return metric as">
												<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>Bps</option>
												<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>kBps</option>
												<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>MBps</option>
												<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>GBps</option>
												<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>TBps</option>
												<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>PBps</option>
												<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Guest_NIC_Usage .= ' selected'; $output_Guest_NIC_Usage .= '>EBps</option>
											</select></td>
											<td></td>
											<td>Rate</td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_NIC_Usage][nic_rate][warning_checkbox]['.$g.']" value="'.$g.'"'.$rate_warning_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_NIC_Usage][nic_rate][warning]['.$g.']" value="'.$rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_NIC_Usage][nic_rate][critical_checkbox]['.$g.']" value="'.$g.'"'.$rate_critical_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_NIC_Usage][nic_rate][critical]['.$g.']" value="'.$rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
										</tr>
									</table>
									</td>
								</tr>
								';
								

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'monitor_me'), $g, $guest_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'check_interval'), $g, $guest_check_options, rand(600, 800));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'retry_interval'), $g, $guest_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'number_retries'), $g, $guest_check_options, '3');
							$age_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'warning_checkbox'), $g, $guest_check_options, '');
							$age_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'warning'), $g, $guest_check_options, '');
							$age_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'critical_checkbox'), $g, $guest_check_options, '');
							$age_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'critical'), $g, $guest_check_options, '');
							
							$output_Guest_Snapshot .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Guest</th><th class="'.$wizard_name.'-align-left">Guest Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Snapshot][monitor_me]['.$g.']" value="'.$g.'" class="guest-snapshot-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$guest_checkbox[$g].'</b></td>
									<td><input type="text" name="guest_check_options[Guest_Snapshot][check_interval]['.$g.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Snapshot][retry_interval]['.$g.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="guest_check_options[Guest_Snapshot][number_retries]['.$g.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="5">
									<table class="'.$wizard_name.'-table-align-right">
										<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
										<tr>
											<td>Snapshot Age (Days)</td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Snapshot][snapshot_age][warning_checkbox]['.$g.']" value="'.$g.'"'.$age_warning_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Snapshot][snapshot_age][warning]['.$g.']" value="'.$age_warning_value.'" class="'.$wizard_name.'-width50"></td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="guest_check_options[Guest_Snapshot][snapshot_age][critical_checkbox]['.$g.']" value="'.$g.'"'.$age_critical_checkbox_value.'></td>
											<td><input type="text" name="guest_check_options[Guest_Snapshot][snapshot_age][critical]['.$g.']" value="'.$age_critical_value.'" class="'.$wizard_name.'-width50"></td>
										</tr>
									</table>
									</td>
								</tr>
								';

							array_push($objects_used, $g);
							$row_flag++;
							} /* End if (isset($guest_checkbox[$g])) { */
						} /* End for ($g = 0; $g <= $guest_counter; $g++) { */

					$output_Guests .= '</table>';
					$output_propagate_select_Guests .= '</select>';
					$output_Guest_CPU_Info .= '</table>';
					$output_propagate_select_CPU_Info .= '</select>';
					$output_Guest_CPU_Usage .= '</table>';
					$output_propagate_select_CPU_Usage .= '</select>';
					$output_Guest_Disk_Performance .= '</table>';
					$output_propagate_select_Disk_Performance .= '</select>';
					$output_Guest_Disk_Usage .= '</table>';
					$output_propagate_select_Disk_Usage .= '</select>';
					$output_Guest_Memory_Info .= '</table>';
					$output_propagate_select_Memory_Info .= '</select>';
					$output_Guest_Memory_Usage .= '</table>';
					$output_propagate_select_Memory_Usage .= '</select>';
					$output_Guest_NIC_Usage .= '</table>';
					$output_propagate_select_NIC_Usage .= '</select>';
					$output_Guest_Snapshot .= '</table>';
					$output_propagate_select_Guest_Snapshot .= '</select>';
					
					$output .= '
						<h1>Guest Checks</h1>
						<input type="hidden" name="objects_used" id="id_objects_used" value="'.json_encode($objects_used).'">

						<div id="'.$wizard_name.'-menubar" class="'.$wizard_name.'-width650">
							<input type="button" class="'.$wizard_name.'-menuheading2" id="id-'.$wizard_name.'-Guests" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Guests\')" value="Guests">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-CPU" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-CPU\')" value="CPU">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Disk" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Disk\')" value="Disk">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Memory" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Memory\')" value="Memory">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-NIC" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-NIC\')" value="NIC">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Snapshot" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Snapshot\')" value="Snapshot">
						</div>


						<div id="'.$wizard_name.'-Guests" class="'.$wizard_name.'-togglediv">
							<div class="sectionTitle">Nagios Host Object Settings</div>
						';
					if ($guests_new == 1) {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							On the previous screen, you selected to create NEW Nagios Host objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Here you can defined the individual check settings for each of the NEW host objects.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Guests.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guests,[check_interval]:text~[retry_interval]:text~[number_retries]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max"></td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guests][check_interval][min]" value="3" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guests][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guests,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guests.'
							';
						} /* End if ($guests_new == 1) { */
					else {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							All the guests you have selected to monitor already have existing Nagios HOST objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Hence there are no settings to define on this tab.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<div class="'.$wizard_name.'-spacer20"> </div>
							';
						} /* End else { */
					$output .= '
						</div>


						<div id="'.$wizard_name.'-CPU" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">CPU Info</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_CPU_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_CPU_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select~[cpu_reservation][checkbox]:checkbox~[cpu_reservation][warning_or_critical]:select~[cpu_reservation][warning]:text~[cpu_reservation][critical]:text~[cpu_limit][checkbox]:checkbox~[cpu_limit][warning_or_critical]:select~[cpu_limit][warning]:text~[cpu_limit][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="cpu_info_checkbox_all" id="id_cpu_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_cpu_info_checkbox_all:cpu-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
												
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_CPU_Info][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_CPU_Info][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_CPU_Info,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_CPU_Info.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">CPU Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_CPU_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_CPU_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select~[reporting_si][Time]:select~[cpu_free][warning_checkbox]:checkbox~[cpu_free][warning]:text~[cpu_free][critical_checkbox]:checkbox~[cpu_free][critical]:text~[cpu_used][warning_checkbox]:checkbox~[cpu_used][warning]:text~[cpu_used][critical_checkbox]:checkbox~[cpu_used][critical]:text~[cpu_ready_time][warning_checkbox]:checkbox~[cpu_ready_time][warning]:text~[cpu_ready_time][critical_checkbox]:checkbox~[cpu_ready_time][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="cpu_usage_checkbox_all" id="id_cpu_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_cpu_usage_checkbox_all:cpu-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_CPU_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_CPU_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_CPU_Usage,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_CPU_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Disk" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Disk Performance</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Disk_Performance.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_Disk_Performance,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Disk_Rate]:select~[reporting_si][Time]:select~[disk_rate][warning_checkbox]:checkbox~[disk_rate][warning]:text~[disk_rate][critical_checkbox]:checkbox~[disk_rate][critical]:text~[disk_latency][warning_checkbox]:checkbox~[disk_latency][warning]:text~[disk_latency][critical_checkbox]:checkbox~[disk_latency][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="disk_performance_checkbox_all" id="id_disk_performance_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_disk_performance_checkbox_all:disk-performance-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Disk_Performance][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Disk_Performance][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Disk_Performance,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_Disk_Performance.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">Disk Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Disk_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_Disk_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Disk_Size]:select~[disk_free][warning_checkbox]:checkbox~[disk_free][warning]:text~[disk_free][critical_checkbox]:checkbox~[disk_free][critical]:text~[disk_total][warning_checkbox]:checkbox~[disk_total][warning]:text~[disk_total][critical_checkbox]:checkbox~[disk_total][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="disk_usage_checkbox_all" id="id_disk_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_disk_usage_checkbox_all:disk-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Disk_Usage][check_interval][min]" value="50" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Disk_Usage][check_interval][max]" value="70" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Disk_Usage,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_Disk_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Memory" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Memory Info</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Memory_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_Memory_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Memory_Size]:select~[memory_reservation][checkbox]:checkbox~[memory_reservation][warning_or_critical]:select~[memory_reservation][warning]:text~[memory_reservation][critical]:text~[memory_limit][checkbox]:checkbox~[memory_limit][warning_or_critical]:select~[memory_limit][warning]:text~[memory_limit][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="memory_info_checkbox_all" id="id_memory_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_memory_info_checkbox_all:memory-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
												
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Memory_Info][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Memory_Info][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Memory_Info,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_Memory_Info.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">Memory Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Memory_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_Memory_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Memory_Size]:select~[reporting_si][Memory_Rate]:select~[memory_free][warning_checkbox]:checkbox~[memory_free][warning]:text~[memory_free][critical_checkbox]:checkbox~[memory_free][critical]:text~[memory_consumed][warning_checkbox]:checkbox~[memory_consumed][warning]:text~[memory_consumed][critical_checkbox]:checkbox~[memory_consumed][critical]:text~[memory_ballooned][warning_checkbox]:checkbox~[memory_ballooned][warning]:text~[memory_ballooned][critical_checkbox]:checkbox~[memory_ballooned][critical]:text~[memory_swap_rate][warning_checkbox]:checkbox~[memory_swap_rate][warning]:text~[memory_swap_rate][critical_checkbox]:checkbox~[memory_swap_rate][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="memory_usage_checkbox_all" id="id_memory_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_memory_usage_checkbox_all:memory-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Memory_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Memory_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Memory_Usage,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_Memory_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-NIC" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">NIC Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_NIC_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_NIC_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][NIC_Rate]:select~[nic_rate][warning_checkbox]:checkbox~[nic_rate][warning]:text~[nic_rate][critical_checkbox]:checkbox~[nic_rate][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="nic_usage_checkbox_all" id="id_nic_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_nic_usage_checkbox_all:nic-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_NIC_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_NIC_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_NIC_Usage,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_NIC_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Snapshot" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Snapshots</div>
							NOTE: It\'s better to add a Datacenter/Cluster/Host wide check for this as it will find ALL Guests.
							<div class="'.$wizard_name.'-spacer5"> </div>
							This results in just one service definition instead of a definition for each guest!. 
							<div class="'.$wizard_name.'-spacer20"> </div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Guest_Snapshot.'</td><td class="'.$wizard_name.'-padding-left">Select the Guest whose options you want to propagate to all other Guests</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'guest_check_options:Guest_Snapshot,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[snapshot_age][warning_checkbox]:checkbox~[snapshot_age][warning]:text~[snapshot_age][critical_checkbox]:checkbox~[snapshot_age][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="guest_snapshot_checkbox_all" id="id_guest_snapshot_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_guest_snapshot_checkbox_all:guest-snapshot-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Guests
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Snapshot][check_interval][min]" value="600" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Snapshot][check_interval][max]" value="800" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Snapshot,guest_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Guest_Snapshot.'
						</div>
						';
					break; /* End case 'guests': */


				case 'host':
					/* Define some variables */
					$output_Hosts = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500"><tr'.$row_class.'><th></th><th></th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_Hosts = '<select name="propagate_options_Hosts" id="id_propagate_options_Hosts" title="Select Host to Propagate Common Options">';
					$output_Host_CPU_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_CPU_Info = '<select name="propagate_options_Host_CPU_Info" id="id_propagate_options_Host_CPU_Info" title="Select Host to Propagate Common Options">';
					$output_Host_CPU_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_CPU_Usage = '<select name="propagate_options_Host_CPU_Usage" id="id_propagate_options_Host_CPU_Usage" title="Select Host to Propagate Common Options">';
					$output_Host_Datastore_Performance = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Datastore_Performance = '<select name="propagate_options_Host_Datastore_Performance" id="id_propagate_options_Host_Datastore_Performance" title="Select Host to Propagate Common Options">';
					$output_Host_Guest_Snapshot = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Guest_Snapshot = '<select name="propagate_options_Guest_Snapshot" id="id_propagate_options_Guest_Snapshot" title="Select Host to Propagate Common Options">';
					$output_Host_License_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_License_Status = '<select name="propagate_options_Host_License_Status" id="id_propagate_options_Host_License_Status" title="Select Host to Propagate Common Options">';
					$output_Host_Memory_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Memory_Usage = '<select name="propagate_options_Host_Memory_Usage" id="id_propagate_options_Host_Memory_Usage" title="Select Host to Propagate Common Options">';
					$output_Host_OS_Name_Version = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_OS_Name_Version = '<select name="propagate_options_Host_OS_Name_Version" id="id_propagate_options_Host_OS_Name_Version" title="Select Host to Propagate Common Options">';
					$output_Host_pNIC_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_pNIC_Status = '<select name="propagate_options_Host_pNIC_Status" id="id_propagate_options_Host_pNIC_Status" title="Select Host to Propagate Common Options">';
					$output_Host_pNIC_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_pNIC_Usage = '<select name="propagate_options_Host_pNIC_Usage" id="id_propagate_options_Host_pNIC_Usage" title="Select Host to Propagate Common Options">';
					$output_Host_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_Status = '<select name="propagate_options_Host_Status" id="id_propagate_options_Host_Status" title="Select Host to Propagate Common Options">';
					$output_Host_Storage_Adapter_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Storage_Adapter_Info = '<select name="propagate_options_Host_Storage_Adapter_Info" id="id_propagate_options_Host_Storage_Adapter_Info" title="Select Host to Propagate Common Options">';
					$output_Host_Storage_Adapter_Performance = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Storage_Adapter_Performance = '<select name="propagate_options_Host_Storage_Adapter_Performance" id="id_propagate_options_Host_Storage_Adapter_Performance" title="Select Host to Propagate Common Options">';
					$output_Host_Switch_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_Switch_Status = '<select name="propagate_options_Host_Switch_Status" id="id_propagate_options_Host_Switch_Status" title="Select Host to Propagate Common Options">';
					$output_Host_vNIC_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">';
					$output_propagate_select_vNIC_Status = '<select name="propagate_options_Host_vNIC_Status" id="id_propagate_options_Host_vNIC_Status" title="Select Host to Propagate Common Options">';
					
					/* Now loop through to find the hosts selected to monitor */
					$row_flag = 0;
					$hosts_new = 0;
					for ($h = 0; $h <= $host_counter; $h++) {
						/* Was this host selected? */
						if (isset($host_checkbox[$h])) {
							/* Host Selected, now to create the different check lists */
							$select_option = '<option value="'.$h.'">'.$host_checkbox[$h].'</option>';
							$output_propagate_select_CPU_Info .= $select_option;
							$output_propagate_select_CPU_Usage .= $select_option;
							$output_propagate_select_Guest_Snapshot .= $select_option;
							$output_propagate_select_License_Status .= $select_option;
							$output_propagate_select_Memory_Usage .= $select_option;
							$output_propagate_select_OS_Name_Version .= $select_option;
							$output_propagate_select_pNIC_Status .= $select_option;
							$output_propagate_select_pNIC_Usage .= $select_option;
							$output_propagate_select_Status .= $select_option;
							$output_propagate_select_Storage_Adapter_Info .= $select_option;
							$output_propagate_select_Storage_Adapter_Performance .= $select_option;
							$output_propagate_select_Switch_Status .= $select_option;
							$output_propagate_select_vNIC_Status .= $select_option;
					
							$row_class = ($row_flag % 2 == 0) ? ' class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top"' : ' class="'.$wizard_name.'-table-row-silver '.$wizard_name.'-table-row-padding-top"';

							if ($nagios_object[$h] == 'new') {
								$hosts_new = 1;
								$output_propagate_select_Hosts .= $select_option;
							
								$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Hosts', 'check_interval'), $h, $host_check_options, '5');
								$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Hosts', 'retry_interval'), $h, $host_check_options, '2');
								$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Hosts', 'number_retries'), $h, $host_check_options, '5');
								
								$output_Hosts .= '
									<tr'.$row_class.'>
										<td class="'.$wizard_name.'-align-right">
											ESX(i) Host Name:<br/>
											Nagios Object Name:<br/>
											Nagios Object Address:
										</td>
										<td class="'.$wizard_name.'-padding-left-right-10">
											<b>'.$host_checkbox[$h].'</b><br/>
											<b>'.$nagios_object_new_name[$h].'</b><br/>
											<b>'.$nagios_object_new_address[$h].'</b>
										</td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Hosts][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Hosts][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
										<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Hosts][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
									</tr>
									';
								} /* End if ($nagios_object[$h] == 'new') { */
							

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Info', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Info', 'check_interval'), $h, $host_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Info', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Info', 'number_retries'), $h, $host_check_options, '3');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Host_CPU_Info', 'reporting_si', 'CPU_Speed'), $h, $host_check_options, 'GHz');
							
							$output_Host_CPU_Info .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Info][monitor_me]['.$h.']" value="'.$h.'" class="cpu-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Info][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Info][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Info][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
										<table>
											<tr><th colspan="2">Return As</th></tr>
											<tr>
												<td class="'.$wizard_name.'-align-center">CPU</td>
												<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_CPU_Info][reporting_si][CPU_Speed]['.$h.']" title="Return metric as">
													<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Host_CPU_Info .= ' selected'; $output_Host_CPU_Info .= '>Hz</option>
													<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Host_CPU_Info .= ' selected'; $output_Host_CPU_Info .= '>kHz</option>
													<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Host_CPU_Info .= ' selected'; $output_Host_CPU_Info .= '>MHz</option>
													<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Host_CPU_Info .= ' selected'; $output_Host_CPU_Info .= '>GHz</option>
													<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Host_CPU_Info .= ' selected'; $output_Host_CPU_Info .= '>THz</option>
												</select></td>
											</tr>
										</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Usage', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'check_interval'), $h, $host_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'retry_interval'), $h, $host_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'number_retries'), $h, $host_check_options, '5');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Host_CPU_Usage', 'reporting_si', 'CPU_Speed'), $h, $host_check_options, 'GHz');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Usage', 'cpu_free', 'warning_checkbox'), $h, $host_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'cpu_free', 'warning'), $h, $host_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Usage', 'cpu_free', 'critical_checkbox'), $h, $host_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'cpu_free', 'critical'), $h, $host_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Usage', 'cpu_used', 'warning_checkbox'), $h, $host_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'cpu_used', 'warning'), $h, $host_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_CPU_Usage', 'cpu_used', 'critical_checkbox'), $h, $host_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_CPU_Usage', 'cpu_used', 'critical'), $h, $host_check_options, '');
							
							$output_Host_CPU_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Usage][monitor_me]['.$h.']" value="'.$h.'" class="cpu-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Usage][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Usage][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_CPU_Usage][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">CPU</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_CPU_Usage][reporting_si][CPU_Speed]['.$h.']" title="Return metric as">
																<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Host_CPU_Usage .= ' selected'; $output_Host_CPU_Usage .= '>Hz</option>
																<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Host_CPU_Usage .= ' selected'; $output_Host_CPU_Usage .= '>kHz</option>
																<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Host_CPU_Usage .= ' selected'; $output_Host_CPU_Usage .= '>MHz</option>
																<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Host_CPU_Usage .= ' selected'; $output_Host_CPU_Usage .= '>GHz</option>
																<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Host_CPU_Usage .= ' selected'; $output_Host_CPU_Usage .= '>THz</option>
															</select></td>
														</tr>
													</table>
												</td>
												
												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Usage][cpu_free][warning_checkbox]['.$h.']" value="'.$h.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_CPU_Usage][cpu_free][warning]['.$h.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Usage][cpu_free][critical_checkbox]['.$h.']" value="'.$h.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_CPU_Usage][cpu_free][critical]['.$h.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Usage][cpu_used][warning_checkbox]['.$h.']" value="'.$h.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_CPU_Usage][cpu_used][warning]['.$h.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_CPU_Usage][cpu_used][critical_checkbox]['.$h.']" value="'.$h.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_CPU_Usage][cpu_used][critical]['.$h.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';


							/* Get all the datastores and add them to an array */
							$datastores = array();
							foreach ($host_results_decoded['hosts'] as $host) {
								if ($host['host_name'] == $host_checkbox[$h]) {
									foreach ($host['datastores'] as $datastore) {
										/* Add them to the array */
										$datastores[$datastore['datastore_name']] = $datastore;
										} /* End foreach ($host['datastores'] as $datastore) { */
									} /* End if ($host['host_name'] == $host_checkbox[$h]) { */
								} /* End foreach ($host_results_decoded['hosts'] as $host) { */

							/* Sort the array */
							ksort($datastores);

							if (count($datastores) > 0) {
								$output_Host_Datastore_Performance .= '
									<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th colspan="4" class="'.$wizard_name.'-align-center">Host Name</th></tr>
									<tr'.$row_class.'>
										<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance][monitor_me]['.$h.']" value="'.$h.'" class="datastore-performance-checkbox"></td>
										<td colspan="4" class="'.$wizard_name.'-align-center"><b>'.$host_checkbox[$h].'</b></td>
									</tr>

									<tr'.$row_class.'>
										<td></td>
										<td colspan="4">
											<table class="'.$wizard_name.'-table">
									';
								
								$row_flag_datastore = 0;
								
								/* Now list each datastore this host has */
								foreach ($datastores as $datastore) {
									$output_propagate_select_Datastore_Performance .= '<option value="['.$h.']~'.$datastore['datastore_name'].'">'.$host_checkbox[$h].' - '.$datastore['datastore_name'].'</option>';

									$row_class_datastore = ($row_flag_datastore % 2 == 0) ? ' class="'.$wizard_name.'-table-row-graygoose '.$wizard_name.'-table-row-padding-top"' : ' class="'.$wizard_name.'-table-row-platinum '.$wizard_name.'-table-row-padding-top"';
									
									$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Datastore_Performance', 'monitor_me', $datastore['datastore_name']), $h, $host_check_options, '');
									$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'check_interval', $datastore['datastore_name']), $h, $host_check_options, '5');
									$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'retry_interval', $datastore['datastore_name']), $h, $host_check_options, '2');
									$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'number_retries', $datastore['datastore_name']), $h, $host_check_options, '5');
									$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Datastore_Performance', 'reporting_si', 'Datastore_Rate', $datastore['datastore_name']), $h, $host_check_options, 'kBps');
									$return_as_latency_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Datastore_Performance', 'reporting_si', 'Latency', $datastore['datastore_name']), $h, $host_check_options, 'ms');
									$rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Datastore_Performance', 'datastore_rate', 'warning_checkbox', $datastore['datastore_name']), $h, $host_check_options, '');
									$rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'datastore_rate', 'warning', $datastore['datastore_name']), $h, $host_check_options, '');
									$rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Datastore_Performance', 'datastore_rate', 'critical_checkbox', $datastore['datastore_name']), $h, $host_check_options, '');
									$rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'datastore_rate', 'critical', $datastore['datastore_name']), $h, $host_check_options, '');
									$latency_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Datastore_Performance', 'datastore_latency', 'warning_checkbox', $datastore['datastore_name']), $h, $host_check_options, '');
									$latency_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'datastore_latency', 'warning', $datastore['datastore_name']), $h, $host_check_options, '');
									$latency_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Datastore_Performance', 'datastore_latency', 'critical_checkbox', $datastore['datastore_name']), $h, $host_check_options, '');
									$latency_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Datastore_Performance', 'datastore_latency', 'critical', $datastore['datastore_name']), $h, $host_check_options, '');
									
									$output_Host_Datastore_Performance .= '
												<tr'.$row_class_datastore.'>
													<td>
														<table class="'.$wizard_name.'-table">
															<tr'.$row_class_datastore.'><th class="'.$wizard_name.'-width70">Select<br/>Datastore</th><th class="'.$wizard_name.'-align-left">Datastore Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
															<tr>
																<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance]['.$h.'][monitor_me]['.$datastore['datastore_name'].']" value="'.$datastore['datastore_name'].'"'.$monitor_me_checkbox_value.'></td>
																<td class="'.$wizard_name.'-width250"><i>'.$datastore['datastore_name'].'</i></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][check_interval]['.$datastore['datastore_name'].']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][retry_interval]['.$datastore['datastore_name'].']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][number_retries]['.$datastore['datastore_name'].']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
															</tr>
														</table>

														<table class="'.$wizard_name.'-table-align-left">
															<tr><th colspan="2">Return As</th></tr>
															<tr>
																<td class="'.$wizard_name.'-align-right">Rate</td>
																<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_Datastore_Performance]['.$h.'][reporting_si][Datastore_Rate]['.$datastore['datastore_name'].']" title="Return metric as">
																	<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Bps</option>
																	<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>kBps</option>
																	<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>MBps</option>
																	<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>GBps</option>
																	<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>TBps</option>
																	<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>PBps</option>
																	<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>EBps</option>
																</select></td>
															</tr>
															<tr>
																<td class="'.$wizard_name.'-align-right">Latency</td>
																<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_Datastore_Performance]['.$h.'][reporting_si][Latency]['.$datastore['datastore_name'].']" title="Return metric as">
																	<option value="us"'; if ($return_as_latency_value == 'us') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Microseconds</option>
																	<option value="ms"'; if ($return_as_latency_value == 'ms') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Milliseconds</option>
																	<option value="s"'; if ($return_as_latency_value == 's') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Seconds</option>
																	<option value="m"'; if ($return_as_latency_value == 'm') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Minutes</option>
																	<option value="h"'; if ($return_as_latency_value == 'h') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Hours</option>
																	<option value="d"'; if ($return_as_latency_value == 'd') $output_Host_Datastore_Performance .= ' selected'; $output_Host_Datastore_Performance .= '>Days</option>
																</select></td>
															</tr>
														</table>
														
														<table class="'.$wizard_name.'-table-align-right">
															<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
															<tr>
																<td class="'.$wizard_name.'-align-right">Rate</td>
																<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_rate][warning_checkbox]['.$datastore['datastore_name'].']" value="'.$datastore['datastore_name'].'"'.$rate_warning_checkbox_value.'></td>
																<td><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_rate][warning]['.$datastore['datastore_name'].']" value="'.$rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_rate][critical_checkbox]['.$datastore['datastore_name'].']" value="'.$datastore['datastore_name'].'"'.$rate_critical_checkbox_value.'></td>
																<td><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_rate][critical]['.$datastore['datastore_name'].']" value="'.$rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
															</tr>
															<tr>
																<td class="'.$wizard_name.'-align-right">Latency Total</td>
																<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_latency][warning_checkbox]['.$datastore['datastore_name'].']" value="'.$datastore['datastore_name'].'"'.$latency_warning_checkbox_value.'></td>
																<td><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_latency][warning]['.$datastore['datastore_name'].']" value="'.$latency_warning_value.'" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_latency][critical_checkbox]['.$datastore['datastore_name'].']" value="'.$datastore['datastore_name'].'"'.$latency_critical_checkbox_value.'></td>
																<td><input type="text" name="host_check_options[Host_Datastore_Performance]['.$h.'][datastore_latency][critical]['.$datastore['datastore_name'].']" value="'.$latency_critical_value.'" class="'.$wizard_name.'-width50"></td>
															</tr>	
															</tr>
														</table>
													</td>
												</tr>
										';
									$row_flag_datastore++;
									} /* End foreach ($datastores as $datastore) { */

								$output_Host_Datastore_Performance .= '
											</table>
										</td>
									</tr>
									';
								} /* End if (count($datastores) > 0) { */
							else {
								$output_Host_Datastore_Performance .= '
										<tr'.$row_class.'>
											<td></td>
											<td colspan="4">
									';
								if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
									$output_Host_Datastore_Performance .= 'Host <b>'.$host_checkbox[$h].'</b> is not currently accessible, it\'s datastores cannot be retrieved.';
									} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
								else {
									$output_Host_Datastore_Performance .= 'Host <b>'.$host_checkbox[$h].'</b> does not appear to have any datastores.';
									} /* End else { */
									$output_Host_Datastore_Performance .= '
											</td>
										</tr>
										';
								} /* End else { */

								

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'check_interval'), $h, $host_check_options, rand(600, 800));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'number_retries'), $h, $host_check_options, '3');
							$age_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'warning_checkbox'), $h, $host_check_options, '');
							$age_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'warning'), $h, $host_check_options, '');
							$age_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'critical_checkbox'), $h, $host_check_options, '');
							$age_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'critical'), $h, $host_check_options, '');
							
							$output_Host_Guest_Snapshot .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Guest_Snapshot][monitor_me]['.$h.']" value="'.$h.'" class="guest-snapshot-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td><input type="text" name="host_check_options[Guest_Snapshot][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="host_check_options[Guest_Snapshot][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td><input type="text" name="host_check_options[Guest_Snapshot][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="5">
									<table class="'.$wizard_name.'-table-align-right">
										<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
										<tr>
											<td>Snapshot Age (Days)</td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Guest_Snapshot][snapshot_age][warning_checkbox]['.$h.']" value="'.$h.'"'.$age_warning_checkbox_value.'></td>
											<td><input type="text" name="host_check_options[Guest_Snapshot][snapshot_age][warning]['.$h.']" value="'.$age_warning_value.'" class="'.$wizard_name.'-width50"></td>
											<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Guest_Snapshot][snapshot_age][critical_checkbox]['.$h.']" value="'.$h.'"'.$age_critical_checkbox_value.'></td>
											<td><input type="text" name="host_check_options[Guest_Snapshot][snapshot_age][critical]['.$h.']" value="'.$age_critical_value.'" class="'.$wizard_name.'-width50"></td>
										</tr>
									</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_License_Status', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_License_Status', 'check_interval'), $h, $host_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_License_Status', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_License_Status', 'number_retries'), $h, $host_check_options, '3');
							$hide_key_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'hide_key'), $h, $host_check_options, '');
							
							$output_Host_License_Status .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_License_Status][monitor_me]['.$h.']" value="'.$h.'" class="license-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_License_Status][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_License_Status][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_License_Status][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
										<table class="'.$wizard_name.'-table-align-left">
											<tr>
												<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_License_Status][hide_key]['.$h.']" value="'.$h.'"'.$hide_key_checkbox_value.'></td>
												<td>Hide License Key</td>										
											</tr>
										</table>
									</td>
								</tr>
								';
							

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Memory_Usage', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'check_interval'), $h, $host_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'retry_interval'), $h, $host_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'number_retries'), $h, $host_check_options, '5');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Memory_Usage', 'reporting_si', 'Memory_Size'), $h, $host_check_options, 'GB');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Memory_Usage', 'memory_free', 'warning_checkbox'), $h, $host_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'memory_free', 'warning'), $h, $host_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Memory_Usage', 'memory_free', 'critical_checkbox'), $h, $host_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'memory_free', 'critical'), $h, $host_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Memory_Usage', 'memory_used', 'warning_checkbox'), $h, $host_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'memory_used', 'warning'), $h, $host_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Memory_Usage', 'memory_used', 'critical_checkbox'), $h, $host_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Memory_Usage', 'memory_used', 'critical'), $h, $host_check_options, '');
							
							$output_Host_Memory_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Memory_Usage][monitor_me]['.$h.']" value="'.$h.'" class="memory-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Memory_Usage][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Memory_Usage][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Memory_Usage][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_Memory_Usage][reporting_si][Memory_Size]['.$h.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Host_Memory_Usage .= ' selected'; $output_Host_Memory_Usage .= '>EB</option>
															</select></td>
														</tr>
													</table>
												</td>
												
												<td class="'.$wizard_name.'-width20"></td>

												<td>
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Memory_Usage][memory_free][warning_checkbox]['.$h.']" value="'.$h.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_Memory_Usage][memory_free][warning]['.$h.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Memory_Usage][memory_free][critical_checkbox]['.$h.']" value="'.$h.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_Memory_Usage][memory_free][critical]['.$h.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Memory_Usage][memory_used][warning_checkbox]['.$h.']" value="'.$h.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_Memory_Usage][memory_used][warning]['.$h.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Memory_Usage][memory_used][critical_checkbox]['.$h.']" value="'.$h.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_Memory_Usage][memory_used][critical]['.$h.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>								
										</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_OS_Name_Version', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_OS_Name_Version', 'check_interval'), $h, $host_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_OS_Name_Version', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_OS_Name_Version', 'number_retries'), $h, $host_check_options, '3');

							$output_Host_OS_Name_Version .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_OS_Name_Version][monitor_me]['.$h.']" value="'.$h.'" class="os-name-version-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_OS_Name_Version][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_OS_Name_Version][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_OS_Name_Version][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								';


							/* Get all the pNICs and add them to an array */
							$pnics = array();
							foreach ($host_results_decoded['hosts'] as $host) {
								if ($host['host_name'] == $host_checkbox[$h]) {
									foreach ($host['pnics'] as $pnic) {
										/* Add them to the array */
										$pnics[$pnic['pnic_name']] = $pnic;
										} /* End foreach ($host['pnics'] as $pnic) { */
									} /* End if ($host['host_name'] == $host_checkbox[$h]) { */
								} /* End foreach ($host_results_decoded['hosts'] as $host) { */

							/* Sort the array */
							ksort($pnics);

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Status', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Status', 'check_interval'), $h, $host_check_options, rand(21, 39));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Status', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Status', 'number_retries'), $h, $host_check_options, '3');
							$nic_state_value = vmwarevirtualizationwizard_option_check('select', array ('Host_pNIC_Status', 'nic_state'), $h, $host_check_options, 'connected');
							$nic_duplex_value = vmwarevirtualizationwizard_option_check('select', array ('Host_pNIC_Status', 'nic_duplex'), $h, $host_check_options, 'full');
							$nic_speed_value = vmwarevirtualizationwizard_option_check('select', array ('Host_pNIC_Status', 'nic_speed'), $h, $host_check_options, 'default');
							$pnic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Status', 'pnic_checkbox', 'all'), $h, $host_check_options, '');

							$output_Host_pNIC_Status .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Status][monitor_me]['.$h.']" value="'.$h.'" class="pnic-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Status][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Status][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Status][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table>
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-left">
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">State</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_pNIC_Status][nic_state]['.$h.']" title="Return metric as">
																<option value="connected"'; if ($nic_state_value == 'connected') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>Connected</option>
																<option value="disconnected"'; if ($nic_state_value == 'disconnected') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>Disconnected</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Duplex</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_pNIC_Status][nic_duplex]['.$h.']" title="Return metric as">
																<option value="full"'; if ($nic_duplex_value == 'full') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>Full</option>
																<option value="half"'; if ($nic_duplex_value == 'half') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>Half</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Speed</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_pNIC_Status][nic_speed]['.$h.']" title="Return metric as">
																<option value="default"'; if ($nic_speed_value == 'default') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>Connected Speed</option>
																<option value="10"'; if ($nic_speed_value == '10') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>10</option>
																<option value="100"'; if ($nic_speed_value == '100') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>100</option>
																<option value="1000"'; if ($nic_speed_value == '1000') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>1,000</option>
																<option value="40000"'; if ($nic_speed_value == '40000') $output_Host_pNIC_Status .= ' selected'; $output_Host_pNIC_Status .= '>40,000</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td class="'.$wizard_name.'-align-center">	
													<table class="'.$wizard_name.'-table-align-right">
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Status][pnic_checkbox]['.$h.'][all]" value="all"'.$pnic_select_value.'></td><td class="'.$wizard_name.'-align-left">All</td>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_pNIC_Status .= '
														</tr>
														<tr><td colspan="2"></td></tr>
														<tr>
															<td></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s pNICs cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the pNICs */
								$pnic_counter = 1;
								foreach ($pnics as $pnic) {
									if ($pnic_counter != 0) {
										if ($pnic_counter % 3 === 0) {
											$output_Host_pNIC_Status .= '</tr><tr>';
											} /* End if ($pnic_counter % 3 === 0) { */
										else {
											$output_Host_pNIC_Status .= '<td class="'.$wizard_name.'-width2"></td>';
											} /* End else { */
										} /* End if ($pnic_counter != 0) { */
									$nic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Status', 'pnic_checkbox', $pnic['pnic_name']), $h, $host_check_options, '');
									$output_Host_pNIC_Status .= '<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Status][pnic_checkbox]['.$h.']['.$pnic['pnic_name'].']" value="'.$pnic['pnic_name'].'"'.$nic_select_value.'></td><td class="'.$wizard_name.'-align-left">'.$pnic['pnic_name'].'</td>';
									$pnic_counter++;
									} /* End foreach ($pnics as $pnic) { */
								} /* End else { */
							$output_Host_pNIC_Status .= '
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';

						
							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'check_interval'), $h, $host_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'retry_interval'), $h, $host_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'number_retries'), $h, $host_check_options, '5');
							$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Host_pNIC_Usage', 'reporting_si', 'NIC_Rate'), $h, $host_check_options, 'kBps');
							$rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'nic_rate', 'warning_checkbox'), $h, $host_check_options, '');
							$rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'nic_rate', 'warning'), $h, $host_check_options, '');
							$rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'nic_rate', 'critical_checkbox'), $h, $host_check_options, '');
							$rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'nic_rate', 'critical'), $h, $host_check_options, '');
							$packet_errors_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'packet_errors', 'warning_checkbox'), $h, $host_check_options, '');
							$packet_errors_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'packet_errors', 'warning'), $h, $host_check_options, '');
							$packet_errors_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'packet_errors', 'critical_checkbox'), $h, $host_check_options, '');
							$packet_errors_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_pNIC_Usage', 'packet_errors', 'critical'), $h, $host_check_options, '');
							$pnic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'pnic_checkbox', 'all'), $h, $host_check_options, '');
							
							$output_Host_pNIC_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][monitor_me]['.$h.']" value="'.$h.'" class="pnic-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Usage][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Usage][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_pNIC_Usage][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>

								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table>
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-left">
														<tr><th></th><th>Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Rate</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_pNIC_Usage][reporting_si][NIC_Rate]['.$h.']" title="Return metric as">
																<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>Bps</option>
																<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>kBps</option>
																<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>MBps</option>
																<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>GBps</option>
																<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>TBps</option>
																<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>PBps</option>
																<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Host_pNIC_Usage .= ' selected'; $output_Host_pNIC_Usage .= '>EBps</option>
															</select></td>
														</tr>
													</table>

													<div class="'.$wizard_name.'-spacer50"> </div>

													<table class="'.$wizard_name.'-table-align-left">
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Rate</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][nic_rate][warning_checkbox]['.$h.']" value="'.$h.'"'.$rate_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_pNIC_Usage][nic_rate][warning]['.$h.']" value="'.$rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][nic_rate][critical_checkbox]['.$h.']" value="'.$h.'"'.$rate_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_pNIC_Usage][nic_rate][critical]['.$h.']" value="'.$rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Packet Errors</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][packet_errors][warning_checkbox]['.$h.']" value="'.$h.'"'.$packet_errors_warning_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_pNIC_Usage][packet_errors][warning]['.$h.']" value="'.$packet_errors_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][packet_errors][critical_checkbox]['.$h.']" value="'.$h.'"'.$packet_errors_critical_checkbox_value.'></td>
															<td><input type="text" name="host_check_options[Host_pNIC_Usage][packet_errors][critical]['.$h.']" value="'.$packet_errors_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>										
													</table>
												</td>

												<td class="'.$wizard_name.'-width20"></td>

												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][pnic_checkbox]['.$h.'][all]" value="all"'.$pnic_select_value.'></td><td class="'.$wizard_name.'-align-left">All</td>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_pNIC_Usage .= '
														</tr>
														<tr><td colspan="2"></td></tr>
														<tr>
															<td></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s pNICs cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the pNICs */
								$pnic_counter = 1;
								foreach ($pnics as $pnic) {
									if ($pnic_counter != 0) {
										if ($pnic_counter % 3 === 0) {
											$output_Host_pNIC_Usage .= '</tr><tr>';
											} /* End if ($pnic_counter % 3 === 0) { */
										else {
											$output_Host_pNIC_Usage .= '<td class="'.$wizard_name.'-width2"></td>';
											} /* End else { */
										} /* End if ($pnic_counter != 0) { */
									$nic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_pNIC_Usage', 'pnic_checkbox', $pnic['pnic_name']), $h, $host_check_options, '');
									$output_Host_pNIC_Usage .= '<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_pNIC_Usage][pnic_checkbox]['.$h.']['.$pnic['pnic_name'].']" value="'.$pnic['pnic_name'].'"'.$nic_select_value.'></td><td class="'.$wizard_name.'-align-left">'.$pnic['pnic_name'].'</td>';
									$pnic_counter++;
									} /* End foreach ($pnics as $pnic) { */
								} /* End else { */
							$output_Host_pNIC_Usage .= '
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Status', 'check_interval'), $h, $host_check_options, rand(6, 11));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Status', 'retry_interval'), $h, $host_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Status', 'number_retries'), $h, $host_check_options, '5');
							$exclude_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue_checkbox'), $h, $host_check_options, '');
							$exclude_issue_ClusterOvercommittedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'ClusterOvercommittedEvent'), $h, $host_check_options, '');
							$exclude_issue_DasClusterIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'DasClusterIsolatedEvent'), $h, $host_check_options, '');
							$exclude_issue_DasHostFailedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'DasHostFailedEvent'), $h, $host_check_options, '');
							$exclude_issue_DasHostIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'DasHostIsolatedEvent'), $h, $host_check_options, '');
							$exclude_issue_HeartbeatDatastoreNotSufficient_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'HeartbeatDatastoreNotSufficient'), $h, $host_check_options, '');
							$exclude_issue_HostNoRedundantManagementNetworkEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'HostNoRedundantManagementNetworkEvent'), $h, $host_check_options, '');
							$exclude_issue_InsufficientFailoverResourcesEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'InsufficientFailoverResourcesEvent'), $h, $host_check_options, '');
							$exclude_issue_LocalTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'LocalTSMEnabledEvent'), $h, $host_check_options, '');
							$exclude_issue_RemoteTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Status', 'exclude_issue', 'RemoteTSMEnabledEvent'), $h, $host_check_options, '');
							
							$output_Host_Status .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Status][monitor_me]['.$h.']" value="'.$h.'" class="status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Status][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Status][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Status][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5">
										<table class="'.$wizard_name.'-table-align-right"><tr>
											<td class="'.$wizard_name.'-align-center">
												<table class="'.$wizard_name.'-border-dotted">
													<tr><td colspan="2" class="'.$wizard_name.'-align-center '.$wizard_name.'-border-bottom-dotted"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue_checkbox]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_checkbox_value.'> Exclude Issue If Detected</td></tr>
													<tr>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][ClusterOvercommittedEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_ClusterOvercommittedEvent_value.'> ClusterOvercommittedEvent</td>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][DasClusterIsolatedEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasClusterIsolatedEvent_value.'> DasClusterIsolatedEvent</td>
													</tr>
													<tr>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][DasHostFailedEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostFailedEvent_value.'> DasHostFailedEvent</td>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][DasHostIsolatedEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostIsolatedEvent_value.'> DasHostIsolatedEvent</td>
													</tr>
													<tr>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][HeartbeatDatastoreNotSufficient]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HeartbeatDatastoreNotSufficient_value.'> HeartbeatDatastoreNotSufficient</td>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][HostNoRedundantManagementNetworkEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HostNoRedundantManagementNetworkEvent_value.'> HostNoRedundantManagementNetworkEvent</td>
													</tr>
													<tr>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][InsufficientFailoverResourcesEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_InsufficientFailoverResourcesEvent_value.'> InsufficientFailoverResourcesEvent</td>
														<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][LocalTSMEnabledEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_LocalTSMEnabledEvent_value.'> LocalTSMEnabledEvent</td>
													</tr>
													<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="host_check_options[Host_Status][exclude_issue][RemoteTSMEnabledEvent]['.$h.']" value="'.$h.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_RemoteTSMEnabledEvent_value.'> RemoteTSMEnabledEvent</td><td></td></tr>
												</table>
											</td>
										</tr></table>
									</td>
								</tr>
								';

							/* Get all the hbas and add them to an array */
							$hbas = array();
							foreach ($host_results_decoded['hosts'] as $host) {
								if ($host['host_name'] == $host_checkbox[$h]) {
									foreach ($host['hbas'] as $hba) {
										/* Add them to the array */
										$hbas[$hba['hba_name']] = $hba;
										} /* End foreach ($host['hbas'] as $hba) { */
									} /* End if ($host['host_name'] == $host_checkbox[$h]) { */
								} /* End foreach ($host_results_decoded['hosts'] as $host) { */

							/* Sort the array */
							ksort($hbas);

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Info', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Info', 'check_interval'), $h, $host_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Info', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Info', 'number_retries'), $h, $host_check_options, '3');
							$hba_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Info', 'hba_checkbox', 'all'), $h, $host_check_options, '');
							
							$output_Host_Storage_Adapter_Info .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Info][monitor_me]['.$h.']" value="'.$h.'" class="storage-adapter-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Info][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Info][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Info][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
										<div class="'.$wizard_name.'-spacer5"> </div>
										<b>Select HBA(s) or All</b>
										<div class="'.$wizard_name.'-spacer5"> </div>
										<table class="'.$wizard_name.'-table-align-left">
											<tr><td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Info][hba_checkbox]['.$h.'][all]" value="all"'.$hba_select_value.'></td><td class="'.$wizard_name.'-width5"></td><td class="'.$wizard_name.'-align-left">All</td></tr>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_Storage_Adapter_Info .= '
														<tr><td colspan="3"></td></tr>
														<tr>
															<td colspan="2"></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s HBAs cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the HBAs */
								$hba_counter = 1;
								foreach ($hbas as $hba) {
									if ($hba_counter != 0) {
										if ($hba_counter % 3 === 0) {
											$output_Host_Storage_Adapter_Info .= '</tr><tr>';
											} /* End if ($hba_counter % 3 === 0) { */
										else {
											$output_Host_Storage_Adapter_Info .= '<td class="'.$wizard_name.'-width2"></td>';
											} /* End else { */
										} /* End if ($hba_counter != 0) { */
									$hba_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Info', 'hba_checkbox', $hba['hba_name']), $h, $host_check_options, '');
									$output_Host_Storage_Adapter_Info .= '
										<tr><td rowspan="2" class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Info][hba_checkbox]['.$h.']['.$hba['hba_name'].']" value="'.$hba['hba_name'].'"'.$hba_select_value.'></td><td class="'.$wizard_name.'-width5"></td><td class="'.$wizard_name.'-align-left">'.$hba['hba_name'].'</td></tr>
										<tr><td class="'.$wizard_name.'-width5"></td><td><i>'.$hba['hba_model'].'</i></td></tr>
										';
									$hba_counter++;
									} /* End foreach ($hbas as $hba) { */
								} /* End else { */
							$output_Host_Storage_Adapter_Info .= '
										</table>
									</td>
								</tr>
								';

							
							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'check_interval'), $h, $host_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'retry_interval'), $h, $host_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'number_retries'), $h, $host_check_options, '5');
							$return_as_rate_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Storage_Adapter_Performance', 'reporting_si', 'HBA_Rate'), $h, $host_check_options, 'kBps');
							$return_as_latency_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Storage_Adapter_Performance', 'reporting_si', 'Latency'), $h, $host_check_options, 'ms');
							$rate_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_rate', 'warning_checkbox'), $h, $host_check_options, '');
							$rate_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'hba_rate', 'warning'), $h, $host_check_options, '');
							$rate_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_rate', 'critical_checkbox'), $h, $host_check_options, '');
							$rate_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'hba_rate', 'critical'), $h, $host_check_options, '');
							$latency_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_latency', 'warning_checkbox'), $h, $host_check_options, '');
							$latency_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'hba_latency', 'warning'), $h, $host_check_options, '');
							$latency_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_latency', 'critical_checkbox'), $h, $host_check_options, '');
							$latency_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Storage_Adapter_Performance', 'hba_latency', 'critical'), $h, $host_check_options, '');
							$hba_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_checkbox', 'all'), $h, $host_check_options, '');
							
							$output_Host_Storage_Adapter_Performance .= '
								<tr'.$row_class.'>
									<th class="'.$wizard_name.'-width60">
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= 'Select<br/>Host';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') { */
							$output_Host_Storage_Adapter_Performance .= '
									</th><th class="'.$wizard_name.'-align-left">Host Name</th>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= '<th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th>';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') { */
							else {
								$output_Host_Storage_Adapter_Performance .= '<th colspan="3"></th>';
								} /* End else { */
							$output_Host_Storage_Adapter_Performance .= '
								</tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center">
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= '<input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][monitor_me]['.$h.']" value="'.$h.'" class="storage-adapter-performance-checkbox"'.$monitor_me_checkbox_value.'>';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') { */
							$output_Host_Storage_Adapter_Performance .= '
									</td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= '
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') { */
							else {
								$output_Host_Storage_Adapter_Performance .= '<td colspan="3"></td>';
								} /* End else { */
							$output_Host_Storage_Adapter_Performance .= '
								</tr>

								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
										<div class="'.$wizard_name.'-spacer5"> </div>
										<b>Select HBA(s) or All</b>
										<div class="'.$wizard_name.'-spacer5"> </div>
										<table class="'.$wizard_name.'-table-align-left">
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= '
														<tr><td colspan="3"></td></tr>
														<tr>
															<td colspan="2"></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s HBAs cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the HBAs */
								$hba_counter = 1;
								foreach ($hbas as $hba) {
									if ($hba_counter != 0) {
										if ($hba_counter % 3 === 0) {
											$output_Host_Storage_Adapter_Performance .= '</tr><tr>';
											} /* End if ($hba_counter % 3 === 0) { */
										else {
											$output_Host_Storage_Adapter_Performance .= '<td class="'.$wizard_name.'-width2"></td>';
											} /* End else { */
										} /* End if ($hba_counter != 0) { */
									$hba_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Storage_Adapter_Performance', 'hba_checkbox', $hba['hba_name']), $h, $host_check_options, '');
									$output_Host_Storage_Adapter_Performance .= '
										<tr><td rowspan="2" class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][hba_checkbox]['.$h.']['.$hba['hba_name'].']" value="'.$hba['hba_name'].'"'.$hba_select_value.'></td><td class="'.$wizard_name.'-width5"><td class="'.$wizard_name.'-align-left">'.$hba['hba_name'].'</td></tr>
										<tr><td class="'.$wizard_name.'-width5"><td><i>'.$hba['hba_model'].'</i></td></tr>
										';
									$hba_counter++;
									} /* End foreach ($hbas as $hba) { */
								} /* End else { */
							$output_Host_Storage_Adapter_Performance .= '
										</table>
										<div class="'.$wizard_name.'-spacer5"> </div>
									</td>
								</tr>
								';

							if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') {
								$output_Host_Storage_Adapter_Performance .= '
									<tr'.$row_class.'>
										<td colspan="5">
											<table class="'.$wizard_name.'-table-align-left">
												<tr><th colspan="2">Return As</th></tr>
												<tr>
													<td class="'.$wizard_name.'-align-right">Rate</td>
													<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_Storage_Adapter_Performance][reporting_si][HBA_Rate]['.$h.']" title="Return metric as">
														<option value="Bps"'; if ($return_as_rate_value == 'Bps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Bps</option>
														<option value="kBps"'; if ($return_as_rate_value == 'kBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>kBps</option>
														<option value="MBps"'; if ($return_as_rate_value == 'MBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>MBps</option>
														<option value="GBps"'; if ($return_as_rate_value == 'GBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>GBps</option>
														<option value="TBps"'; if ($return_as_rate_value == 'TBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>TBps</option>
														<option value="PBps"'; if ($return_as_rate_value == 'PBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>PBps</option>
														<option value="EBps"'; if ($return_as_rate_value == 'EBps') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>EBps</option>
													</select></td>
												</tr>
												<tr>
													<td class="'.$wizard_name.'-align-right">Latency</td>
													<td class="'.$wizard_name.'-padding-left-right-10"><select name="host_check_options[Host_Storage_Adapter_Performance][reporting_si][Latency]['.$h.']" title="Return metric as">
														<option value="us"'; if ($return_as_latency_value == 'us') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Microseconds</option>
														<option value="ms"'; if ($return_as_latency_value == 'ms') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Milliseconds</option>
														<option value="s"'; if ($return_as_latency_value == 's') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Seconds</option>
														<option value="m"'; if ($return_as_latency_value == 'm') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Minutes</option>
														<option value="h"'; if ($return_as_latency_value == 'h') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Hours</option>
														<option value="d"'; if ($return_as_latency_value == 'd') $output_Host_Storage_Adapter_Performance .= ' selected'; $output_Host_Storage_Adapter_Performance .= '>Days</option>
													</select></td>
												</tr>
											</table>
											
											<table class="'.$wizard_name.'-table-align-right">
												<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
												<tr>
													<td class="'.$wizard_name.'-align-right">Rate</td>
													<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][hba_rate][warning_checkbox]['.$h.']" value="'.$h.'"'.$rate_warning_checkbox_value.'></td>
													<td><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][hba_rate][warning]['.$h.']" value="'.$rate_warning_value.'" class="'.$wizard_name.'-width50"></td>
													<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][hba_rate][critical_checkbox]['.$h.']" value="'.$h.'"'.$rate_critical_checkbox_value.'></td>
													<td><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][hba_rate][critical]['.$h.']" value="'.$rate_critical_value.'" class="'.$wizard_name.'-width50"></td>
												</tr>
												<tr>
													<td class="'.$wizard_name.'-align-right">Latency Total</td>
													<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][hba_latency][warning_checkbox]['.$h.']" value="'.$h.'"'.$latency_warning_checkbox_value.'></td>
													<td><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][hba_latency][warning]['.$h.']" value="'.$latency_warning_value.'" class="'.$wizard_name.'-width50"></td>
													<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Storage_Adapter_Performance][hba_latency][critical_checkbox]['.$h.']" value="'.$h.'"'.$latency_critical_checkbox_value.'></td>
													<td><input type="text" name="host_check_options[Host_Storage_Adapter_Performance][hba_latency][critical]['.$h.']" value="'.$latency_critical_value.'" class="'.$wizard_name.'-width50"></td>
												</tr>	
												</tr>
											</table>
										</td>
									</tr>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] == 'poweredOn') { */
							

							/* Get all the Switches and add them to an array */
							$switches = array();
							foreach ($host_results_decoded['hosts'] as $host) {
								if ($host['host_name'] == $host_checkbox[$h]) {
									foreach ($host['switches'] as $switch) {
										//print_r($switch['switch_name'] . "<br/>");
										/* Add them to the array */
										$switches[$switch['switch_name']] = $switch;
										} /* End foreach ($host['switches'] as $switch) { */
									} /* End if ($host['host_name'] == $host_checkbox[$h]) { */
								} /* End foreach ($host_results_decoded['hosts'] as $host) { */

							/* Sort the array */
							ksort($switches);

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Switch_Status', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Switch_Status', 'check_interval'), $h, $host_check_options, rand(21, 39));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Switch_Status', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_Switch_Status', 'number_retries'), $h, $host_check_options, '3');
							$mtu_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Switch_Status', 'mtu'), $h, $host_check_options, 'default');
							$nic_state_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Switch_Status', 'nic_state'), $h, $host_check_options, 'connected');
							$nic_duplex_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Switch_Status', 'nic_duplex'), $h, $host_check_options, 'full');
							$nic_speed_value = vmwarevirtualizationwizard_option_check('select', array ('Host_Switch_Status', 'nic_speed'), $h, $host_check_options, 'default');
							$switch_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Switch_Status', 'switch_checkbox', 'all'), $h, $host_check_options, '');

							$output_Host_Switch_Status .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Switch_Status][monitor_me]['.$h.']" value="'.$h.'" class="switch-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Switch_Status][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Switch_Status][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_Switch_Status][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<div class="'.$wizard_name.'-spacer8"> </div>
										<b>Select Switches(s) or All</b>
										<table>
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-left">
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">Switch MTU</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_Switch_Status][mtu]['.$h.']" title="Return metric as">
																<option value="default"'; if ($mtu_value == 'default') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Current Size</option>
																<option value="1500"'; if ($mtu_value == '1500') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>1500</option>
																<option value="9000"'; if ($mtu_value == '9000') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>9000</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">pNIC State</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_Switch_Status][nic_state]['.$h.']" title="Return metric as">
																<option value="connected"'; if ($nic_state_value == 'connected') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Connected</option>
																<option value="disconnected"'; if ($nic_state_value == 'disconnected') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Disconnected</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">pNIC Duplex</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_Switch_Status][nic_duplex]['.$h.']" title="Return metric as">
																<option value="full"'; if ($nic_duplex_value == 'full') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Full</option>
																<option value="half"'; if ($nic_duplex_value == 'half') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Half</option>
															</select></td>
														</tr>
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">pNIC Speed</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_Switch_Status][nic_speed]['.$h.']" title="Return metric as">
																<option value="default"'; if ($nic_speed_value == 'default') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>Connected Speed</option>
																<option value="10"'; if ($nic_speed_value == '10') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>10</option>
																<option value="100"'; if ($nic_speed_value == '100') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>100</option>
																<option value="1000"'; if ($nic_speed_value == '1000') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>1,000</option>
																<option value="40000"'; if ($nic_speed_value == '40000') $output_Host_Switch_Status .= ' selected'; $output_Host_Switch_Status .= '>40,000</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-left">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="host_check_options[Host_Switch_Status][switch_checkbox]['.$h.'][all]" value="all"'.$switch_select_value.'>
															</td>
															<td class="'.$wizard_name.'-width2">
															</td>
															<td class="'.$wizard_name.'-align-left">
																All
															</td>
														</tr>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_Switch_Status .= '
														</tr>
														<tr><td colspan="3"></td></tr>
														<tr>
															<td colspan="2"></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s Switches cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the Switches */
								foreach ($switches as $switch) {
									$switch_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_Switch_Status', 'switch_checkbox', $switch['switch_name']), $h, $host_check_options, '');
									$output_Host_Switch_Status .= '
															<tr><td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_Switch_Status][switch_checkbox]['.$h.']['.$switch['switch_name'].']" value="'.$switch['switch_name'].'"'.$switch_select_value.'></td><td class="'.$wizard_name.'-width2"></td><td class="'.$wizard_name.'-align-left">'.$switch['switch_name'].' (pNICs: <i>
										';
									/* Display the pNICs in the switch */
									$switch_pnic_counter = 0;
									if (count($switch['pnics']) == 0) {
										$output_Host_Switch_Status .= 'None!';
										} /* End if (count($switch['pnics']) == 0) { */
									else {
										foreach ($switch['pnics'] as $pnic) {
											if ($switch_pnic_counter != 0) {
												$output_Host_Switch_Status .= ', ';
												} /* if ($switch_pnic_counter != 0) { */
											$output_Host_Switch_Status .= $pnic['pnic_name'];
											$switch_pnic_counter++;
											} /* End foreach ($switch['pnics'] as $pnic) { */
										} /* End else { */
									$output_Host_Switch_Status .= '</i>)</td></tr>';
									} /* End foreach ($switches as $switch) { */
								} /* End else { */
							$output_Host_Switch_Status .= '
													</table>
												</td>
											</tr>
										</td>
									</table>
								</tr>
								';


							/* Get all the vNICs and add them to an array */
							$vnics = array();
							foreach ($host_results_decoded['hosts'] as $host) {
								if ($host['host_name'] == $host_checkbox[$h]) {
									foreach ($host['vnics'] as $vnic) {
										/* Add them to the array */
										$vnics[$vnic['vnic_name']] = $vnic;
										} /* End foreach ($host['vnics'] as $vnic) { */
									} /* End if ($host['host_name'] == $host_checkbox[$h]) { */
								} /* End foreach ($host_results_decoded['hosts'] as $host) { */

							/* Sort the array */
							ksort($vnics);

							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_vNIC_Status', 'monitor_me'), $h, $host_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_vNIC_Status', 'check_interval'), $h, $host_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Host_vNIC_Status', 'retry_interval'), $h, $host_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Host_vNIC_Status', 'number_retries'), $h, $host_check_options, '3');
							$mtu_value = vmwarevirtualizationwizard_option_check('select', array ('Host_vNIC_Status', 'mtu'), $h, $host_check_options, 'default');
							$vnic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_vNIC_Status', 'vnic_checkbox', 'all'), $h, $host_check_options, '');

							$output_Host_vNIC_Status .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Host</th><th class="'.$wizard_name.'-align-left">Host Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_vNIC_Status][monitor_me]['.$h.']" value="'.$h.'" class="vnic-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$host_checkbox[$h].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_vNIC_Status][check_interval]['.$h.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_vNIC_Status][retry_interval]['.$h.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="host_check_options[Host_vNIC_Status][number_retries]['.$h.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<div class="'.$wizard_name.'-spacer8"> </div>
										<b>Select Virtual Nics(s) or All</b>
										<table>
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-left">
														<tr>
															<td class="'.$wizard_name.'-width70 '.$wizard_name.'-align-right">MTU</td>
															<td class="'.$wizard_name.'-padding-left-right-10 '.$wizard_name.'-align-left"><select name="host_check_options[Host_vNIC_Status][mtu]['.$h.']" title="Return metric as">
																<option value="default"'; if ($mtu_value == 'default') $output_Host_vNIC_Status .= ' selected'; $output_Host_vNIC_Status .= '>Current Size</option>
																<option value="1500"'; if ($mtu_value == '1500') $output_Host_vNIC_Status .= ' selected'; $output_Host_vNIC_Status .= '>1500</option>
																<option value="9000"'; if ($mtu_value == '9000') $output_Host_vNIC_Status .= ' selected'; $output_Host_vNIC_Status .= '>9000</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr><td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_vNIC_Status][vnic_checkbox]['.$h.'][all]" value="all"'.$vnic_select_value.'></td><td class="'.$wizard_name.'-align-left">All</td></tr>
								';
							if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') {
								$output_Host_vNIC_Status .= '
														</tr>
														<tr><td colspan="2"></td></tr>
														<tr>
															<td></td><td class="'.$wizard_name.'-align-left">The host is currently NOT accessible, it\'s vNICs cannot be retrieved.</td>
									';
								} /* End if ($host_results_decoded['hosts'][$h]['host_power_state'] != 'poweredOn') { */
							else {
								/* Display the vNICs */
								foreach ($vnics as $vnic) {
									$vnic_select_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Host_vNIC_Status', 'vnic_checkbox', $vnic['vnic_name']), $h, $host_check_options, '');
									$output_Host_vNIC_Status .= '<tr><td class="'.$wizard_name.'-align-center"><input type="checkbox" name="host_check_options[Host_vNIC_Status][vnic_checkbox]['.$h.']['.$vnic['vnic_name'].']" value="'.$vnic['vnic_name'].'"'.$vnic_select_value.'></td><td class="'.$wizard_name.'-align-left">'.$vnic['vnic_name'].'</td></tr>';
									} /* End foreach ($vnics as $vnic) { */
								} /* End else { */
							$output_Host_vNIC_Status .= '
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>';

							array_push($objects_used, $h);
							$row_flag++;
							} /* End if (isset($host_checkbox[$h])) { */
						} /* End for ($h = 0; $h <= $host_counter; $h++) { */

					$output_Hosts .= '</table>';
					$output_propagate_select_Hosts .= '</select>';
					$output_Host_CPU_Info .= '</table>';
					$output_propagate_select_CPU_Info .= '</select>';
					$output_Host_CPU_Usage .= '</table>';
					$output_propagate_select_CPU_Usage .= '</select>';
					$output_Host_Datastore_Performance .= '</table>';
					$output_propagate_select_Datastore_Performance .= '</select>';
					$output_Host_Guest_Snapshot .= '</table>';
					$output_propagate_select_Guest_Snapshot .= '</select>';
					$output_Host_License_Status .= '</table>';
					$output_propagate_select_License_Status .= '</select>';
					$output_Host_Memory_Usage .= '</table>';
					$output_propagate_select_Memory_Usage .= '</select>';
					$output_Host_OS_Name_Version .= '</table>';
					$output_propagate_select_OS_Name_Version .= '</select>';
					$output_Host_pNIC_Status .= '</table>';
					$output_propagate_select_pNIC_Status .= '</select>';
					$output_Host_pNIC_Usage .= '</table>';
					$output_propagate_select_pNIC_Usage .= '</select>';
					$output_Host_Status .= '</table>';
					$output_propagate_select_Status .= '</select>';
					$output_Host_Storage_Adapter_Info .= '</table>';
					$output_propagate_select_Storage_Adapter_Info .= '</select>';
					$output_Host_Storage_Adapter_Performance .= '</table>';
					$output_propagate_select_Storage_Adapter_Performance .= '</select>';
					$output_Host_Switch_Status .= '</table>';
					$output_propagate_select_Switch_Status .= '</select>';
					$output_Host_vNIC_Status .= '</table>';
					$output_propagate_select_vNIC_Status .= '</select>';
					$output .= '
						<h1>Host Checks</h1>
						<input type="hidden" name="objects_used" id="id_objects_used" value="'.json_encode($objects_used).'">

						<div id="'.$wizard_name.'-menubar" class="'.$wizard_name.'-width650">
							<input type="button" class="'.$wizard_name.'-menuheading2" id="id-'.$wizard_name.'-Hosts" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Hosts\')" value="Hosts">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-CPU" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-CPU\')" value="CPU">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Datastore" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Datastore\')" value="Datastore">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Guest-Snapshot" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Guest-Snapshot\')" value="Guest Snapshots">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-License" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-License\')" value="License">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Memory" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Memory\')" value="Memory">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-OS" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-OS\')" value="OS">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-pNIC" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-pNIC\')" value="Physical NIC">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Status" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Status\')" value="Status">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-HBA" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-HBA\')" value="Storage Adapter">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Switch" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Switch\')" value="Switch">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-vNIC" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-vNIC\')" value="Virtual NIC">
						</div>
						

						<div id="'.$wizard_name.'-Hosts" class="'.$wizard_name.'-togglediv">
							<div class="sectionTitle">Nagios Host Object Settings</div>
						';
					if ($hosts_new == 1) {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							On the previous screen, you selected to create NEW Nagios Host objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Here you can defined the individual check settings for each of the NEW hosts.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Hosts.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Hosts,[check_interval]:text~[retry_interval]:text~[number_retries]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max"></td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Hosts][check_interval][min]" value="3" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Hosts][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Hosts,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Hosts.'
							';
						} /* End if ($hosts_new == 1) { */
					else {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							All the hosts you have selected to monitor already have existing Nagios HOST objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Hence there are no settings to define on this tab.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<div class="'.$wizard_name.'-spacer20"> </div>
							';
						} /* End else { */
					$output .= '
						</div>


						<div id="'.$wizard_name.'-CPU" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">CPU Info</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_CPU_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_CPU_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="cpu_info_checkbox_all" id="id_cpu_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_cpu_info_checkbox_all:cpu-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_CPU_Info][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_CPU_Info][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_CPU_Info,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_CPU_Info.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">CPU Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_CPU_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_CPU_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select~[cpu_free][warning_checkbox]:checkbox~[cpu_free][warning]:text~[cpu_free][critical_checkbox]:checkbox~[cpu_free][critical]:text~[cpu_used][warning_checkbox]:checkbox~[cpu_used][warning]:text~[cpu_used][critical_checkbox]:checkbox~[cpu_used][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="cpu_usage_checkbox_all" id="id_cpu_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_cpu_usage_checkbox_all:cpu-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_CPU_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_CPU_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_CPU_Usage,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_CPU_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Datastore" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Datastore Performance</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Datastore_Performance.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Datastore_Performance,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Datastore_Rate]:select~[reporting_si][Latency]:select~[datastore_rate][warning_checkbox]:checkbox~[datastore_rate][warning]:text~[datastore_rate][critical_checkbox]:checkbox~[datastore_rate][critical]:text~[datastore_latency][warning_checkbox]:checkbox~[datastore_latency][warning]:text~[datastore_latency][critical_checkbox]:checkbox~[datastore_latency][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="datastore_performance_checkbox_all" id="id_datastore_performance_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_datastore_performance_checkbox_all:datastore-performance-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Datastore_Performance][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Datastore_Performance][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Datastore_Performance,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Datastore_Performance.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Guest-Snapshot" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Guest Snapshots</div>
							NOTE: It\'s better to add a Datacenter/Cluster wide check for this as it will find ALL Guests.
							<div class="'.$wizard_name.'-spacer5"> </div>
							This results in just one service definition instead of a definition for each host!
							<div class="'.$wizard_name.'-spacer15"> </div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Guest_Snapshot.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Guest_Snapshot,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[snapshot_age][warning_checkbox]:checkbox~[snapshot_age][warning]:text~[snapshot_age][critical_checkbox]:checkbox~[snapshot_age][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="guest_snapshot_checkbox_all" id="id_guest_snapshot_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_guest_snapshot_checkbox_all:guest-snapshot-checkbox\')">Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Snapshot][check_interval][min]" value="600" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Guest_Snapshot][check_interval][max]" value="800" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Guest_Snapshot,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Guest_Snapshot.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-License" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">License Status</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_License_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_License_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[hide_key]:checkbox\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="license_status_checkbox_all" id="id_license_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_license_status_checkbox_all:license-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_License_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_License_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_License_Status,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_License_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Memory" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Memory Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Memory_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Memory_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Memory_Size]:select~[memory_free][warning_checkbox]:checkbox~[memory_free][warning]:text~[memory_free][critical_checkbox]:checkbox~[memory_free][critical]:text~[memory_used][warning_checkbox]:checkbox~[memory_used][warning]:text~[memory_used][critical_checkbox]:checkbox~[memory_used][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="memory_usage_checkbox_all" id="id_memory_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_memory_usage_checkbox_all:memory-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Memory_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Memory_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Memory_Usage,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Memory_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-OS" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Operating System Name and Version</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_OS_Name_Version.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_OS_Name_Version,[check_interval]:text~[retry_interval]:text~[number_retries]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="os_name_version_checkbox_all" id="id_os_name_version_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_os_name_version_checkbox_all:os-name-version-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_OS_Name_Version][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_OS_Name_Version][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_OS_Name_Version,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_OS_Name_Version.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-pNIC" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Physical NIC Status</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_pNIC_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_pNIC_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[nic_state]:select~[nic_duplex]:select~[nic_speed]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="pnic_status_checkbox_all" id="id_pnic_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_pnic_status_checkbox_all:pnic-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_pNIC_Status][check_interval][min]" value="21" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_pNIC_Status][check_interval][max]" value="39" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_pNIC_Status,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_pNIC_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">Physical NIC Usage</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_pNIC_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_pNIC_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][NIC_Rate]:select~[nic_rate][warning_checkbox]:checkbox~[nic_rate][warning]:text~[nic_rate][critical_checkbox]:checkbox~[nic_rate][critical]:text~[packet_errors][warning_checkbox]:checkbox~[packet_errors][warning]:text~[packet_errors][critical_checkbox]:checkbox~[packet_errors][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="pnic_usage_checkbox_all" id="id_pnic_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_pnic_usage_checkbox_all:pnic-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_pNIC_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_pNIC_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_pNIC_Usage,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_pNIC_Usage.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Status" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Status</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[exclude_issue_checkbox]:checkbox~[exclude_issue][ClusterOvercommittedEvent]:checkbox~[exclude_issue][DasClusterIsolatedEvent]:checkbox~[exclude_issue][DasHostFailedEvent]:checkbox~[exclude_issue][DasHostIsolatedEvent]:checkbox~[exclude_issue][HeartbeatDatastoreNotSufficient]:checkbox~[exclude_issue][HostNoRedundantManagementNetworkEvent]:checkbox~[exclude_issue][InsufficientFailoverResourcesEvent]:checkbox~[exclude_issue][LocalTSMEnabledEvent]:checkbox~[exclude_issue][RemoteTSMEnabledEvent]:checkbox\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="status_checkbox_all" id="id_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_status_checkbox_all:status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Status][check_interval][min]" value="6" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Status][check_interval][max]" value="11" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Status,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-HBA" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Storage Adapter Info</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Storage_Adapter_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Storage_Adapter_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="storage_adapter_info_checkbox_all" id="id_storage_adapter_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_storage_adapter_info_checkbox_all:storage-adapter-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Storage_Adapter_Info][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Storage_Adapter_Info][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Storage_Adapter_Info,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Storage_Adapter_Info.'
							<div class="'.$wizard_name.'-spacer15"> </div>


							<div class="sectionTitle">Storage Adapter Performance</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Storage_Adapter_Performance.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Storage_Adapter_Performance,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][HBA_Rate]:select~[reporting_si][Latency]:select~[hba_rate][warning_checkbox]:checkbox~[hba_rate][warning]:text~[hba_rate][critical_checkbox]:checkbox~[hba_rate][critical]:text~[hba_latency][warning_checkbox]:checkbox~[hba_latency][warning]:text~[hba_latency][critical_checkbox]:checkbox~[hba_latency][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="storage_adapter_performance_checkbox_all" id="id_storage_adapter_performance_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_storage_adapter_performance_checkbox_all:storage-adapter-performance-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Storage_Adapter_Performance][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Storage_Adapter_Performance][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Storage_Adapter_Performance,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Storage_Adapter_Performance.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Switch" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Switch Status</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_Switch_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_Switch_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[mtu]:select~[nic_state]:select~[nic_duplex]:select~[nic_speed]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="switch_status_checkbox_all" id="id_switch_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_switch_status_checkbox_all:switch-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Switch_Status][check_interval][min]" value="21" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_Switch_Status][check_interval][max]" value="39" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_Switch_Status,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_Switch_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-vNIC" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Virtual NIC Status</div>
							<table class="'.$wizard_name.'-table '.$wizard_name.'-width500">
								<tr><td>'.$output_propagate_select_vNIC_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Host whose options you want to propagate to all other Hosts</td></tr>
								<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'host_check_options:Host_vNIC_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[mtu]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
								<tr>
									<td colspan="2" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table">
											<tr>
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<input type="checkbox" name="vnic_status_checkbox_all" id="id_vnic_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_vnic_status_checkbox_all:vnic-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Hosts
															</td>
														</tr>
													</table>
												</td>
			
												<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
													<table class="'.$wizard_name.'-table">
														<tr>
															<td class="'.$wizard_name.'-align-center">Min</td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_vNIC_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Host_vNIC_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center">Max</td>
														</tr>
														<tr>
															<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Host_vNIC_Status,host_check_options\')" value="Randomize Check Interval"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								<tr>
							</table>
							<div class="'.$wizard_name.'-spacer10"> </div>
							'.$output_Host_vNIC_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>
						';
					break; /* End case 'host': */


				case 'vcenter':
					/* Define some variables */
					$output_VMware_Host = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_Cluster_CPU_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_propagate_select_CPU_Usage = '<select name="propagate_options_Cluster_CPU_Usage" id="id_propagate_options_Cluster_CPU_Usage" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_DRS_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_propagate_select_DRS_Status = '<select name="propagate_options_Cluster_DRS_Status" id="id_propagate_options_Cluster_DRS_Status" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_EVC_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_EVC_Status = '<select name="propagate_options_Cluster_EVC_Status" id="id_propagate_options_Cluster_EVC_Status" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_HA_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_propagate_select_HA_Status = '<select name="propagate_options_Cluster_HA_Status" id="id_propagate_options_Cluster_HA_Status" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_Memory_Usage = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_propagate_select_Memory_Usage = '<select name="propagate_options_Cluster_Memory_Usage" id="id_propagate_options_Cluster_Memory_Usage" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_Resource_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_propagate_select_Resource_Info = '<select name="propagate_options_Cluster_Resource_Info" id="id_propagate_options_Cluster_Resource_Info" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_Swapfile_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_Swapfile_Status = '<select name="propagate_options_Cluster_Swapfile_Status" id="id_propagate_options_Cluster_Swapfile_Status" title="Select Cluster to Propagate Common Options">';
					$output_Cluster_vMotion_Info = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550"><tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>';
					$output_propagate_select_vMotion_Info = '<select name="propagate_options_Cluster_vMotion_Info" id="id_propagate_options_Cluster_vMotion_Info" title="Select Cluster to Propagate Common Options">';
					$output_Guest_Snapshot = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_vCenter_License_Status = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					$output_vCenter_Name_Version = '<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">';
					
					/* Now loop through to find the vCenter cluster objects selected to monitor */
					$cluster_flag = 0;
					$cluster_drs_flag = 0;
					$cluster_ha_flag = 0;
					$row_flag = 0;
					$vmware_host_new = 0;

					if ($nagios_object[0] == 'new') {
						$vmware_host_new = 1;
						
						$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('VMware_Host', 'check_interval'), 0, $vcenter_check_options, '5');
						$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('VMware_Host', 'retry_interval'), 0, $vcenter_check_options, '2');
						$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('VMware_Host', 'number_retries'), 0, $vcenter_check_options, '5');
						
						$output_VMware_Host .= '
							<tr class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top">
								<td class="'.$wizard_name.'-align-right">
									Nagios Object Name:<br/>
									Nagios Object Address:
								</td>
								<td class="'.$wizard_name.'-padding-left-right-10">
									<b>'.$nagios_object_new_name[0].'</b><br/>
									<b>'.$nagios_object_new_address[0].'</b>
								</td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[VMware_Host][check_interval][0]" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[VMware_Host][retry_interval][0]" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
								<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[VMware_Host][number_retries][0]" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
							</tr>
							';
						} /* End if ($nagios_object[0] == 'new') { */
					

					/* Starting at 1 because 0 is the vCenter server object itself */
					for ($v = 1; $v <= $vcenter_counter; $v++) {
						/* Was this cluster selected? */
						if (isset($vcenter_checkbox[$v])) {
							/* Cluster selected, now to create the different check lists */
							$cluster_flag = 1;

							$select_option = '<option value="'.$v.'">'.$vcenter_checkbox[$v].'</option>';
							$output_propagate_select_CPU_Usage .= $select_option;
							$output_propagate_select_EVC_Status .= $select_option;
							$output_propagate_select_Memory_Usage .= $select_option;
							$output_propagate_select_Resource_Info .= $select_option;
							$output_propagate_select_Swapfile_Status .= $select_option;
							$output_propagate_select_vMotion_Info .= $select_option;
							
							$row_class = ($row_flag % 2 == 0) ? ' class="'.$wizard_name.'-table-row-lightgray '.$wizard_name.'-table-row-padding-top"' : ' class="'.$wizard_name.'-table-row-silver '.$wizard_name.'-table-row-padding-top"';
	
							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_CPU_Usage', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'check_interval'), $v, $vcenter_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'retry_interval'), $v, $vcenter_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'number_retries'), $v, $vcenter_check_options, '5');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_CPU_Usage', 'reporting_si', 'CPU_Speed'), $v, $vcenter_check_options, 'GHz');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_CPU_Usage', 'cpu_free', 'warning_checkbox'), $v, $vcenter_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'cpu_free', 'warning'), $v, $vcenter_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_CPU_Usage', 'cpu_free', 'critical_checkbox'), $v, $vcenter_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'cpu_free', 'critical'), $v, $vcenter_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_CPU_Usage', 'cpu_used', 'warning_checkbox'), $v, $vcenter_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'cpu_used', 'warning'), $v, $vcenter_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_CPU_Usage', 'cpu_used', 'critical_checkbox'), $v, $vcenter_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_CPU_Usage', 'cpu_used', 'critical'), $v, $vcenter_check_options, '');

							$output_Cluster_CPU_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_CPU_Usage][monitor_me]['.$v.']" value="'.$v.'" class="cpu-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2" class="'.$wizard_name.'-align-center">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-right">CPU</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_CPU_Usage][reporting_si][CPU_Speed]['.$v.']" title="Return metric as">
																<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Cluster_CPU_Usage .= ' selected'; $output_Cluster_CPU_Usage .= '>Hz</option>
																<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Cluster_CPU_Usage .= ' selected'; $output_Cluster_CPU_Usage .= '>kHz</option>
																<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Cluster_CPU_Usage .= ' selected'; $output_Cluster_CPU_Usage .= '>MHz</option>
																<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Cluster_CPU_Usage .= ' selected'; $output_Cluster_CPU_Usage .= '>GHz</option>
																<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Cluster_CPU_Usage .= ' selected'; $output_Cluster_CPU_Usage .= '>THz</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20">
									
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td>Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_CPU_Usage][cpu_free][warning_checkbox]['.$v.']" value="'.$v.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][cpu_free][warning]['.$v.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_CPU_Usage][cpu_free][critical_checkbox]['.$v.']" value="'.$v.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][cpu_free][critical]['.$v.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td>Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_CPU_Usage][cpu_used][warning_checkbox]['.$v.']" value="'.$v.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][cpu_used][warning]['.$v.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_CPU_Usage][cpu_used][critical_checkbox]['.$v.']" value="'.$v.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_CPU_Usage][cpu_used][critical]['.$v.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';


							foreach ($vcenter_results_decoded['clusters'] as $cluster) {
								if ($cluster['cluster_name'] == $vcenter_checkbox[$v]) {
									if ($cluster['cluster_drs'] == 'Yes') {
										$cluster_drs_flag = 1;

										$output_propagate_select_DRS_Status .= $select_option;
							
										$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'monitor_me'), $v, $vcenter_check_options, '');
										$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_DRS_Status', 'check_interval'), $v, $vcenter_check_options, rand(1380, 1500));
										$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_DRS_Status', 'retry_interval'), $v, $vcenter_check_options, '20');
										$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_DRS_Status', 'number_retries'), $v, $vcenter_check_options, '3');
										$drs_state_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_DRS_Status', 'drs_state'), $v, $vcenter_check_options, 'enabled');
										$drs_automation_level_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_DRS_Status', 'drs_automation_level'), $v, $vcenter_check_options, 'fullyAutomated');
										$drs_dpm_level_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_DRS_Status', 'drs_dpm_level'), $v, $vcenter_check_options, 'off');
										$exclude_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue_checkbox'), $v, $vcenter_check_options, '');
										$exclude_issue_ClusterOvercommittedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'ClusterOvercommittedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasClusterIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'DasClusterIsolatedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasHostFailedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'DasHostFailedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasHostIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'DasHostIsolatedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_HeartbeatDatastoreNotSufficient_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'HeartbeatDatastoreNotSufficient'), $v, $vcenter_check_options, '');
										$exclude_issue_HostNoRedundantManagementNetworkEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'HostNoRedundantManagementNetworkEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_InsufficientFailoverResourcesEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'InsufficientFailoverResourcesEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_LocalTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'LocalTSMEnabledEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_RemoteTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_DRS_Status', 'exclude_issue', 'RemoteTSMEnabledEvent'), $v, $vcenter_check_options, '');
										
										$output_Cluster_DRS_Status .= '
											<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
											<tr'.$row_class.'>
												<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][monitor_me]['.$v.']" value="'.$v.'" class="drs-status-checkbox"'.$monitor_me_checkbox_value.'></td>
												<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
												<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_DRS_Status][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
												<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_DRS_Status][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
												<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_DRS_Status][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
											</tr>
											<tr'.$row_class.'>
												<td colspan="5" class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<table>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70">State</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_DRS_Status][drs_state]['.$v.']" title="Check DRS State">
																			<option value="enabled"'; if ($drs_state_value == 'enabled') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Enabled</option>
																			<option value="disabled"'; if ($drs_state_value == 'disabled') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Disabled</option>
																		</select></td>
																	</tr>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70">Automation Level</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_DRS_Status][drs_automation_level]['.$v.']" title="Check DRS Automation Level">
																			<option value="manual"'; if ($drs_automation_level_value == 'manual') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Manual</option>
																			<option value="partiallyAutomated"'; if ($drs_automation_level_value == 'partiallyAutomated') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Partially Automated</option>
																			<option value="fullyAutomated"'; if ($drs_automation_level_value == 'fullyAutomated') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Fully Automated</option>
																		</select></td>
																	</tr>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70">Power Management (DPM) Level</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_DRS_Status][drs_dpm_level]['.$v.']" title="Check Power Management (DPM)">
																			<option value="off"'; if ($drs_dpm_level_value == 'off') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Off</option>
																			<option value="manual"'; if ($drs_dpm_level_value == 'manual') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Manual</option>
																			<option value="automated"'; if ($drs_dpm_level_value == 'automated') $output_Cluster_DRS_Status .= ' selected'; $output_Cluster_DRS_Status .= '>Automated</option>
																		</select></td>
																	</tr>
																</table>
															</td>

															<td class="'.$wizard_name.'-width10""></td>

															<td class="'.$wizard_name.'-align-center">
																<table class="'.$wizard_name.'-border-dotted">
																	<tr><td class="'.$wizard_name.'-align-center '.$wizard_name.'-border-bottom-dotted"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue_checkbox]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_checkbox_value.'> Exclude Issue If Detected</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][ClusterOvercommittedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_ClusterOvercommittedEvent_value.'> ClusterOvercommittedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][DasClusterIsolatedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasClusterIsolatedEvent_value.'> DasClusterIsolatedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][DasHostFailedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostFailedEvent_value.'> DasHostFailedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][DasHostIsolatedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostIsolatedEvent_value.'> DasHostIsolatedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][HeartbeatDatastoreNotSufficient]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HeartbeatDatastoreNotSufficient_value.'> HeartbeatDatastoreNotSufficient</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][HostNoRedundantManagementNetworkEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HostNoRedundantManagementNetworkEvent_value.'> HostNoRedundantManagementNetworkEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][InsufficientFailoverResourcesEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_InsufficientFailoverResourcesEvent_value.'> InsufficientFailoverResourcesEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][LocalTSMEnabledEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_LocalTSMEnabledEvent_value.'> LocalTSMEnabledEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_DRS_Status][exclude_issue][RemoteTSMEnabledEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_RemoteTSMEnabledEvent_value.'> RemoteTSMEnabledEvent</td></tr>
																</table>
															</td>
														</tr>
													</table>
												</td>
											</tr>
											';
										} /* End if ($cluster['cluster_drs'] == 'Yes') { */
									} /* End if ($cluster['cluster_name'] == $vcenter_checkbox[$v]) { */
								} /* End foreach ($vcenter_results_decoded['clusters'] as $cluster) { */


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_EVC_Status', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_EVC_Status', 'check_interval'), $v, $vcenter_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_EVC_Status', 'retry_interval'), $v, $vcenter_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_EVC_Status', 'number_retries'), $v, $vcenter_check_options, '3');
							$evc_mode_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_EVC_Status', 'evc_mode'), $v, $vcenter_check_options, 'default');

							$output_Cluster_EVC_Status .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_EVC_Status][monitor_me]['.$v.']" value="'.$v.'" class="evc-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_EVC_Status][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_EVC_Status][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_EVC_Status][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
									<table class="'.$wizard_name.'-table-align-left">
										<tr>
											<td>EVC Mode</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_EVC_Status][evc_mode]['.$v.']" title="Check EVC Mode">
												<option value="default"'; if ($evc_mode_value == 'default') $output_Cluster_EVC_Status .= ' selected'; $output_Cluster_EVC_Status .= '>Do not check</option>
												<option value="enabled"'; if ($evc_mode_value == 'enabled') $output_Cluster_EVC_Status .= ' selected'; $output_Cluster_EVC_Status .= '>Enabled</option>
												<option value="disabled"'; if ($evc_mode_value == 'disabled') $output_Cluster_EVC_Status .= ' selected'; $output_Cluster_EVC_Status .= '>Disabled</option>
											</select></td>
										</tr>
									</table>
									</td>
								</tr>
								';

							foreach ($vcenter_results_decoded['clusters'] as $cluster) {
								if ($cluster['cluster_name'] == $vcenter_checkbox[$v]) {
									if ($cluster['cluster_ha'] == 'Yes') {
										$cluster_ha_flag = 1;

										$output_propagate_select_HA_Status .= $select_option;

										$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'monitor_me'), $v, $vcenter_check_options, '');
										$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_HA_Status', 'check_interval'), $v, $vcenter_check_options, rand(1380, 1500));
										$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_HA_Status', 'retry_interval'), $v, $vcenter_check_options, '20');
										$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_HA_Status', 'number_retries'), $v, $vcenter_check_options, '3');
										$ha_state_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_HA_Status', 'ha_state'), $v, $vcenter_check_options, 'enabled');
										$ha_host_monitoring_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_HA_Status', 'ha_host_monitoring'), $v, $vcenter_check_options, 'enabled');
										$ha_admission_control_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_HA_Status', 'ha_admission_control'), $v, $vcenter_check_options, 'enabled');
										$exclude_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue_checkbox'), $v, $vcenter_check_options, '');
										$exclude_issue_ClusterOvercommittedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'ClusterOvercommittedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasClusterIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'DasClusterIsolatedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasHostFailedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'DasHostFailedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_DasHostIsolatedEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'DasHostIsolatedEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_HeartbeatDatastoreNotSufficient_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'HeartbeatDatastoreNotSufficient'), $v, $vcenter_check_options, '');
										$exclude_issue_HostNoRedundantManagementNetworkEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'HostNoRedundantManagementNetworkEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_InsufficientFailoverResourcesEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'InsufficientFailoverResourcesEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_LocalTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'LocalTSMEnabledEvent'), $v, $vcenter_check_options, '');
										$exclude_issue_RemoteTSMEnabledEvent_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_HA_Status', 'exclude_issue', 'RemoteTSMEnabledEvent'), $v, $vcenter_check_options, '');
										
										$output_Cluster_HA_Status .= '
											<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
											<tr'.$row_class.'>
												<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][monitor_me]['.$v.']" value="'.$v.'" class="ha-status-checkbox"'.$monitor_me_checkbox_value.'></td>
												<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
												<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_HA_Status][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
												<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_HA_Status][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
												<td class="'.$wizard_name.'-align-center"v><input type="text" name="vcenter_check_options[Cluster_HA_Status][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
											</tr>
											<tr'.$row_class.'>
												<td colspan="5" class="'.$wizard_name.'-align-center">
													<table class="'.$wizard_name.'-table-align-right">
														<tr>
															<td class="'.$wizard_name.'-align-center">
																<table>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70"">State</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_HA_Status][ha_state]['.$v.']" title="Check HA State">
																			<option value="enabled"'; if ($ha_state_value == 'enabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Enabled</option>
																			<option value="disabled"'; if ($ha_state_value == 'disabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Disabled</option>
																		</select></td>
																	</tr>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70"">Host Monitoring</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_HA_Status][ha_host_monitoring]['.$v.']" title="Check HA Host Monitoring">
																			<option value="enabled"'; if ($ha_host_monitoring_value == 'enabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Enabled</option>
																			<option value="disabled"'; if ($ha_host_monitoring_value == 'disabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Disabled</option>
																		</select></td>
																	</tr>
																	<tr>
																		<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width70"">Admission Control</td>
																		<td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_HA_Status][ha_admission_control]['.$v.']" title="Check HA Adminission Control">
																			<option value="enabled"'; if ($ha_admission_control_value == 'enabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Enabled</option>
																			<option value="disabled"'; if ($ha_admission_control_value == 'disabled') $output_Cluster_HA_Status .= ' selected'; $output_Cluster_HA_Status .= '>Disabled</option>
																		</select></td>
																	</tr>
																</table>
															</td>

															<td class="'.$wizard_name.'-width70""></td>

															<td>
																<table class="'.$wizard_name.'-border-dotted">
																	<tr><td class="'.$wizard_name.'-align-center '.$wizard_name.'-border-bottom-dotted"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue_checkbox]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_checkbox_value.'> Exclude Issue If Detected</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][ClusterOvercommittedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_ClusterOvercommittedEvent_value.'> ClusterOvercommittedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][DasClusterIsolatedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasClusterIsolatedEvent_value.'> DasClusterIsolatedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][DasHostFailedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostFailedEvent_value.'> DasHostFailedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][DasHostIsolatedEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_DasHostIsolatedEvent_value.'> DasHostIsolatedEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][HeartbeatDatastoreNotSufficient]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HeartbeatDatastoreNotSufficient_value.'> HeartbeatDatastoreNotSufficient</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][HostNoRedundantManagementNetworkEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_HostNoRedundantManagementNetworkEvent_value.'> HostNoRedundantManagementNetworkEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][InsufficientFailoverResourcesEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_InsufficientFailoverResourcesEvent_value.'> InsufficientFailoverResourcesEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][LocalTSMEnabledEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_LocalTSMEnabledEvent_value.'> LocalTSMEnabledEvent</td></tr>
																	<tr><td class="'.$wizard_name.'-align-left '.$wizard_name.'-padding-none '.$wizard_name.'-padding-left-right-10"><input type="checkbox" name="vcenter_check_options[Cluster_HA_Status][exclude_issue][RemoteTSMEnabledEvent]['.$v.']" value="'.$v.'" class="'.$wizard_name.'-align-center"'.$exclude_issue_RemoteTSMEnabledEvent_value.'> RemoteTSMEnabledEvent</td></tr>
																</table>
															</td>
														</tr>
													</table>
												</td>
											</tr>
											';
										} /* End if ($cluster['cluster_ha'] == 'Yes') { */
									} /* End if ($cluster['cluster_name'] == $vcenter_checkbox[$v]) { */
								} /* End foreach ($vcenter_results_decoded['clusters'] as $cluster) { */


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Memory_Usage', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'check_interval'), $v, $vcenter_check_options, '5');
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'retry_interval'), $v, $vcenter_check_options, '2');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'number_retries'), $v, $vcenter_check_options, '5');
							$return_as_size_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_Memory_Usage', 'reporting_si', 'Memory_Size'), $v, $vcenter_check_options, 'GB');
							$free_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Memory_Usage', 'memory_free', 'warning_checkbox'), $v, $vcenter_check_options, '');
							$free_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'memory_free', 'warning'), $v, $vcenter_check_options, '');
							$free_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Memory_Usage', 'memory_free', 'critical_checkbox'), $v, $vcenter_check_options, '');
							$free_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'memory_free', 'critical'), $v, $vcenter_check_options, '');
							$used_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Memory_Usage', 'memory_used', 'warning_checkbox'), $v, $vcenter_check_options, '');
							$used_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'memory_used', 'warning'), $v, $vcenter_check_options, '');
							$used_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Memory_Usage', 'memory_used', 'critical_checkbox'), $v, $vcenter_check_options, '');
							$used_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Memory_Usage', 'memory_used', 'critical'), $v, $vcenter_check_options, '');

							$output_Cluster_Memory_Usage .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Memory_Usage][monitor_me]['.$v.']" value="'.$v.'" class="memory-usage-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td colspan="5" class="'.$wizard_name.'-align-center">
										<table class="'.$wizard_name.'-table-align-right">
											<tr>
												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr><th colspan="2">Return As</th></tr>
														<tr>
															<td class="'.$wizard_name.'-align-center">Size</td>
															<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_Memory_Usage][reporting_si][Memory_Size]['.$v.']" title="Return metric as">
																<option value="B"'; if ($return_as_size_value == 'B') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>B</option>
																<option value="kB"'; if ($return_as_size_value == 'kB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>kB</option>
																<option value="MB"'; if ($return_as_size_value == 'MB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>MB</option>
																<option value="GB"'; if ($return_as_size_value == 'GB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>GB</option>
																<option value="TB"'; if ($return_as_size_value == 'TB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>TB</option>
																<option value="PB"'; if ($return_as_size_value == 'PB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>PB</option>
																<option value="EB"'; if ($return_as_size_value == 'EB') $output_Cluster_Memory_Usage .= ' selected'; $output_Cluster_Memory_Usage .= '>EB</option>
															</select></td>
														</tr>
													</table>
												</td>

												<td class="'.$wizard_name.'-width20">

												<td class="'.$wizard_name.'-align-center">
													<table>
														<tr></th><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
														<tr>
															<td>Free</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Memory_Usage][memory_free][warning_checkbox]['.$v.']" value="'.$v.'"'.$free_warning_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][memory_free][warning]['.$v.']" value="'.$free_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Memory_Usage][memory_free][critical_checkbox]['.$v.']" value="'.$v.'"'.$free_critical_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][memory_free][critical]['.$v.']" value="'.$free_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
														<tr>
															<td>Used</td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Memory_Usage][memory_used][warning_checkbox]['.$v.']" value="'.$v.'"'.$used_warning_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][memory_used][warning]['.$v.']" value="'.$used_warning_value.'" class="'.$wizard_name.'-width50"></td>
															<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Memory_Usage][memory_used][critical_checkbox]['.$v.']" value="'.$v.'"'.$used_critical_checkbox_value.'></td>
															<td><input type="text" name="vcenter_check_options[Cluster_Memory_Usage][memory_used][critical]['.$v.']" value="'.$used_critical_value.'" class="'.$wizard_name.'-width50"></td>
														</tr>
													</table>
												</td>
											</tr>
										</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Resource_Info', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Resource_Info', 'check_interval'), $v, $vcenter_check_options, rand(21, 39));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Resource_Info', 'retry_interval'), $v, $vcenter_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Resource_Info', 'number_retries'), $v, $vcenter_check_options, '3');
							$return_as_cpu_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_Resource_Info', 'reporting_si', 'CPU_Speed'), $v, $vcenter_check_options, 'GHz');
							$return_as_memory_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_Resource_Info', 'reporting_si', 'Memory_Size'), $v, $vcenter_check_options, 'GB');

							$output_Cluster_Resource_Info .= '
								<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Cluster Name</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Resource_Info][monitor_me]['.$v.']" value="'.$v.'" class="resource-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Resource_Info][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Resource_Info][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Resource_Info][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="5">
									<table class="'.$wizard_name.'-table-align-left">
										<tr><th colspan="2">Return As</th><th class="'.$wizard_name.'-width20"><th colspan="2">Return As</th></tr>
										<tr>
											<td class="'.$wizard_name.'-align-center">CPU</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_Resource_Info][reporting_si][CPU_Speed]['.$v.']" title="Return metric as">
												<option value="Hz"'; if ($return_as_cpu_value == 'Hz') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>Hz</option>
												<option value="kHz"'; if ($return_as_cpu_value == 'kHz') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>kHz</option>
												<option value="MHz"'; if ($return_as_cpu_value == 'MHz') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>MHz</option>
												<option value="GHz"'; if ($return_as_cpu_value == 'GHz') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>GHz</option>
												<option value="THz"'; if ($return_as_cpu_value == 'THz') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>THz</option>
											</select></td>
											<td></td>
											<td class="'.$wizard_name.'-align-center">Memory</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_Resource_Info][reporting_si][Memory_Size]['.$v.']" title="Return metric as">
												<option value="B"'; if ($return_as_memory_value == 'B') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>B</option>
												<option value="kB"'; if ($return_as_memory_value == 'kB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>kB</option>
												<option value="MB"'; if ($return_as_memory_value == 'MB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>MB</option>
												<option value="GB"'; if ($return_as_memory_value == 'GB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>GB</option>
												<option value="TB"'; if ($return_as_memory_value == 'TB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>TB</option>
												<option value="PB"'; if ($return_as_memory_value == 'PB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>PB</option>
												<option value="EB"'; if ($return_as_memory_value == 'EB') $output_Cluster_Resource_Info .= ' selected'; $output_Cluster_Resource_Info .= '>EB</option>
											</select></td>
										</tr>
									</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_Swapfile_Status', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Swapfile_Status', 'check_interval'), $v, $vcenter_check_options, rand(1380, 1500));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Swapfile_Status', 'retry_interval'), $v, $vcenter_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_Swapfile_Status', 'number_retries'), $v, $vcenter_check_options, '3');
							$swapfile_status_value = vmwarevirtualizationwizard_option_check('select', array ('Cluster_Swapfile_Status', 'swapfile_policy'), $v, $vcenter_check_options, 'vmDirectory');

							$output_Cluster_Swapfile_Status .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_Swapfile_Status][monitor_me]['.$v.']" value="'.$v.'" class="swapfile-status-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Swapfile_Status][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Swapfile_Status][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_Swapfile_Status][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								<tr'.$row_class.'>
									<td></td>
									<td colspan="4">
									<table class="'.$wizard_name.'-table-align-left">
										<tr>
											<td>Swapfile Status</td>
											<td class="'.$wizard_name.'-padding-left-right-10"><select name="vcenter_check_options[Cluster_Swapfile_Status][swapfile_policy]['.$v.']" title="Check Swapfile Status">
												<option value="vmDirectory"'; if ($swapfile_status_value == 'vmDirectory') $output_Cluster_Swapfile_Status .= ' selected'; $output_Cluster_Swapfile_Status .= '>VM Directory</option>
												<option value="hostLocal"'; if ($swapfile_status_value == 'hostLocal') $output_Cluster_Swapfile_Status .= ' selected'; $output_Cluster_Swapfile_Status .= '>Host Local</option>
											</select></td>
										</tr>
									</table>
									</td>
								</tr>
								';


							$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Cluster_vMotion_Info', 'monitor_me'), $v, $vcenter_check_options, '');
							$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_vMotion_Info', 'check_interval'), $v, $vcenter_check_options, rand(21, 39));
							$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_vMotion_Info', 'retry_interval'), $v, $vcenter_check_options, '20');
							$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Cluster_vMotion_Info', 'number_retries'), $v, $vcenter_check_options, '3');

							$output_Cluster_vMotion_Info .= '
								<tr'.$row_class.'>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Cluster_vMotion_Info][monitor_me]['.$v.']" value="'.$v.'" class="vmotion-info-checkbox"'.$monitor_me_checkbox_value.'></td>
									<td class="'.$wizard_name.'-width250"><b>'.$vcenter_checkbox[$v].'</b></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_vMotion_Info][check_interval]['.$v.']" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_vMotion_Info][retry_interval]['.$v.']" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Cluster_vMotion_Info][number_retries]['.$v.']" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
								';

							array_push($objects_used, $v);
							$row_flag++;
							} /* End if (isset($vcenter_checkbox[$v])) { */
						} /* End for ($v = 0; $v <= $vcenter_counter; $v++) { */

					$output_VMware_Host .= '</table>';
					$output_Cluster_CPU_Usage .= '</table>';
					$output_propagate_select_CPU_Usage .= '</select>';
					$output_Cluster_DRS_Status .= '</table>';
					$output_propagate_select_DRS_Status .= '</select>';
					$output_Cluster_EVC_Status .= '</table>';
					$output_propagate_select_EVC_Status .= '</select>';
					$output_Cluster_HA_Status .= '</table>';
					$output_propagate_select_HA_Status .= '</select>';
					$output_Cluster_Memory_Usage .= '</table>';
					$output_propagate_select_Memory_Usage .= '</select>';
					$output_Cluster_Resource_Info .= '</table>';
					$output_propagate_select_Resource_Info .= '</select>';
					$output_Cluster_Swapfile_Status .= '</table>';
					$output_propagate_select_Swapfile_Status .= '</select>';
					$output_Cluster_vMotion_Info .= '</table>';
					$output_propagate_select_vMotion_Info .= '</select>';
					
					$v = $vcenter_counter + 1;

					$row_class = ' class="'.$wizard_name.'-table-row-lightgray"';
					
					$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'monitor_me'), 0, $vcenter_check_options, '');
					$scope_value = vmwarevirtualizationwizard_option_check('select', array ('Guest_Snapshot', 'target'), 0, $vcenter_check_options, '');
					$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'check_interval'), 0, $vcenter_check_options, rand(600, 800));
					$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'retry_interval'), 0, $vcenter_check_options, '20');
					$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'number_retries'), 0, $vcenter_check_options, '3');
					$age_warning_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'warning_checkbox'), 0, $vcenter_check_options, '');
					$age_warning_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'warning'), 0, $vcenter_check_options, '');
					$age_critical_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('Guest_Snapshot', 'snapshot_age', 'critical_checkbox'), 0, $vcenter_check_options, '');
					$age_critical_value = vmwarevirtualizationwizard_option_check('text', array ('Guest_Snapshot', 'snapshot_age', 'critical'), 0, $vcenter_check_options, '');
					
					$output_Guest_Snapshot .= '
						<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select</th><th class="'.$wizard_name.'-align-left">Guest Scope</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
						<tr'.$row_class.'>
							<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Guest_Snapshot][monitor_me][0]" value="0"'.$monitor_me_checkbox_value.'></td>
							<td class="'.$wizard_name.'-width250">
							<select name="vcenter_check_options[Guest_Snapshot][target][0]" title="Guest Scope">
						';

					foreach ($vcenter_results_decoded['datacenters'] as $datacenter) {
						$output_Guest_Snapshot .= '<option value="datacenter:'.$datacenter['datacenter_name'].'"'; if ($scope_value == 'datacenter:'.$datacenter['datacenter_name']) $output_Guest_Snapshot .= ' selected'; $output_Guest_Snapshot .= '>Datacenter: '.$datacenter['datacenter_name'].'</option>';
						} /* End foreach ($vcenter_results_decoded['datacenters'] as $datacenter) { */

					foreach ($vcenter_results_decoded['clusters'] as $cluster) {
						$output_Guest_Snapshot .= '<option value="cluster:'.$cluster['cluster_name'].'"'; if ($scope_value == 'cluster:'.$cluster['cluster_name']) $output_Guest_Snapshot .= ' selected'; $output_Guest_Snapshot .= '>Cluster: '.$cluster['cluster_name'].'</option>';
						} /* End foreach ($vcenter_results_decoded['clusters'] as $cluster) { */
					

					$output_Guest_Snapshot .= '
							</select>
							</td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Guest_Snapshot][check_interval][0]" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Guest_Snapshot][retry_interval][0]" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[Guest_Snapshot][number_retries][0]" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
						</tr>
						<tr'.$row_class.'>
							<td></td>
							<td colspan="5">
							<table class="'.$wizard_name.'-table-align-right">
								<tr><th></th><th></th><th>Warning</th><th></th><th>Critical</th></tr>
								<tr>
									<td>Snapshot Age (Days)</td>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Guest_Snapshot][snapshot_age][warning_checkbox][0]" value="0"'.$age_warning_checkbox_value.'></td>
									<td><input type="text" name="vcenter_check_options[Guest_Snapshot][snapshot_age][warning][0]" value="'.$age_warning_value.'" class="'.$wizard_name.'-width50"></td>
									<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[Guest_Snapshot][snapshot_age][critical_checkbox][0]" value="0"'.$age_critical_checkbox_value.'></td>
									<td><input type="text" name="vcenter_check_options[Guest_Snapshot][snapshot_age][critical][0]" value="'.$age_critical_value.'" class="'.$wizard_name.'-width50"></td>
								</tr>
							</table>
							</td>
						</tr>
						';
					$v++;
					

					$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('vCenter_License_Status', 'monitor_me'), 0, $vcenter_check_options, '');
					$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_License_Status', 'check_interval'), 0, $vcenter_check_options, rand(1380, 1500));
					$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_License_Status', 'retry_interval'), 0, $vcenter_check_options, '20');
					$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_License_Status', 'number_retries'), 0, $vcenter_check_options, '3');
					$hide_key_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('vCenter_License_Status', 'hide_key'), 0, $vcenter_check_options, '');

					$output_vCenter_License_Status .= '
						<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Guest Scope</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
						<tr'.$row_class.'>
							<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[vCenter_License_Status][monitor_me][0]" value="0"'.$monitor_me_checkbox_value.'></td>
							<td class="'.$wizard_name.'-width250">Report the vCenter Server License Status</td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_License_Status][check_interval][0]" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_License_Status][retry_interval][0]" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_License_Status][number_retries][0]" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
						</tr>
						<tr'.$row_class.'>
							<td></td>
							<td colspan="4">
								<table class="'.$wizard_name.'-table-align-left">
									<tr>
										<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[vCenter_License_Status][hide_key][0]" value="0"'.$hide_key_checkbox_value.'></td>
										<td>Hide License Key</td>										
									</tr>
								</table>
							</td>
						</tr>';
					$v++;
					

					$monitor_me_checkbox_value = vmwarevirtualizationwizard_option_check('checkbox', array ('vCenter_Name_Version', 'monitor_me'), 0, $vcenter_check_options, '');
					$check_interval_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_Name_Version', 'check_interval'), 0, $vcenter_check_options, rand(1380, 1500));
					$retry_interval_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_Name_Version', 'retry_interval'), 0, $vcenter_check_options, '20');
					$number_retries_value = vmwarevirtualizationwizard_option_check('text', array ('vCenter_Name_Version', 'number_retries'), 0, $vcenter_check_options, '3');

					$output_vCenter_Name_Version .= '
						<tr'.$row_class.'><th class="'.$wizard_name.'-width60">Select<br/>Cluster</th><th class="'.$wizard_name.'-align-left">Guest Scope</th><th>Check<br/>Interval</th><th>Retry<br/>Interval</th><th>Number<br/>Retries</th></tr>
						<tr'.$row_class.'>
							<td class="'.$wizard_name.'-align-center"><input type="checkbox" name="vcenter_check_options[vCenter_Name_Version][monitor_me][0]" value="0"'.$monitor_me_checkbox_value.'></td>
							<td class="'.$wizard_name.'-width250">Report the vCenter Server Name & Version</td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_Name_Version][check_interval][0]" value="'.$check_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_Name_Version][retry_interval][0]" value="'.$retry_interval_value.'" class="'.$wizard_name.'-width50"></td>
							<td class="'.$wizard_name.'-align-center"><input type="text" name="vcenter_check_options[vCenter_Name_Version][number_retries][0]" value="'.$number_retries_value.'" class="'.$wizard_name.'-width50"></td>
						</tr>
						';
					
					$output_Guest_Snapshot .= '</table>';
					$output_vCenter_License_Status .= '</table>';
					$output_vCenter_Name_Version .= '</table>';
					
					$output .= '
						<h1>vCenter Checks</h1>
						<input type="hidden" name="objects_used" id="id_objects_used" value="'.json_encode($objects_used).'">

						<div id="'.$wizard_name.'-menubar" class="'.$wizard_name.'-width550">
							<input type="button" class="'.$wizard_name.'-menuheading2" id="id-'.$wizard_name.'-vCenter-Server" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-vCenter-Server\')" value="vCenter Server">
						';
					if ($cluster_flag == 1) {
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-CPU" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-CPU\')" value="CPU">';
						if ($cluster_drs_flag == 1) {
							$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-DRS" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-DRS\')" value="DRS">';
							} /* End if ($cluster_drs_flag == 1) { */
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-EVC" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-EVC\')" value="EVC">';
						if ($cluster_ha_flag == 1) {
							$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-HA" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-HA\')" value="HA">';
							} /* End if ($cluster_ha_flag == 1) { */
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Memory" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Memory\')" value="Memory">';
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Resources" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Resources\')" value="Resources">';
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Swapfile" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Swapfile\')" value="Swapfile">';
						$output .= '<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-vMotion" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-vMotion\')" value="vMotion">';
						} /* End if ($cluster_flag == 1) { */

					$output .= '
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Snapshot" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Snapshot\')" value="Snapshot">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-License" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-License\')" value="License">
							<input type="button" class="'.$wizard_name.'-menuheading1" id="id-'.$wizard_name.'-Version" onclick="'.$wizard_name.'_ToggleMenu(\''.$wizard_name.'-Version\')" value="Version">
						</div>
					

						<div id="'.$wizard_name.'-vCenter-Server" class="'.$wizard_name.'-togglediv">
							<div class="sectionTitle">Nagios Host Object Settings</div>
						';
					if ($vmware_host_new == 1) {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							On the previous screen, you selected to create a NEW Nagios Host object.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Here you can defined the individual check settings for the NEW host.
							<div class="'.$wizard_name.'-spacer20"> </div>
							'.$output_VMware_Host.'
							';
						} /* End if ($vmware_host_new == 1) { */
					else {
						$output .= '
							<div class="'.$wizard_name.'-spacer10"> </div>
							The vCenter Server you have selected already has an existing Nagios HOST objects.
							<div class="'.$wizard_name.'-spacer10"> </div>
							Hence there are no settings to define on this tab.
							<div class="'.$wizard_name.'-spacer20"> </div>
							<div class="'.$wizard_name.'-spacer20"> </div>
							';
						} /* End else { */
					$output .= '
						</div>
						';


					/* Don't show any cluster stuff if it wasn't selected */
					if ($cluster_flag == 1) {
						$output .= '
							<div id="'.$wizard_name.'-CPU" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster CPU Usage</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_CPU_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_CPU_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select~[cpu_free][warning_checkbox]:checkbox~[cpu_free][warning]:text~[cpu_free][critical_checkbox]:checkbox~[cpu_free][critical]:text~[cpu_used][warning_checkbox]:checkbox~[cpu_used][warning]:text~[cpu_used][critical_checkbox]:checkbox~[cpu_used][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="cpu_usage_checkbox_all" id="id_cpu_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_cpu_usage_checkbox_all:cpu-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_CPU_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_CPU_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_CPU_Usage,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_CPU_Usage.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>
							';


						if ($cluster_drs_flag == 1) {
							$output .= '
								<div id="'.$wizard_name.'-DRS" class="'.$wizard_name.'-togglediv" style="display:none">
									<div class="sectionTitle">Cluster Distributed Resource Scheduler (DRS) Status</div>
									<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
										<tr><td>'.$output_propagate_select_DRS_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
										<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_DRS_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[drs_state]:select~[drs_automation_level]:select~[drs_dpm_level]:select~[exclude_issue_checkbox]:checkbox~[exclude_issue][ClusterOvercommittedEvent]:checkbox~[exclude_issue][DasClusterIsolatedEvent]:checkbox~[exclude_issue][DasHostFailedEvent]:checkbox~[exclude_issue][DasHostIsolatedEvent]:checkbox~[exclude_issue][HeartbeatDatastoreNotSufficient]:checkbox~[exclude_issue][HostNoRedundantManagementNetworkEvent]:checkbox~[exclude_issue][InsufficientFailoverResourcesEvent]:checkbox~[exclude_issue][LocalTSMEnabledEvent]:checkbox~[exclude_issue][RemoteTSMEnabledEvent]:checkbox\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
										<tr>
											<td colspan="2" class="'.$wizard_name.'-align-center">
												<table class="'.$wizard_name.'-table">
													<tr>
														<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
															<table class="'.$wizard_name.'-table">
																<tr>
																	<td class="'.$wizard_name.'-align-center">
																		<input type="checkbox" name="drs_status_checkbox_all" id="id_drs_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_drs_status_checkbox_all:drs-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																	</td>
																</tr>
															</table>
														</td>
					
														<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
															<table class="'.$wizard_name.'-table">
																<tr>
																	<td class="'.$wizard_name.'-align-center">Min</td>
																	<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_DRS_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
																	<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_DRS_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
																	<td class="'.$wizard_name.'-align-center">Max</td>
																</tr>
																<tr>
																	<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_DRS_Status,vcenter_check_options\')" value="Randomize Check Interval"></td>
																</tr>
															</table>
														</td>
													</tr>
												</table>
											</td>
										<tr>
									</table>
									<div class="'.$wizard_name.'-spacer10"> </div>
									'.$output_Cluster_DRS_Status.'
									<div class="'.$wizard_name.'-spacer15"> </div>
								</div>
								';
							} /* End if ($cluster_drs_flag == 1) { */


						$output .= '
							<div id="'.$wizard_name.'-EVC" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster Enhanced vMotion Compatibility (EVC) Status</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_EVC_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_EVC_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[evc_mode]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="evc_status_checkbox_all" id="id_evc_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_evc_status_checkbox_all:evc-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_EVC_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_EVC_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_EVC_Status,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_EVC_Status.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>
							';


						if ($cluster_ha_flag == 1) {
							$output .= '
								<div id="'.$wizard_name.'-HA" class="'.$wizard_name.'-togglediv" style="display:none">
									<div class="sectionTitle">Cluster High Availability (HA) Status</div>
									<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
										<tr><td>'.$output_propagate_select_HA_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
										<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_HA_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[ha_state]:select~[ha_host_monitoring]:select~[ha_admission_control]:select~[exclude_issue_checkbox]:checkbox~[exclude_issue][ClusterOvercommittedEvent]:checkbox~[exclude_issue][DasClusterIsolatedEvent]:checkbox~[exclude_issue][DasHostFailedEvent]:checkbox~[exclude_issue][DasHostIsolatedEvent]:checkbox~[exclude_issue][HeartbeatDatastoreNotSufficient]:checkbox~[exclude_issue][HostNoRedundantManagementNetworkEvent]:checkbox~[exclude_issue][InsufficientFailoverResourcesEvent]:checkbox~[exclude_issue][LocalTSMEnabledEvent]:checkbox~[exclude_issue][RemoteTSMEnabledEvent]:checkbox\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
										<tr>
											<td colspan="2" class="'.$wizard_name.'-align-center">
												<table class="'.$wizard_name.'-table">
													<tr>
														<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
															<table class="'.$wizard_name.'-table">
																<tr>
																	<td class="'.$wizard_name.'-align-center">
																		<input type="checkbox" name="ha_status_checkbox_all" id="id_ha_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_ha_status_checkbox_all:ha-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																	</td>
																</tr>
															</table>
														</td>
					
														<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
															<table class="'.$wizard_name.'-table">
																<tr>
																	<td class="'.$wizard_name.'-align-center">Min</td>
																	<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_HA_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
																	<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_HA_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
																	<td class="'.$wizard_name.'-align-center">Max</td>
																</tr>
																<tr>
																	<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_HA_Status,vcenter_check_options\')" value="Randomize Check Interval"></td>
																</tr>
															</table>
														</td>
													</tr>
												</table>
											</td>
										<tr>
									</table>
									<div class="'.$wizard_name.'-spacer10"> </div>
									'.$output_Cluster_HA_Status.'
									<div class="'.$wizard_name.'-spacer15"> </div>
								</div>
								';
							} /* End if ($cluster_ha_flag == 1) { */
						
						$output .= '
							<div id="'.$wizard_name.'-Memory" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster Memory Usage</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_Memory_Usage.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_Memory_Usage,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][Memory_Size]:select~[memory_free][warning_checkbox]:checkbox~[memory_free][warning]:text~[memory_free][critical_checkbox]:checkbox~[memory_free][critical]:text~[memory_used][warning_checkbox]:checkbox~[memory_used][warning]:text~[memory_used][critical_checkbox]:checkbox~[memory_used][critical]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="memory_usage_checkbox_all" id="id_memory_usage_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_memory_usage_checkbox_all:memory-usage-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Memory_Usage][check_interval][min]" value="4" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Memory_Usage][check_interval][max]" value="8" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_Memory_Usage,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_Memory_Usage.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>


							<div id="'.$wizard_name.'-Resources" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster Resource Info</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_Resource_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_Resource_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[reporting_si][CPU_Speed]:select~[reporting_si][Memory_Size]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="resource_info_checkbox_all" id="id_resource_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_resource_info_checkbox_all:resource-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Resource_Info][check_interval][min]" value="21" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Resource_Info][check_interval][max]" value="39" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_Resource_Info,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_Resource_Info.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>
							

							<div id="'.$wizard_name.'-Swapfile" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster Swapfile Status</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_Swapfile_Status.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_Swapfile_Status,[check_interval]:text~[retry_interval]:text~[number_retries]:text~[swapfile_policy]:select\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="swapfile_status_checkbox_all" id="id_swapfile_status_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_swapfile_status_checkbox_all:swapfile-status-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Swapfile_Status][check_interval][min]" value="1380" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_Swapfile_Status][check_interval][max]" value="1500" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_Swapfile_Status,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_Swapfile_Status.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>
							

							<div id="'.$wizard_name.'-vMotion" class="'.$wizard_name.'-togglediv" style="display:none">
								<div class="sectionTitle">Cluster vMotion Info</div>
								<table class="'.$wizard_name.'-table '.$wizard_name.'-width550">
									<tr><td>'.$output_propagate_select_vMotion_Info.'</td><td class="'.$wizard_name.'-padding-left">Select the Cluster whose options you want to propagate to all other Hosts</td></tr>
									<tr><td colspan="2"><input type="button" onclick="'.$wizard_name.'_PropagateCommonOptions(\'vcenter_check_options:Cluster_vMotion_Info,[check_interval]:text~[retry_interval]:text~[number_retries]:text\')" value="Propagate Common Options"> Click the button to Propagate</td></tr>
									<tr>
										<td colspan="2" class="'.$wizard_name.'-align-center">
											<table class="'.$wizard_name.'-table">
												<tr>
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">
																	<input type="checkbox" name="vmotion_info_checkbox_all" id="id_vmotion_info_checkbox_all" value="off" onclick="'.$wizard_name.'_ToggleCheckbox(\'id_vmotion_info_checkbox_all:vmotion-info-checkbox\')" class="'.$wizard_name.'-align-center"> Select All Clusters
																</td>
															</tr>
														</table>
													</td>
				
													<td class="'.$wizard_name.'-align-center '.$wizard_name.'-width-min-max">
														<table class="'.$wizard_name.'-table">
															<tr>
																<td class="'.$wizard_name.'-align-center">Min</td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_vMotion_Info][check_interval][min]" value="21" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center"><input type="text" name="randomizer[Cluster_vMotion_Info][check_interval][max]" value="39" class="'.$wizard_name.'-width50"></td>
																<td class="'.$wizard_name.'-align-center">Max</td>
															</tr>
															<tr>
																<td colspan="4" class="'.$wizard_name.'-align-center"><input type="button" onclick="'.$wizard_name.'_RandomizeCheckInterval(\'Cluster_vMotion_Info,vcenter_check_options\')" value="Randomize Check Interval"></td>
															</tr>
														</table>
													</td>
												</tr>
											</table>
										</td>
									<tr>
								</table>
								<div class="'.$wizard_name.'-spacer10"> </div>
								'.$output_Cluster_vMotion_Info.'
								<div class="'.$wizard_name.'-spacer15"> </div>
							</div>
							';
						} /* End if ($cluster_flag == 1) { */

					$output .= '
						<div id="'.$wizard_name.'-Snapshot" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">Guest Snapshot</div>
							'.$output_Guest_Snapshot.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-License" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">vCenter License Status</div>
							'.$output_vCenter_License_Status.'
							<div class="'.$wizard_name.'-spacer15"> </div>
						</div>


						<div id="'.$wizard_name.'-Version" class="'.$wizard_name.'-togglediv" style="display:none">
							<div class="sectionTitle">vCenter Name & Version</div>
							'.$output_vCenter_Name_Version.'
						</div>
						';
					break; /* End case 'vcenter': */
				} /* End switch ($vmware_check_type) { */

				
			$output .= '
				
				<div class="'.$wizard_name.'-spacer20"> </div>

				<p>
				Click <b>Next</b> to continue.
				</p>
				';
			/* The quote and semicolon ends HTML for CONFIGWIZARD_MODE_GETSTAGE2HTML */ 
			/* $output will be passed back to XI framework and rendered to browser */
			/* The next line ends CONFIGWIZARD_MODE_GETSTAGE2HTML */
			break;

			
		/* Form validation for CONFIGWIZARD_MODE_GETSTAGE2HTML */ 
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />post CONFIGWIZARD_MODE_VALIDATESTAGE2DATA<br />'); 
			//print_r($_POST); 
			//print_r('<br /><br />');
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session CONFIGWIZARD_MODE_VALIDATESTAGE2DATA<br />'); 
			//print_r($_SESSION[$wizard_name]); 
			//print_r('<br /><br />'); 
			
			
			/* This defines $back variable, used for determining if the Back button */
			/* was clicked when the user was on CONFIGWIZARD_MODE_GETSTAGE4HTML */
			$back = htmlentities(grab_array_var($_POST,'backButton',false),ENT_QUOTES); 	
			
			/* If the user came back from CONFIGWIZARD_MODE_GETSTAGE3HTML then we don't need to revalidate and check for errors */
			if ($back) break;	
			
			/* Check For Errors */
			$errors = 0;
			$errmsg = array();
			
			/* Get existing settings and variables that were passed to us */
			$vma_host_select = $_SESSION[$wizard_name]['vma_host_select'];
			$vma_host_object_select = $_SESSION[$wizard_name]['vma_host_object_select'];
			$vma_host_object_type = $_SESSION[$wizard_name]['vma_host_object_type'];
			$vmware_check_type = $_SESSION[$wizard_name]['vmware_check_type'];
			$nagios_object = $_SESSION[$wizard_name]['nagios_object'];
			$nagios_object_existing = $_SESSION[$wizard_name]['nagios_object_existing'];
			$nagios_object_new_name = $_SESSION[$wizard_name]['nagios_object_new_name'];
			$nagios_object_new_address = $_SESSION[$wizard_name]['nagios_object_new_address'];
			
			/* Specific to the vmware_check_type */
			switch ($vmware_check_type) {
				case 'datastores':
					$datastore_results_decoded = $_SESSION[$wizard_name]['datastore_results_decoded'];
					$datastore_checkbox = $_SESSION[$wizard_name]['datastore_checkbox'];
					$datastore_counter = $_SESSION[$wizard_name]['datastore_counter'];
					$datastore_check_options = grab_array_var($inargs,'datastore_check_options',array());

					$datastore_checks = array (
						'Datastore_Usage'			=> 'Datastore Usage',
						);

					/* If this is a NEW Nagios Host Object, check the settings */
					if ($nagios_object[0] == 'new') {
						/* Check the intervals and retries */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'New vCenter Server OR ESX(i) Host', $datastore_checkbox[0], $datastore_check_options['VMware_Host']['check_interval'][0], $datastore_check_options['VMware_Host']['retry_interval'][0], $datastore_check_options['VMware_Host']['number_retries'][0]);
						} /* End if ($nagios_object[0] == 'new') { */
				
					/* Find what datastore objects were selected */
					$datastore_checkbox_flag = 0;
					/* Starting at 1 because the vCenter server is 0 */
					for ($d = 1; $d < $datastore_counter; $d++) {
						/* Loop through each check */
						foreach ($datastore_checks as $check_key => $check_value) {
							/* Test to see if the check was selected */
							if (isset($datastore_check_options[$check_key]['monitor_me'][$d])) {
								/* Check selected, trigger flag */
								$datastore_checkbox_flag = 1;

								/* Now check the relevant options */
								switch ($check_key) {
									case 'Datastore_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $datastore_checkbox[$d], $datastore_check_options[$check_key]['check_interval'][$d], $datastore_check_options[$check_key]['retry_interval'][$d], $datastore_check_options[$check_key]['number_retries'][$d]);

										/* datastore_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $d, $datastore_checkbox[$d], 'CW', 'Datastore Free', 'datastore_free', $datastore_check_options);

										/* datastore_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $d, $datastore_checkbox[$d], 'WC', 'Datastore Used', 'datastore_used', $datastore_check_options);
										break; /* End case 'Datastore_Usage': */
									} /* End switch ($check) { */
								} /* End if (isset($datastore_check_options[$check]['monitor_me'][$d])) { */
							} /* End foreach ($datastore_checks as $check) { */
						} /* End for ($d = 1; $d < $datastore_counter; $d++) { */
					
					/* Were any services selected to be monitored? */
					if ($datastore_checkbox_flag == 0) {
						$errmsg[$errors++] = 'You did not select any Datastores to monitor!';
						} /* End if ($datastore_checkbox_flag == 0) { */
					else {
						/* We will save these to the session variable array for later use */
						$_SESSION[$wizard_name]['datastore_check_options'] = $datastore_check_options;
						} /* End else { */
					break; /* End case 'datastores': */
				

				case 'guests':
					$guest_results_decoded = $_SESSION[$wizard_name]['guest_results_decoded'];
					$guest_checkbox = $_SESSION[$wizard_name]['guest_checkbox'];
					$guest_counter = $_SESSION[$wizard_name]['guest_counter'];
					$guest_check_options = grab_array_var($inargs,'guest_check_options',array());
					
					$guest_checks = array (
						'Guest_CPU_Info'			=> 'CPU Info',
						'Guest_CPU_Usage'			=> 'CPU Usage',
						'Guest_Disk_Performance'	=> 'Disk Performance',
						'Guest_Disk_Usage'			=> 'Disk Usage',
						'Guest_Memory_Info'			=> 'Memory Info',
						'Guest_Memory_Usage'		=> 'Memory Usage',
						'Guest_NIC_Usage'			=> 'NIC Usage',
						'Guest_Snapshot'			=> 'Guest Snapshot'
						);

					/* Find what guest objects were selected */
					$guest_checkbox_flag = 0;
					for ($g = 0; $g < $guest_counter; $g++) {
						/* If this is a NEW Nagios Host Object, check the settings */
						if (isset($guest_checkbox[$g])) {
							if ($nagios_object[$g] == 'new') {
								/* Check the intervals and retries */
								list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'New Guest', $guest_checkbox[$g], $guest_check_options['Guests']['check_interval'][$g], $guest_check_options['Guests']['retry_interval'][$g], $guest_check_options['Guests']['number_retries'][$g]);
								} /* End if ($nagios_object[$g] == 'new') { */
							} /* End if (isset($guest_checkbox[$g])) { */

						/* Loop through each check */
						foreach ($guest_checks as $check_key => $check_value) {
							/* Test to see if the check was selected */
							if (isset($guest_check_options[$check_key]['monitor_me'][$g])) {
								/* Check selected, trigger flag */
								$guest_checkbox_flag = 1;

								/* Now check the relevant options */
								switch ($check_key) {
									case 'Guest_CPU_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* cpu_reservation => Check the warning or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WOC', 'CPU Reservation', 'cpu_reservation', $guest_check_options);

										/* cpu_limit => Check the warning or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WOC', 'CPU Limit', 'cpu_limit', $guest_check_options);
										break; /* End case 'Guest_CPU_Info': */


									case 'Guest_CPU_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* cpu_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'CW', 'CPU Free', 'cpu_free', $guest_check_options);

										/* cpu_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'CPU Used', 'cpu_used', $guest_check_options);
										
										/* cpu_ready_time => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'CPU Ready Time', 'cpu_ready_time', $guest_check_options);
										break; /* End case 'Guest_CPU_Usage': */


									case 'Guest_Disk_Performance':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* disk_rate => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Disk Rate', 'disk_rate', $guest_check_options);

										/* disk_latency => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Disk Latency', 'disk_latency', $guest_check_options);
										break; /* End case 'Guest_Disk_Performance': */


									case 'Guest_Disk_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* disk_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'CW', 'Disk Free', 'disk_free', $guest_check_options);

										/* disk_total => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Disk Total', 'disk_total', $guest_check_options);
										break; /* End case 'Guest_Disk_Usage': */


									case 'Guest_Memory_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* memory_reservation => Check the warning or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WOC', 'Memory Reservation', 'memory_reservation', $guest_check_options);

										/* memory_limit => Check the warning or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WOC', 'Memory Limit', 'memory_limit', $guest_check_options);
										break; /* End case 'Guest_Memory_Info': */


									case 'Guest_Memory_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* memory_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'CW', 'Memory Free', 'memory_free', $guest_check_options);

										/* memory_consumed => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Memory Consumed', 'memory_consumed', $guest_check_options);

										/* memory_ballooned => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Memory Ballooned', 'memory_ballooned', $guest_check_options);

										/* memory_swap_rate => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Memory Swap Rate', 'memory_swap_rate', $guest_check_options);
										break; /* End case 'Guest_Memory_Usage': */


									case 'Guest_NIC_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);
										
										/* nic_rate => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'NIC Rate', 'nic_rate', $guest_check_options);
										break; /* End case 'Guest_NIC_Usage': */


									case 'Guest_Snapshot':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $guest_checkbox[$g], $guest_check_options[$check_key]['check_interval'][$g], $guest_check_options[$check_key]['retry_interval'][$g], $guest_check_options[$check_key]['number_retries'][$g]);

										/* snapshot_age => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $g, $guest_checkbox[$g], 'WC', 'Snapshot Age', 'snapshot_age', $guest_check_options);
										break; /* End case 'Guest_Guest_Snapshot': */
									} /* End switch ($check) { */
								} /* End if (isset($guest_check_options[$check]['monitor_me'][$g])) { */
							} /* End foreach ($guest_checks as $check) { */
						} /* End for ($g = 0; $g < $guest_counter; $g++) { */
					
					/* Were any services selected to be monitored? */
					if ($guest_checkbox_flag == 0) {
						$errmsg[$errors++] = 'You did not select any Guest Objects to monitor!';
						} /* End if ($guest_checkbox_flag == 0) { */
					else {
						/* We will save these to the session variable array for later use */
						$_SESSION[$wizard_name]['guest_check_options'] = $guest_check_options;
						} /* End else { */
					break; /* End case 'guests': */
				

				case 'host':
					$host_results_decoded = $_SESSION[$wizard_name]['host_results_decoded'];
					$host_checkbox = $_SESSION[$wizard_name]['host_checkbox'];
					$host_counter = $_SESSION[$wizard_name]['host_counter'];
					$host_check_options = grab_array_var($inargs,'host_check_options',array());
					
					$host_checks = array (
						'Host_CPU_Info'						=> 'CPU Info',
						'Host_CPU_Usage'					=> 'CPU Usage',
						'Host_Datastore_Performance'		=> 'Datastore Performance',
						'Guest_Snapshot'					=> 'Guest Snapshot',
						'Host_License_Status'				=> 'License Status',
						'Host_Memory_Usage'					=> 'Memory Usage',
						'Host_OS_Name_Version'				=> 'OS Name Version',
						'Host_pNIC_Status'					=> 'pNIC Status',
						'Host_pNIC_Usage'					=> 'pNIC Usage',
						'Host_Status'						=> 'Host Status',
						'Host_Storage_Adapter_Info'			=> 'Storage Adapter Info',
						'Host_Storage_Adapter_Performance'	=> 'Storage Adapter Performance',
						'Host_Switch_Status'				=> 'Switch Status',
						'Host_vNIC_Status'					=> 'vNIC Status'
						);

					/* Find what host objects were selected */
					$host_checkbox_flag = 0;
					for ($h = 0; $h < $host_counter; $h++) {
						/* If this is a NEW Nagios Host Object, check the settings */
						if (isset($host_checkbox[$h])) {
							if ($nagios_object[$h] == 'new') {
								/* Check the intervals and retries */
								list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'New Host', $host_checkbox[$h], $host_check_options['Hosts']['check_interval'][$h], $host_check_options['Hosts']['retry_interval'][$h], $host_check_options['Hosts']['number_retries'][$h]);
								} /* End if ($nagios_object[$h] == 'new') { */
							} /* End if (isset($host_checkbox[$h])) { */
										
						/* Loop through each check */
						foreach ($host_checks as $check_key => $check_value) {
							/* Test to see if the check was selected */
							if (isset($host_check_options[$check_key]['monitor_me'][$h])) {
								/* Check selected, trigger flag */
								$host_checkbox_flag = 1;

								/* Now check the relevant options */
								switch ($check_key) {
									case 'Host_CPU_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										break; /* End case 'Host_CPU_Info': */


									case 'Host_CPU_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);

										/* cpu_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CW', 'CPU Free', 'cpu_free', $host_check_options);

										/* cpu_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'CPU Used', 'cpu_used', $host_check_options);
										break; /* End case 'Host_CPU_Usage': */


									case 'Host_Datastore_Performance':
										$datastore_flag = 0;
										if (isset($host_check_options[$check_key][$h]['monitor_me'])) {
											foreach ($host_check_options[$check_key][$h]['monitor_me'] as $datastore) {
												$datastore_flag = 1;
												/* Check the intervals and retries */
												list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, "$host_checkbox[$h] - $datastore", $host_check_options[$check_key][$h]['check_interval'][$datastore], $host_check_options[$check_key][$h]['retry_interval'][$datastore], $host_check_options[$check_key][$h]['number_retries'][$datastore]);

												/* datastore_rate => Check the warning and or critical */
												list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, array ($h, $datastore), "$host_checkbox[$h] - $datastore", 'WC', 'Datastore Rate', 'datastore_rate', $host_check_options);

												/* datastore_latency => Check the warning and or critical */
												list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, array ($h, $datastore), "$host_checkbox[$h] - $datastore", 'WC', 'Datastore Latency', 'datastore_latency', $host_check_options);

												} /* End foreach ($host_check_options[$check_key][$h]['monitor_me'] as $datastore) { */
											} /* End if (isset($host_check_options[$check_key][$h]['monitor_me']) { */
										if ($datastore_flag == 0) {
											$errmsg[$errors++] = "You did not select any DATASTORES for the host '$host_checkbox[$h]' !";
											} /* End if ($datastore_flag == 0) { */
										break; /* End case 'Host_Datastore_Performance': */


									case 'Guest_Snapshot':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);

										/* snapshot_age => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'Snapshot Age', 'snapshot_age', $host_check_options);
										break; /* End case 'Host_Guest_Snapshot': */


									case 'Host_License_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										break; /* End case 'Host_License_Status': */


									case 'Host_Memory_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);

										/* memory_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CW', 'Memory Free', 'memory_free', $host_check_options);

										/* memory_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'Memory Used', 'memory_used', $host_check_options);
										break; /* End case 'Host_Memory_Usage': */


									case 'Host_OS_Name_Version':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										break; /* End case 'Host_OS_Name_Version': */
										

									case 'Host_pNIC_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* pnic_checkbox => Make sure at least one pNIC is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'pNICs', 'pnic_checkbox', $host_check_options);
										break; /* End case 'Host_pNIC_Status': */
										

									case 'Host_pNIC_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* nic_rate => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'NIC Rate', 'nic_rate', $host_check_options);

										/* packet_errors => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'Packet Errors', 'packet_errors', $host_check_options);

										/* pnic_checkbox => Make sure at least one pNIC is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'pNICs', 'pnic_checkbox', $host_check_options);
										break; /* End case 'Host_pNIC_Usage': */


									case 'Host_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* exclude_issue => Check the exclude issue options */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'EXCLUDE', 'Exclude Issues', 'exclude_issue', $host_check_options);
										break; /* End case 'Host_Status': */


									case 'Host_Storage_Adapter_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* hba_checkbox => Make sure at least one HBA is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'HBAs', 'hba_checkbox', $host_check_options);
										break; /* End case 'Host_Storage_Adapter_Info': */
									

									case 'Host_Storage_Adapter_Performance':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* hba_checkbox => Make sure at least one HBA is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'HBAs', 'hba_checkbox', $host_check_options);

										/* hba_rate => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'HBA Rate', 'hba_rate', $host_check_options);

										/* hba_latency => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'WC', 'Latency Total', 'hba_latency', $host_check_options);
										break; /* End case 'Host_Storage_Adapter_Performance': */

										
									case 'Host_Switch_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* switch_checkbox => Make sure at least one Switch is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'Switch', 'switch_checkbox', $host_check_options);
										break; /* End case 'Host_Switch_Status': */

										
									case 'Host_vNIC_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $host_checkbox[$h], $host_check_options[$check_key]['check_interval'][$h], $host_check_options[$check_key]['retry_interval'][$h], $host_check_options[$check_key]['number_retries'][$h]);
										
										/* vnic_checkbox => Make sure at least one vNIC is selected */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $h, $host_checkbox[$h], 'CHOOSE', 'vNICs', 'vnic_checkbox', $host_check_options);
										break; /* End case 'Host_vNIC_Status': */
									} /* End switch ($check) { */
								} /* End if (isset($host_check_options[$check]['monitor_me'][$h])) { */
							} /* End foreach ($host_checks as $check) { */
						} /* End for ($h = 0; $h < $host_counter; $h++) { */
					
					/* Were any services selected to be monitored? */
					if ($host_checkbox_flag == 0) {
						$errmsg[$errors++] = 'You did not select any Host Objects to monitor!';
						} /* End if ($host_checkbox_flag == 0) { */
					else {
						/* We will save these to the session variable array for later use */
						$_SESSION[$wizard_name]['host_check_options'] = $host_check_options;
						} /* End else { */
					break; /* End case 'host': */


				case 'vcenter':
					$vcenter_results_decoded = $_SESSION[$wizard_name]['vcenter_results_decoded'];
					$vcenter_checkbox = $_SESSION[$wizard_name]['vcenter_checkbox'];
					$vcenter_counter = $_SESSION[$wizard_name]['vcenter_counter'];
					$vcenter_check_options = grab_array_var($inargs,'vcenter_check_options',array());
					
					$vcenter_checks = array (
						'Cluster_CPU_Usage'			=> 'Cluster CPU Usage',
						'Cluster_DRS_Status'		=> 'Cluster DRS Status',
						'Cluster_EVC_Status'		=> 'Cluster EVC Status',
						'Cluster_HA_Status'			=> 'Cluster HA Status',
						'Cluster_Memory_Usage'		=> 'Cluster Memory Usage',
						'Cluster_Resource_Info'		=> 'Cluster Resource Info',
						'Cluster_Swapfile_Status'	=> 'Cluster Swapfile Status',
						'Cluster_vMotion_Info'		=> 'Cluster vMotion Info'
						);
					
					/* Find what vcenter objects were selected */
					$vcenter_checkbox_flag = 0;

					/* If this is a NEW Nagios Host Object, check the settings */
					if ($nagios_object[0] == 'new') {
						/* Check the intervals and retries */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'New vCenter Server', $vcenter_checkbox[0], $vcenter_check_options['VMware_Host']['check_interval'][0], $vcenter_check_options['VMware_Host']['retry_interval'][0], $vcenter_check_options['VMware_Host']['number_retries'][0]);
						} /* End if ($nagios_object[0] == 'new') { */
						
					/* Starting at 1 because the vCenter server is 0 */
					for ($v = 1; $v < $vcenter_counter; $v++) {
						/* Loop through each check */
						foreach ($vcenter_checks as $check_key => $check_value) {
							/* Test to see if the check was selected */
							if (isset($vcenter_check_options[$check_key]['monitor_me'][$v])) {
								/* Check selected, trigger flag */
								$vcenter_checkbox_flag = 1;

								/* Now check the relevant options */
								switch ($check_key) {
									case 'Cluster_CPU_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);

										/* cpu_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'CW', 'CPU Free', 'cpu_free', $vcenter_check_options);

										/* cpu_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'WC', 'CPU Used', 'cpu_used', $vcenter_check_options);
										break; /* End case 'Cluster_CPU_Usage': */


									case 'Cluster_DRS_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);

										/* exclude_issue => Check the exclude issue options */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'EXCLUDE', 'Exclude Issues', 'exclude_issue', $vcenter_check_options);
										break; /* End case 'Cluster_DRS_Status': */


									case 'Cluster_EVC_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										break; /* End case 'Cluster_EVC_Status': */


									case 'Cluster_HA_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										
										/* exclude_issue => Check the exclude issue options */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'EXCLUDE', 'Exclude Issues', 'exclude_issue', $vcenter_check_options);
										break; /* End case 'Cluster_HA_Status': */
										

									case 'Cluster_Memory_Usage':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										
										/* memory_free => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'CW', 'Memory Free', 'memory_free', $vcenter_check_options);

										/* memory_used => Check the warning and or critical */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $v, $vcenter_checkbox[$v], 'WC', 'Memory Used', 'memory_used', $vcenter_check_options);
										break; /* End case 'Cluster_Memory_Usage': */
										

									case 'Cluster_Resource_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										break; /* End case 'Cluster_Resource_Info': */


									case 'Cluster_Swapfile_Status':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										break; /* End case 'Cluster_Swapfile_Status': */


									case 'Cluster_vMotion_Info':
										/* Check the intervals and retries */
										list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check_value, $vcenter_checkbox[$v], $vcenter_check_options[$check_key]['check_interval'][$v], $vcenter_check_options[$check_key]['retry_interval'][$v], $vcenter_check_options[$check_key]['number_retries'][$v]);
										break; /* End case 'Cluster_vMotion_Info': */
									} /* End switch ($check) { */
								} /* End if (isset($vcenter_check_options[$check]['monitor_me'][$v])) { */
							} /* End foreach ($vcenter_checks as $check) { */
						} /* End for ($v = 1; $v < $vcenter_counter; $v++) { */
					
					/* Guest Snapshot */
					if (isset($vcenter_check_options['Guest_Snapshot']['monitor_me'][0])) {
						$vcenter_checkbox_flag = 1;
						/* Check the intervals and retries */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'Guest Snapshot', $vcenter_checkbox[0], $vcenter_check_options['Guest_Snapshot']['check_interval'][0], $vcenter_check_options['Guest_Snapshot']['retry_interval'][0], $vcenter_check_options['Guest_Snapshot']['number_retries'][0]);

						/* snapshot_age => Check the warning and or critical */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_threshold_check($errmsg, $errors, 'Guest_Snapshot', 'Guest Snapshot', 0, $vcenter_checkbox[0], 'WC', 'Snapshot Age', 'snapshot_age', $vcenter_check_options);
						} /* End if (isset($vcenter_check_options['Guest_Snapshot']['monitor_me'][0])) { */
					
					/* vCenter License Status */
					if (isset($vcenter_check_options['vCenter_License_Status']['monitor_me'][0])) {
						$vcenter_checkbox_flag = 1;
						/* Check the intervals and retries */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'vCenter License Status', $vcenter_checkbox[0], $vcenter_check_options['vCenter_License_Status']['check_interval'][0], $vcenter_check_options['vCenter_License_Status']['retry_interval'][0], $vcenter_check_options['vCenter_License_Status']['number_retries'][0]);
						} /* End if (isset($vcenter_check_options['vCenter_License_Status']['monitor_me'][0])) { */

					/* vCenter Name and Version */
					if (isset($vcenter_check_options['vCenter_Name_Version']['monitor_me'][0])) {
						$vcenter_checkbox_flag = 1;
						$vcenter_checkbox_flag = 1;
						/* Check the intervals and retries */
						list ($errmsg, $errors) = vmwarevirtualizationwizard_interval_check($errmsg, $errors, 'vCenter Name & Version', $vcenter_checkbox[0], $vcenter_check_options['vCenter_Name_Version']['check_interval'][0], $vcenter_check_options['vCenter_Name_Version']['retry_interval'][0], $vcenter_check_options['vCenter_Name_Version']['number_retries'][0]);
						} /* End if (isset($vcenter_check_options['vCenter_Name_Version']['monitor_me'][0])) { */

					/* Were any services selected to be monitored? */
					if ($vcenter_checkbox_flag == 0) {
						$errmsg[$errors++] = 'You did not select any vCenter Objects to monitor!';
						} /* End if ($vcenter_checkbox_flag == 0) { */
					else {
						/* We will save these to the session variable array for later use */
						$_SESSION[$wizard_name]['vcenter_check_options'] = $vcenter_check_options;
						} /* End else { */
					
					break; /* End case 'vcenter': */
				} /* End switch ($vmware_check_type) { */

			/* Check to see if the $errors array contains errors */
			if ($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
				$result = 1;
				} /* End if ($errors>0){ */
			
			/* The next line ends CONFIGWIZARD_MODE_VALIDATESTAGE2DATA */
			break;
	

		case CONFIGWIZARD_MODE_GETSTAGE3OPTS:
			/* Use this to hard code the Monitoring Settings options */
			/* The below options are currently the only supported options to hard code */
	
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />post CONFIGWIZARD_MODE_GETSTAGE3OPTS<br />'); 
			//print_r($_POST); 
			//print_r('<br /><br />'); 
			
			/* The following THREE lines can be enabled for debugging purposes */
			//print_r('<br />session CONFIGWIZARD_MODE_GETSTAGE3OPTS<br />'); 
			//print_r($_SESSION[$wizard_name]); 
			//print_r('<br /><br />'); 
			
			/* Use this to hide the Monitoring Settings options */
			$result = CONFIGWIZARD_HIDE_OPTIONS;

			/* Now we are creating the HTML for CONFIGWIZARD_MODE_GETSTAGE3OPTS that will appear on CONFIGWIZARD_MODE_GETSTAGE3HTML */ 
			$output = '
				<link href="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.css" rel="stylesheet" type="text/css" />
				<script type="text/javascript" src="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.js"></script>

				<div class="'.$wizard_name.'-width550">
					The default monitoring settings do not apply when using this wizard.
					<div class="'.$wizard_name.'-spacer10"> </div>
					You have defined the monitoring settings for all checks in the previous stage.
					<div class="'.$wizard_name.'-spacer20"> </div>
					The next two stages are for defining "Notification Settings" and "Host Groups".
					<div class="'.$wizard_name.'-spacer10"> </div>
					If you do not need to define those settings you can click the <b>Finish</b> button now.
					<div class="'.$wizard_name.'-spacer20"> </div>
				</div>
				';

			/* $output will be passed back to XI framework and rendered to browser */
			/* The next line ends CONFIGWIZARD_MODE_GETSTAGE3OPTS */
			break;
		
	
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			/* Now we are creating the HTML for CONFIGWIZARD_MODE_GETFINALSTAGEHTML */ 
			$output = '
				<link href="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.css" rel="stylesheet" type="text/css" />
				<script type="text/javascript" src="../includes/configwizards/'.$wizard_name.'/'.$wizard_name.'.js"></script>

				<div class="'.$wizard_name.'-width550">
					You have now completed all the steps to monitor the objects you have selected in the previous stages.
					<div class="'.$wizard_name.'-spacer20"> </div>
					<div class="'.$wizard_name.'-spacer20"> </div>
				</div>
				';
			/* The quote and semicolon ends HTML for CONFIGWIZARD_MODE_GETFINALSTAGEHTML */ 
			/* $output will be passed back to XI framework and rendered to browser */
			/* The next line ends CONFIGWIZARD_MODE_GETFINALSTAGEHTML */
			break;
		
		
		/* This stage commits the wizard data into objects definitions to be imported */
		case CONFIGWIZARD_MODE_GETOBJECTS:
			/* Initialize objects array, this will contain the objects that we will add */
			$objs = array();
			
			/* Get existing settings and variables that were passed to us */
			$vma_host_select = $_SESSION[$wizard_name]['vma_host_select'];
			$vma_host_object_select = $_SESSION[$wizard_name]['vma_host_object_select'];
			$vma_host_object_type = $_SESSION[$wizard_name]['vma_host_object_type'];
			$vmware_check_type = $_SESSION[$wizard_name]['vmware_check_type'];
			$nagios_object = $_SESSION[$wizard_name]['nagios_object'];
			$nagios_object_existing = $_SESSION[$wizard_name]['nagios_object_existing'];
			$nagios_object_new_name = $_SESSION[$wizard_name]['nagios_object_new_name'];
			$nagios_object_new_address = $_SESSION[$wizard_name]['nagios_object_new_address'];

			$exclude_issues = Array('ClusterOvercommittedEvent', 'DasClusterIsolatedEvent', 'DasHostFailedEvent', 'DasHostIsolatedEvent', 'HeartbeatDatastoreNotSufficient', 'HostNoRedundantManagementNetworkEvent', 'InsufficientFailoverResourcesEvent', 'LocalTSMEnabledEvent', 'RemoteTSMEnabledEvent');

			/* Specific to the vmware_check_type */
			switch ($vmware_check_type) {
				case 'datastores':
					$datastore_results_decoded = $_SESSION[$wizard_name]['datastore_results_decoded'];
					$datastore_checkbox = $_SESSION[$wizard_name]['datastore_checkbox'];
					$datastore_counter = $_SESSION[$wizard_name]['datastore_counter'];
					$datastore_check_options = $_SESSION[$wizard_name]['datastore_check_options'];

					/* Determine if this is a new host or existing host */
					switch ($nagios_object[0]) {
						case 'new':
							/* New host, define variables and host object */
							$host_name = $nagios_object_new_name[0];
							$host_address = $nagios_object_new_address[0];
							$check_interval = $datastore_check_options['VMware_Host']['check_interval'][0];
							$retry_interval = $datastore_check_options['VMware_Host']['retry_interval'][0];
							$max_check_attempts = $datastore_check_options['VMware_Host']['number_retries'][0];

							/* Determine what image should be used for the host object */
							if ($vma_host_object_type == 'vcenter') {
								$vrml_image = 'vmware3.png';
								$statusmap_image = 'vmware3.gd2';
								$icon_image = 'vmware3.png';
								} /* End if ($vma_host_object_type == 'vcenter') { */
							else {
								$vrml_image = 'vmware_host.png';
								$statusmap_image = 'vmware_host.png';
								$icon_image = 'vmware_host.png';
								} /* End else { */
							
							if (!host_exists($host_name)) {
								$objs[] = array(
									'type'					=> OBJECTTYPE_HOST,
									'host_name'				=> $host_name,
									'address'				=> $host_address,
									'check_interval'		=> $check_interval,
									'retry_interval'		=> $retry_interval,
									'max_check_attempts'	=> $max_check_attempts,
									'vrml_image'			=> $vrml_image,
									'statusmap_image'		=> $statusmap_image,
									'icon_image'			=> $icon_image,
									'use' 					=> 'xiwizard_generic_host',
									'_xiwizard'				=> $wizard_name,
									);
								} /* End if (!host_exists($hostname)) { */
							break; /* End case 'new': */
						

						case 'existing':
							/* Existing object, define variables */
							$host_name = $nagios_object_existing[0];
							break; /* End case 'existing': */
						} /* End switch ($nagios_object[0]) { */

					
					/* Find what vcenter objects were selected */
					/* Starting at 1 because the vCenter server OR ESX(i) host is the host object */
					for ($d = 1; $d < $datastore_counter; $d++) {
						/* Check to see if this object was originally selected */
						if (isset($datastore_checkbox[$d])) {
							/* Test to see if the check was selected */
							if (isset($datastore_check_options['Datastore_Usage']['monitor_me'][$d])) {
								/* Check selected */
								$check_interval = $datastore_check_options['Datastore_Usage']['check_interval'][$d];
								$retry_interval = $datastore_check_options['Datastore_Usage']['retry_interval'][$d];
								$max_check_attempts = $datastore_check_options['Datastore_Usage']['number_retries'][$d];

								/* Build the check command */
								$check_command = 'vmware_datastore_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$datastore_checkbox[$d].'!Disk_Size:'.$datastore_check_options['Datastore_Usage']['reporting_si']['Disk_Size'][$d];
								
								/* Determine if warning and critical have been defined and add to command*/
								$warning = '';
								$critical = '';
								list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, 'Datastore_Usage', $d, 'datastore_free', $datastore_check_options);
								list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, 'Datastore_Usage', $d, 'datastore_used', $datastore_check_options);
								$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
								switch ($waoc) {
									case 'W':
										$check_command .= '!--warning!'.$warning;
										break; /* End case 'W': */
										
									case 'C':
										$check_command .= '!--critical!'.$critical;
										break; /* End case 'C': */
										
									case 'WAC':
										$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
										break; /* End case 'WAC': */
									} /* End switch ($waoc) { */
								
								$objs[] = array(
									'type' 					=> OBJECTTYPE_SERVICE,
									'host_name' 			=> $host_name,
									'service_description' 	=> 'Datastore Usage - '.$datastore_checkbox[$d],
									'check_command'			=> $check_command,
									'check_interval'		=> $check_interval,
									'retry_interval'		=> $retry_interval,
									'max_check_attempts'	=> $max_check_attempts,
									'use' 					=> $wizard_name.'_datastore',
									'_xiwizard' 			=> $wizard_name,
									);
								} /* End if (isset($datastore_check_options['Datastore_Usage']['monitor_me'][$d])) { */
							} /* End if (isset($datastore_checkbox[$d])) { */
						} /* End for ($d = 1; $d < $datastore_counter; $d++) { */
					break; /* End case 'datastores': */
				

				case 'guests':
					$guest_results_decoded = $_SESSION[$wizard_name]['guest_results_decoded'];
					$guest_checkbox = $_SESSION[$wizard_name]['guest_checkbox'];
					$guest_counter = $_SESSION[$wizard_name]['guest_counter'];
					$guest_check_options = $_SESSION[$wizard_name]['guest_check_options'];

					$guest_checks = array (
						'Guest_CPU_Info'			=> 'CPU Info',
						'Guest_CPU_Usage'			=> 'CPU Usage',
						'Guest_Disk_Performance'	=> 'Disk Performance',
						'Guest_Disk_Usage'			=> 'Disk Usage',
						'Guest_Memory_Info'			=> 'Memory Info',
						'Guest_Memory_Usage'		=> 'Memory Usage',
						'Guest_NIC_Usage'			=> 'NIC Usage',
						'Guest_Snapshot'			=> 'Guest Snapshot'
						);

					/* Find what guest objects were selected */
					for ($g = 0; $g < $guest_counter; $g++) {
						/* Check to see if this guest was originally selected */
						if (isset($guest_checkbox[$g])) {
							
							/* Determine if this is a new guest or existing guest */
							switch ($nagios_object[$g]) {
								case 'new':
									/* New guest, define variables and host object */
									$host_name = $nagios_object_new_name[$g];
									$host_address = $nagios_object_new_address[$g];
									$check_interval = $guest_check_options['Guests']['check_interval'][$g];
									$retry_interval = $guest_check_options['Guests']['retry_interval'][$g];
									$max_check_attempts = $guest_check_options['Guests']['number_retries'][$g];

									if (!host_exists($host_name)) {
										$objs[] = array(
											'type'					=> OBJECTTYPE_HOST,
											'host_name'				=> $host_name,
											'address'				=> $host_address,
											'check_interval'		=> $check_interval,
											'retry_interval'		=> $retry_interval,
											'max_check_attempts'	=> $max_check_attempts,
											'vrml_image'			=> 'vmware_guest.png',
											'statusmap_image'		=> 'vmware_guest.png',
											'icon_image'			=> 'vmware_guest.png',
											'use' 					=> 'xiwizard_generic_host',
											'_xiwizard'				=> $wizard_name,
											);
										} /* End if (!host_exists($hostname)) { */
									break; /* End case 'new': */
								

								case 'existing':
									/* Existing object, define variables */
									$host_name = $nagios_object_existing[$g];
									break; /* End case 'existing': */
								} /* End switch ($nagios_object[$g]) { */


							/* Loop through each check for this guest */
							foreach ($guest_checks as $check_key => $check_value) {
								/* Test to see if the check was selected */
								if (isset($guest_check_options[$check_key]['monitor_me'][$g])) {
									/* Check selected */

									/* Now create the relevant services */
									switch ($check_key) {
										case 'Guest_CPU_Info':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_cpu_info!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!CPU_Speed:'.$guest_check_options[$check_key]['reporting_si']['CPU_Speed'][$g];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'cpu_reservation', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'cpu_limit', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'CPU Info',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cpu',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_CPU_Info': */


										case 'Guest_CPU_Usage':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Create reporting_si */
											$reporting_si = 'CPU_Speed:'.$guest_check_options[$check_key]['reporting_si']['CPU_Speed'][$g].',Time:'.$guest_check_options[$check_key]['reporting_si']['Time'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_cpu_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!'.$reporting_si;
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'cpu_free', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'cpu_used', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'cpu_ready_time', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'CPU Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cpu',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_CPU_Usage': */


										case 'Guest_Disk_Performance':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Create reporting_si */
											$reporting_si = 'Disk_Rate:'.$guest_check_options[$check_key]['reporting_si']['Disk_Rate'][$g];
											if ($guest_check_options[$check_key]['reporting_si']['Time'][$g] != 'default') {
												$reporting_si .= ',Time:'.$guest_check_options[$check_key]['reporting_si']['Time'][$g];
												} /* End if ($guest_check_options[$check_key]['reporting_si']['Time'][$g] != 'default') { */

											/* Build the check command */
											$check_command = 'vmware_guest_disk_performance!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!'.$reporting_si;
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'disk_rate', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'disk_latency', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Disk Performance',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_disk',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Disk_Performance': */


										case 'Guest_Disk_Usage':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_disk_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!Disk_Size:'.$guest_check_options[$check_key]['reporting_si']['Disk_Size'][$g];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'disk_free', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'disk_total', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Disk Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_disk',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Disk_Usage': */


										case 'Guest_Memory_Info':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_memory_info!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!Memory_Size:'.$guest_check_options[$check_key]['reporting_si']['Memory_Size'][$g];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_reservation', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_limit', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Memory Info',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_memory',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Memory_Info': */


										case 'Guest_Memory_Usage':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Create reporting_si */
											$reporting_si = 'Memory_Size:'.$guest_check_options[$check_key]['reporting_si']['Memory_Size'][$g].',Memory_Rate:'.$guest_check_options[$check_key]['reporting_si']['Memory_Rate'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_memory_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!'.$reporting_si;
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_free', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_consumed', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_ballooned', $guest_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'memory_swap_rate', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Memory Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_memory',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Memory_Usage': */


										case 'Guest_NIC_Usage':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_nic_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$guest_checkbox[$g].'!NIC_Rate:'.$guest_check_options[$check_key]['reporting_si']['NIC_Rate'][$g];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'nic_rate', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'NIC Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_network',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_NIC_Usage': */


										case 'Guest_Snapshot':
											$check_interval = $guest_check_options[$check_key]['check_interval'][$g];
											$retry_interval = $guest_check_options[$check_key]['retry_interval'][$g];
											$max_check_attempts = $guest_check_options[$check_key]['number_retries'][$g];

											/* Build the check command */
											$check_command = 'vmware_guest_snapshot!'.$vma_host_select.'!'.$vma_host_object_select.'!--guest!'.$guest_checkbox[$g];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $g, 'snapshot_age', $guest_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Guest Snapshots',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_snapshot',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Snapshot': */
										} /* End switch ($check_key) { */
									} /* End if (isset($guest_check_options[$check_key]['monitor_me'][$g])) { */
								} /* End foreach ($guest_checks as $check_key => $check_value) { */
							} /* End if (isset($guest_checkbox[$g])) { */
						} /* End for ($g = 0; $g < $guest_counter; $g++) { */
					break; /* End case 'guests': */
				

				case 'host':
					$host_results_decoded = $_SESSION[$wizard_name]['host_results_decoded'];
					$host_checkbox = $_SESSION[$wizard_name]['host_checkbox'];
					$host_counter = $_SESSION[$wizard_name]['host_counter'];
					$host_check_options = $_SESSION[$wizard_name]['host_check_options'];

					$host_checks = array (
						'Host_CPU_Info'						=> 'CPU Info',
						'Host_CPU_Usage'					=> 'CPU Usage',
						'Host_Datastore_Performance'		=> 'Datastore Performance',
						'Guest_Snapshot'					=> 'Guest Snapshot',
						'Host_License_Status'				=> 'License Status',
						'Host_Memory_Usage'					=> 'Memory Usage',
						'Host_OS_Name_Version'				=> 'OS Name Version',
						'Host_pNIC_Status'					=> 'pNIC Status',
						'Host_pNIC_Usage'					=> 'pNIC Usage',
						'Host_Status'						=> 'Host Status',
						'Host_Storage_Adapter_Info'			=> 'Storage Adapter Info',
						'Host_Storage_Adapter_Performance'	=> 'Storage Adapter Performance',
						'Host_Switch_Status'				=> 'Switch Status',
						'Host_vNIC_Status'					=> 'vNIC Status'
						);

					/* Find what host objects were selected */
					for ($h = 0; $h < $host_counter; $h++) {
						/* Check to see if this host was originally selected */
						if (isset($host_checkbox[$h])) {
							
							/* Determine if this is a new host or existing host */
							switch ($nagios_object[$h]) {
								case 'new':
									/* New host, define variables and host object */
									$host_name = $nagios_object_new_name[$h];
									$host_address = $nagios_object_new_address[$h];
									$check_interval = $host_check_options['Hosts']['check_interval'][$h];
									$retry_interval = $host_check_options['Hosts']['retry_interval'][$h];
									$max_check_attempts = $host_check_options['Hosts']['number_retries'][$h];

									if (!host_exists($host_name)) {
										$objs[] = array(
											'type'					=> OBJECTTYPE_HOST,
											'host_name'				=> $host_name,
											'address'				=> $host_address,
											'check_interval'		=> $check_interval,
											'retry_interval'		=> $retry_interval,
											'max_check_attempts'	=> $max_check_attempts,
											'vrml_image'			=> 'vmware_host.png',
											'statusmap_image'		=> 'vmware_host.png',
											'icon_image'			=> 'vmware_host.png',
											'use' 					=> 'xiwizard_generic_host',
											'_xiwizard'				=> $wizard_name,
											);
										} /* End if (!host_exists($hostname)) { */
									break; /* End case 'new': */
								

								case 'existing':
									/* Existing object, define variables */
									$host_name = $nagios_object_existing[$h];
									break; /* End case 'existing': */
								} /* End switch ($nagios_object[$h]) { */


							/* Loop through each check for this host */
							foreach ($host_checks as $check_key => $check_value) {
								/* Test to see if the check was selected */
								if (isset($host_check_options[$check_key]['monitor_me'][$h])) {
									/* Check selected */

									/* Now create the relevant services */
									switch ($check_key) {
										case 'Host_CPU_Info':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h].'!--reporting_si!CPU_Speed:'.$host_check_options[$check_key]['reporting_si']['CPU_Speed'][$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal_reporting_si!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!CPU_Speed:'.$host_check_options[$check_key]['reporting_si']['CPU_Speed'][$h];
												} /* End else { */

											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'CPU Info',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cpu',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_CPU_Info': */


										case 'Host_CPU_Usage':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter_cpu_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!CPU_Speed:'.$host_check_options[$check_key]['reporting_si']['CPU_Speed'][$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal_reporting_si!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!CPU_Speed:'.$host_check_options[$check_key]['reporting_si']['CPU_Speed'][$h];
												} /* End else { */

											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'cpu_free', $host_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'cpu_used', $host_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'CPU Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cpu',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_CPU_Usage': */


										case 'Host_Datastore_Performance':
											/* Check each available datastore for this host */
											foreach ($host_check_options[$check_key][$h]['monitor_me'] as $datastore) {
												$check_interval = $host_check_options[$check_key][$h]['check_interval'][$datastore];
												$retry_interval = $host_check_options[$check_key][$h]['retry_interval'][$datastore];
												$max_check_attempts = $host_check_options[$check_key][$h]['number_retries'][$datastore];
												
												/* Determine if warning and critical have been defined */
												$warning = '';
												$critical = '';
												list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, array ($h, $datastore), 'datastore_rate', $host_check_options);
												list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, array ($h, $datastore), 'datastore_latency', $host_check_options);
												$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);

												/* Create reporting_si */
												$reporting_si = 'Datastore_Rate:'.$host_check_options[$check_key][$h]['reporting_si']['Datastore_Rate'][$datastore].',Latency:'.$host_check_options[$check_key][$h]['reporting_si']['Latency'][$datastore];
												
												/* Build the check command */
												/* Is this a host connected to vCenter */
												if ($vma_host_object_type == 'vcenter') {
													if ($waoc == 'WAC') {
														$check_command = 'vmware_datastore_performance_vcenter_wac!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$datastore.'!'.$reporting_si.'!'.$warning.'!'.$critical;
														} /* End if ($waoc == 'WAC') { */
													else {
														$check_command = 'vmware_datastore_performance_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$datastore.'!'.$reporting_si;
														if ($waoc == 'W') {
															$check_command .= '!--warning!'.$warning;
															} /* End if ($waoc == 'W') { */
														if ($waoc == 'C') {
															$check_command .= '!--critical!'.$critical;
															} /* End if ($waoc == 'C') { */
														} /* End else { */
													} /* End if ($vma_host_object_type == 'vcenter') { */
												else {
													$check_command = 'vmware_datastore_performance_esx!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$datastore.'!'.$reporting_si;
													if ($waoc == 'WAC') {
														$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
														} /* End if ($waoc == 'WAC') { */
													if ($waoc == 'W') {
														$check_command .= '!--warning!'.$warning;
														} /* End if ($waoc == 'W') { */
													if ($waoc == 'C') {
														$check_command .= '!--critical!'.$critical;
														} /* End if ($waoc == 'C') { */
													} /* End else { */

												$service_description = 'Datastore Performance - ' . $datastore;

												$objs[] = array(
													'type' 					=> OBJECTTYPE_SERVICE,
													'host_name' 			=> $host_name,
													'service_description' 	=> $service_description,
													'check_command'			=> $check_command,
													'check_interval'		=> $check_interval,
													'retry_interval'		=> $retry_interval,
													'max_check_attempts'	=> $max_check_attempts,
													'use' 					=> $wizard_name.'_datastore',
													'_xiwizard' 			=> $wizard_name,
													);
												} /* End foreach ($host_check_options[$check_key][$h]['monitor_me'] as $datastore) { */
											break; /* End case 'Host_Datastore_Performance': */


										case 'Guest_Snapshot':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											$check_command = 'vmware_guest_snapshot!'.$vma_host_select.'!'.$vma_host_object_select.'!--host!'.$host_checkbox[$h];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'snapshot_age', $host_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Guest Snapshots',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_snapshot',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Guest_Snapshot': */
											

										case 'Host_License_Status':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key;
												} /* End else { */

											/* Check for the hide_key argument */
											if (isset($host_check_options[$check_key]['hide_key'][$h])) {
												$check_command .= '!--hide_key';
												} /* End if (isset($host_check_options[$check_key]['hide_key'][$h])) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'License Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_license',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_License_Status': */


										case 'Host_Memory_Usage':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter_memory_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!Memory_Size:'.$host_check_options[$check_key]['reporting_si']['Memory_Size'][$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal_reporting_si!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!--reporting_si!Memory_Size:'.$host_check_options[$check_key]['reporting_si']['Memory_Size'][$h];
												} /* End else { */

											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'memory_free', $host_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'memory_used', $host_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Memory Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_memory',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_Memory_Usage': */


										case 'Host_OS_Name_Version':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key;
												} /* End else { */

											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Host Version',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_version',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_OS_Name_Version': */


										case 'Host_pNIC_Status':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all nics OR specific ones */
											$nic_name = '';
											$service_description = '';
											if (isset($host_check_options[$check_key]['pnic_checkbox'][$h]['all'])) {
												$nic_name = 'all';
												$service_description = 'All pNICs';
												} /* End if (isset($host_check_options[$check_key]['pnic_checkbox'][$h]['all'])) { */
											else {
												foreach ($host_check_options[$check_key]['pnic_checkbox'][$h] as $pnic) {
													if ($nic_name != '') {
														$nic_name .= ',';
														$service_description .= ' ';
														} /* End if ($nic_name != '') { */
													$nic_name .= $pnic;
													$service_description .= $pnic;
													} /* End foreach ($host_check_options[$check_key]['pnic_checkbox'][$h] as $pnic) { */
												} /* End else { */

											$nic_state = $host_check_options[$check_key]['nic_state'][$h];
											$nic_duplex = $host_check_options[$check_key]['nic_duplex'][$h];
											
											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												if ($nic_name == 'all') {
													$check_command = 'vmware_host_vcenter_pnic_status!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$nic_state.'!'.$nic_duplex;
													} /* End if ($nic_name == 'all') { */
												else {
													$check_command = 'vmware_host_vcenter_pnic_status_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$nic_name.'!'.$nic_state.'!'.$nic_duplex;
													} /* End else { */
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_host_esx_pnic_status!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$nic_state.'!'.$nic_duplex;
												if ($nic_name != 'all') {
													$check_command .= '!--name!'.$nic_name;
													} /* End if ($nic_name != 'all') { */
												} /* End else { */

											/* Determine if we need to check the NIC speed */
											if ($host_check_options[$check_key]['nic_speed'][$h] != 'default') {
												$check_command .= '!--nic_speed!'.$host_check_options[$check_key]['nic_speed'][$h];
												} /* End if ($host_check_options[$check_key]['nic_speed'][$h] != 'default') { */

											$service_description = 'pNIC Status - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_network',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_pNIC_Status': */


										case 'Host_pNIC_Usage':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all nics OR specific ones */
											$nic_name = '';
											$service_description = '';
											if (isset($host_check_options[$check_key]['pnic_checkbox'][$h]['all'])) {
												$nic_name = 'all';
												$service_description = 'All pNICs';
												} /* End if (isset($host_check_options[$check_key]['pnic_checkbox'][$h]['all'])) { */
											else {
												foreach ($host_check_options[$check_key]['pnic_checkbox'][$h] as $pnic) {
													if ($nic_name != '') {
														$nic_name .= ',';
														$service_description .= ' ';
														} /* End if ($nic_name != '') { */
													$nic_name .= $pnic;
													$service_description .= $pnic;
													} /* End foreach ($host_check_options[$check_key]['pnic_checkbox'][$h] as $pnic) { */
												} /* End else { */

											/* Determine if warning and critical have been defined */
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'nic_rate', $host_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'packet_errors', $host_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											
											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												if ($waoc == 'WAC') {
													$check_command = 'vmware_host_vcenter_pnic_usage_wac!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!NIC_Rate:'.$host_check_options[$check_key]['reporting_si']['NIC_Rate'][$h].'!'.$warning.'!'.$critical;
													} /* End if ($waoc == 'WAC') { */
												else {
													$check_command = 'vmware_host_vcenter_pnic_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!NIC_Rate:'.$host_check_options[$check_key]['reporting_si']['NIC_Rate'][$h];
													if ($waoc == 'W') {
														$check_command .= '!--warning!'.$warning;
														} /* End if ($waoc == 'W') { */
													if ($waoc == 'C') {
														$check_command .= '!--critical!'.$critical;
														} /* End if ($waoc == 'C') { */
													} /* End else { */
												if ($nic_name != 'all') {
													$check_command .= '!--name!'.$nic_name;
													} /* End if ($nic_name != 'all') { */
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												if ($nic_name == 'all') {
													$check_command = 'vmware_host_esx_pnic_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!NIC_Rate:'.$host_check_options[$check_key]['reporting_si']['NIC_Rate'][$h];
													} /* End if ($nic_name == 'all') { */
												else {
													$check_command = 'vmware_host_esx_pnic_usage_named!'.$vma_host_select.'!'.$vma_host_object_select.'!NIC_Rate:'.$host_check_options[$check_key]['reporting_si']['NIC_Rate'][$h].'!'.$nic_name;
													} /* End else { */
												if ($waoc == 'WAC') {
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													} /* End if ($waoc == 'WAC') { */
												if ($waoc == 'W') {
													$check_command .= '!--warning!'.$warning;
													} /* End if ($waoc == 'W') { */
												if ($waoc == 'C') {
													$check_command .= '!--critical!'.$critical;
													} /* End if ($waoc == 'C') { */
												} /* End else { */

											$service_description = 'pNIC Usage - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_network',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_pNIC_Usage': */


										case 'Host_Status':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key;
												} /* End else { */

											/* Determine if we need exclude issues */
											if (isset($host_check_options[$check_key]['exclude_issue_checkbox'][$h])) {
												$exclude_options = '';
												foreach ($exclude_issues as $issue) {
													if (isset($host_check_options[$check_key]['exclude_issue'][$issue][$h])) {
														if ($exclude_options != '') {
															$exclude_options .= ',';
															} /* End if ($exclude_options != '') { */
														$exclude_options .= $issue;
														} /* End if (isset($host_check_options[$check_key]['[exclude_issue'][$issue][$h])) { */
													} /* End foreach ($exclude_issues as $issue) { */
												$check_command .= '!--exclude_issue!'.$exclude_options;
												} /* End if (isset($host_check_options[$check_key]['exclude_issue_checkbox'][$h])) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> 'Host Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_host',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_Status': */


										case 'Host_Storage_Adapter_Info':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all hbas OR specific ones */
											$hba_name = '';
											$service_description = '';
											if (isset($host_check_options[$check_key]['hba_checkbox'][$h]['all'])) {
												$hba_name = 'all';
												$service_description = 'All HBAs';
												} /* End if (isset($host_check_options[$check_key]['hba_checkbox'][$h]['all'])) { */
											else {
												foreach ($host_check_options[$check_key]['hba_checkbox'][$h] as $hba) {
													if ($hba_name != '') {
														$hba_name .= ',';
														$service_description .= ' ';
														} /* End if ($hba_name != '') { */
													$hba_name .= $hba;
													$service_description .= $hba;
													} /* End foreach ($host_check_options[$check_key]['hba_checkbox'][$h] as $hba) { */
												} /* End else { */

											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key;
												} /* End else { */

											if ($hba_name != 'all') {
												$check_command .= '!--name!'.$hba_name;
												} /* End if ($hba_name != 'all') { */

											$service_description = 'Storage Adapter Info - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_adapter',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_Storage_Adapter_Info': */


										case 'Host_Storage_Adapter_Performance':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all hbas OR specific ones */
											$hba_name = '';
											$service_description = '';
											foreach ($host_check_options[$check_key]['hba_checkbox'][$h] as $hba) {
												if ($hba_name != '') {
													$hba_name .= ',';
													$service_description .= ' ';
													} /* End if ($hba_name != '') { */
												$hba_name .= $hba;
												$service_description .= $hba;
												} /* End foreach ($host_check_options[$check_key]['hba_checkbox'][$h] as $hba) { */
										
											/* Determine if warning and critical have been defined */
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'hba_rate', $host_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $h, 'hba_latency', $host_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);

											/* Create reporting_si */
											$reporting_si = 'HBA_Rate:'.$host_check_options[$check_key]['reporting_si']['HBA_Rate'][$h].',Latency:'.$host_check_options[$check_key]['reporting_si']['Latency'][$h];
											
											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												if ($waoc == 'WAC') {
													$check_command = 'vmware_host_vcenter_hba_usage_wac!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$hba_name.'!'.$reporting_si.'!'.$warning.'!'.$critical;
													} /* End if ($waoc == 'WAC') { */
												else {
													$check_command = 'vmware_host_vcenter_hba_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$hba_name.'!--reporting_si!'.$reporting_si;
													if ($waoc == 'W') {
														$check_command .= '!--warning!'.$warning;
														} /* End if ($waoc == 'W') { */
													if ($waoc == 'C') {
														$check_command .= '!--critical!'.$critical;
														} /* End if ($waoc == 'C') { */
													} /* End else { */
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_host_esx_hba_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$hba_name.'!'.$reporting_si;
												if ($waoc == 'WAC') {
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													} /* End if ($waoc == 'WAC') { */
												if ($waoc == 'W') {
													$check_command .= '!--warning!'.$warning;
													} /* End if ($waoc == 'W') { */
												if ($waoc == 'C') {
													$check_command .= '!--critical!'.$critical;
													} /* End if ($waoc == 'C') { */
												} /* End else { */

											$service_description = 'Storage Adapter Performance - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_adapter',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_Storage_Adapter_Performance': */


										case 'Host_Switch_Status':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all switches OR specific ones */
											$switch_name = '';
											$service_description = '';
											if (isset($host_check_options[$check_key]['switch_checkbox'][$h]['all'])) {
												$switch_name = 'all';
												$service_description = 'All Switches';
												} /* End if (isset($host_check_options[$check_key]['switch_checkbox'][$h]['all'])) { */
											else {
												foreach ($host_check_options[$check_key]['switch_checkbox'][$h] as $switch) {
													if ($switch_name != '') {
														$switch_name .= ',';
														$service_description .= ' ';
														} /* End if ($switch_name != '') { */
													$switch_name .= $switch;
													$service_description .= $switch;
													} /* End foreach ($host_check_options[$check_key]['switch_checkbox'][$h] as $switch) { */
												} /* End else { */

											$switch_mtu = $host_check_options[$check_key]['mtu'][$h];
											$nic_state = $host_check_options[$check_key]['nic_state'][$h];
											$nic_duplex = $host_check_options[$check_key]['nic_duplex'][$h];
											
											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												switch ($switch_mtu) {
													case '1500':
														if ($switch_name == 'all') {
															$check_command = 'vmware_host_vcenter_switch_status_mtu_1500!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$nic_state.'!'.$nic_duplex;
															} /* End if ($switch_name == 'all') { */
														else {
															$check_command = 'vmware_host_vcenter_switch_status_mtu_1500_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$switch_name.'!'.$nic_state.'!'.$nic_duplex;
															} /* End else { */
														break; /* End case '1500': */

													case '9000':
														if ($switch_name == 'all') {
															$check_command = 'vmware_host_vcenter_switch_status_mtu_9000!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$nic_state.'!'.$nic_duplex;
															} /* End if ($switch_name == 'all') { */
														else {
															$check_command = 'vmware_host_vcenter_switch_status_mtu_9000_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$switch_name.'!'.$nic_state.'!'.$nic_duplex;
															} /* End else { */
														break; /* End case '9000': */

													default:
														if ($switch_name == 'all') {
															$check_command = 'vmware_host_vcenter_switch_status!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$nic_state.'!'.$nic_duplex;
															} /* End if ($switch_name == 'all') { */
														else {
															$check_command = 'vmware_host_vcenter_switch_status_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$host_checkbox[$h].'!'.$switch_name.'!'.$nic_state.'!'.$nic_duplex;
															} /* End else { */
														break; /* End default: */
													} /* End switch ($switch_mtu) { */
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												switch ($switch_mtu) {
													case '1500':
													case '9000':
														if ($switch_name == 'all') {
															$check_command = 'vmware_host_esx_switch_status_mtu!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$nic_state.'!'.$nic_duplex.'!'.$switch_mtu;
															} /* End if ($switch_name == 'all') { */
														else {
															$check_command = 'vmware_host_esx_switch_status_mtu_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$switch_name.'!'.$nic_state.'!'.$nic_duplex.'!'.$switch_mtu;
															} /* End else { */
														break; /* End case '1500': case '9000': */

													default:
														if ($switch_name == 'all') {
															$check_command = 'vmware_host_esx_switch_status!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$nic_state.'!'.$nic_duplex;
															} /* End if ($switch_name == 'all') { */
														else {
															$check_command = 'vmware_host_esx_switch_status_named!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$switch_name.'!'.$nic_state.'!'.$nic_duplex;
															} /* End else { */
														break; /* End default: */
													} /* End switch ($switch_mtu) { */
												} /* End else { */

											/* Determine if we need to check the NIC speed */
											if ($host_check_options[$check_key]['nic_speed'][$h] != 'default') {
												$check_command .= '!--nic_speed!'.$host_check_options[$check_key]['nic_speed'][$h];
												} /* End if ($host_check_options[$check_key]['nic_speed'][$h] != 'default') { */

											$service_description = 'Switch Status - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_switch',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_Switch_Status': */


										case 'Host_vNIC_Status':
											$check_interval = $host_check_options[$check_key]['check_interval'][$h];
											$retry_interval = $host_check_options[$check_key]['retry_interval'][$h];
											$max_check_attempts = $host_check_options[$check_key]['number_retries'][$h];

											/* Determine if we need to check all vnics OR specific ones */
											$nic_name = '';
											$service_description = '';
											if (isset($host_check_options[$check_key]['vnic_checkbox'][$h]['all'])) {
												$nic_name = 'all';
												$service_description = 'All vNICs';
												} /* End if (isset($host_check_options[$check_key]['vnic_checkbox'][$h]['all'])) { */
											else {
												foreach ($host_check_options[$check_key]['vnic_checkbox'][$h] as $vnic) {
													if ($nic_name != '') {
														$nic_name .= ',';
														$service_description .= ' ';
														} /* End if ($nic_name != '') { */
													$nic_name .= $vnic;
													$service_description .= $vnic;
													} /* End foreach ($host_check_options[$check_key]['vnic_checkbox'][$h] as $vnic) { */
												} /* End else { */

											$vnic_mtu = $host_check_options[$check_key]['mtu'][$h];
											
											/* Build the check command */
											/* Is this a host connected to vCenter */
											if ($vma_host_object_type == 'vcenter') {
												$check_command = 'vmware_host_vcenter!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!'.$host_checkbox[$h];
												} /* End if ($vma_host_object_type == 'vcenter') { */
											else {
												$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key;
												} /* End else { */

											/* Determine if we need to specify the MTU */
											switch ($vnic_mtu) {
												case '1500':
												case '9000':
													$check_command .= '!--mtu!'.$vnic_mtu;
													break; /* End case '1500': case '9000': */
												} /* End switch ($vnic_mtu) { */

											/* Determine if we need to specify the vNIC name */
											if ($nic_name != 'all') {
												$check_command .= '!--name!'.$nic_name;
												} /* End if ($nic_name != 'all') { */

											$service_description = 'vNIC Status - ' . $service_description;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $service_description,
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_adapter',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Host_vNIC_Status': */
										} /* End switch ($check_key) { */
									} /* End if (isset($host_check_options[$check_key]['monitor_me'][$h])) { */
								} /* End foreach ($host_checks as $check_key => $check_value) { */
							} /* End if (isset($host_checkbox[$h])) { */
						} /* End for ($h = 0; $h < $host_counter; $h++) { */
					break; /* End case 'host': */


				case 'vcenter':
					$vcenter_results_decoded = $_SESSION[$wizard_name]['vcenter_results_decoded'];
					$vcenter_checkbox = $_SESSION[$wizard_name]['vcenter_checkbox'];
					$vcenter_counter = $_SESSION[$wizard_name]['vcenter_counter'];
					$vcenter_check_options = $_SESSION[$wizard_name]['vcenter_check_options'];

					$vcenter_checks = array (
						'Cluster_CPU_Usage'			=> 'Cluster CPU Usage',
						'Cluster_DRS_Status'		=> 'Cluster DRS Status',
						'Cluster_EVC_Status'		=> 'Cluster EVC Status',
						'Cluster_HA_Status'			=> 'Cluster HA Status',
						'Cluster_Memory_Usage'		=> 'Cluster Memory Usage',
						'Cluster_Resource_Info'		=> 'Cluster Resource Info',
						'Cluster_Swapfile_Status'	=> 'Cluster Swapfile Status',
						'Cluster_vMotion_Info'		=> 'Cluster vMotion Info'
						);

					/* Determine if this is a new host or existing host */
					switch ($nagios_object[0]) {
						case 'new':
							/* New host, define variables and host object */
							$host_name = $nagios_object_new_name[0];
							$host_address = $nagios_object_new_address[0];
							$check_interval = $vcenter_check_options['VMware_Host']['check_interval'][0];
							$retry_interval = $vcenter_check_options['VMware_Host']['retry_interval'][0];
							$max_check_attempts = $vcenter_check_options['VMware_Host']['number_retries'][0];

							if (!host_exists($host_name)) {
								$objs[] = array(
									'type'					=> OBJECTTYPE_HOST,
									'host_name'				=> $host_name,
									'address'				=> $host_address,
									'check_interval'		=> $check_interval,
									'retry_interval'		=> $retry_interval,
									'max_check_attempts'	=> $max_check_attempts,
									'vrml_image'			=> 'vmware3.png',
									'statusmap_image'		=> 'vmware3.gd2',
									'icon_image'			=> 'vmware3.png',
									'use' 					=> 'xiwizard_generic_host',
									'_xiwizard'				=> $wizard_name,
									);
								} /* End if (!host_exists($hostname)) { */
							break; /* End case 'new': */
						

						case 'existing':
							/* Existing object, define variables */
							$host_name = $nagios_object_existing[0];
							break; /* End case 'existing': */
						} /* End switch ($nagios_object[0]) { */

					
					/* Find what vcenter objects were selected */
					/* Starting at 1 because the vCenter server itself is the host object */
					for ($v = 1; $v < $vcenter_counter; $v++) {
						/* Check to see if this object was originally selected */
						if (isset($vcenter_checkbox[$v])) {
							/* Loop through each check for this object */
							foreach ($vcenter_checks as $check_key => $check_value) {
								/* Test to see if the check was selected */
								if (isset($vcenter_check_options[$check_key]['monitor_me'][$v])) {
									/* Check selected */

									/* Now create the relevant services */
									switch ($check_key) {
										case 'Cluster_CPU_Usage':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											/* Build the check command */
											$check_command = 'vmware_cluster_cpu_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$vcenter_checkbox[$v].'!CPU_Speed:'.$vcenter_check_options[$check_key]['reporting_si']['CPU_Speed'][$v];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $v, 'cpu_free', $vcenter_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $v, 'cpu_used', $vcenter_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster CPU Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cpu',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_CPU_Usage': */


										case 'Cluster_DRS_Status':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											$drs_state = $vcenter_check_options[$check_key]['drs_state'][$v];
											$drs_automation_level = $vcenter_check_options[$check_key]['drs_automation_level'][$v];
											$drs_dpm_level = $vcenter_check_options[$check_key]['drs_dpm_level'][$v];

											/* Build the check command */
											$check_command = 'vmware_cluster_drs!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$vcenter_checkbox[$v].'!'.$drs_state.'!'.$drs_automation_level.'!'.$drs_dpm_level;
											
											/* Determine if we need exclude issues */
											if (isset($vcenter_check_options[$check_key]['exclude_issue_checkbox'][$v])) {
												$exclude_options = '';
												foreach ($exclude_issues as $issue) {
													if (isset($vcenter_check_options[$check_key]['exclude_issue'][$issue][$v])) {
														if ($exclude_options != '') {
															$exclude_options .= ',';
															} /* End if ($exclude_options != '') { */
														$exclude_options .= $issue;
														} /* End if (isset($vcenter_check_options[$check_key]['[exclude_issue'][$issue][$v])) { */
													} /* End foreach ($exclude_issues as $issue) { */
												$check_command .= '!--exclude_issue!'.$exclude_options;
												} /* End if (isset($vcenter_check_options[$check_key]['exclude_issue_checkbox'][$v])) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster DRS Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cluster_drs',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_DRS_Status': */


										case 'Cluster_EVC_Status':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											/* Build the check command */
											$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!--cluster!'.$vcenter_checkbox[$v];

											/* Test if the EVC Mode needs to be checked */
											if ($vcenter_check_options[$check_key]['evc_mode'][$v] != 'default') {
												$check_command .= '!--evc_mode!'.$vcenter_check_options[$check_key]['evc_mode'][$v];
												}
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster EVC Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cluster_vmotion',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_EVC_Status': */


										case 'Cluster_HA_Status':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											$ha_state = $vcenter_check_options[$check_key]['ha_state'][$v];
											$ha_host_monitoring = $vcenter_check_options[$check_key]['ha_host_monitoring'][$v];
											$ha_admission_control = $vcenter_check_options[$check_key]['ha_admission_control'][$v];

											/* Build the check command */
											$check_command = 'vmware_cluster_ha!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$vcenter_checkbox[$v].'!'.$ha_state.'!'.$ha_host_monitoring.'!'.$ha_admission_control;
											
											/* Determine if we need exclude issues */
											if (isset($vcenter_check_options[$check_key]['exclude_issue_checkbox'][$v])) {
												$exclude_options = '';
												foreach ($exclude_issues as $issue) {
													if (isset($vcenter_check_options[$check_key]['exclude_issue'][$issue][$v])) {
														if ($exclude_options != '') {
															$exclude_options .= ',';
															} /* End if ($exclude_options != '') { */
														$exclude_options .= $issue;
														} /* End if (isset($vcenter_check_options[$check_key]['[exclude_issue'][$issue][$v])) { */
													} /* End foreach ($exclude_issues as $issue) { */
												$check_command .= '!--exclude_issue!'.$exclude_options;
												} /* End if (isset($vcenter_check_options[$check_key]['exclude_issue_checkbox'][$v])) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster HA Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cluster_ha',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_HA_Status': */


										case 'Cluster_Memory_Usage':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											/* Build the check command */
											$check_command = 'vmware_cluster_memory_usage!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$vcenter_checkbox[$v].'!Memory_Size:'.$vcenter_check_options[$check_key]['reporting_si']['Memory_Size'][$v];
											
											/* Determine if warning and critical have been defined and add to command*/
											$warning = '';
											$critical = '';
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $v, 'memory_free', $vcenter_check_options);
											list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $v, 'memory_used', $vcenter_check_options);
											$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
											switch ($waoc) {
												case 'W':
													$check_command .= '!--warning!'.$warning;
													break; /* End case 'W': */
													
												case 'C':
													$check_command .= '!--critical!'.$critical;
													break; /* End case 'C': */
													
												case 'WAC':
													$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
													break; /* End case 'WAC': */
												} /* End switch ($waoc) { */
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster Memory Usage',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_memory',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_Memory_Usage': */


										case 'Cluster_Resource_Info':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											$reporting_si = 'CPU_Speed:'.$vcenter_check_options[$check_key]['reporting_si']['CPU_Speed'][$v].',Memory_Size:'.$vcenter_check_options[$check_key]['reporting_si']['Memory_Size'][$v];

											/* Build the check command */
											$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!--cluster!'.$vcenter_checkbox[$v].'!--reporting_si!'.$reporting_si;
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster Resource Info',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cluster_resource',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_Resource_Info': */


										case 'Cluster_Swapfile_Status':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											/* Build the check command */
											$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!--cluster!'.$vcenter_checkbox[$v].'!--swapfile_policy!'.$vcenter_check_options[$check_key]['swapfile_policy'][$v];

											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster Swapfile Status',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_guest',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_Swapfile_Status': */


										case 'Cluster_vMotion_Info':
											$check_interval = $vcenter_check_options[$check_key]['check_interval'][$v];
											$retry_interval = $vcenter_check_options[$check_key]['retry_interval'][$v];
											$max_check_attempts = $vcenter_check_options[$check_key]['number_retries'][$v];

											/* Build the check command */
											$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!'.$check_key.'!--cluster!'.$vcenter_checkbox[$v];
											
											$objs[] = array(
												'type' 					=> OBJECTTYPE_SERVICE,
												'host_name' 			=> $host_name,
												'service_description' 	=> $vcenter_checkbox[$v].' - Cluster vMotion Info',
												'check_command'			=> $check_command,
												'check_interval'		=> $check_interval,
												'retry_interval'		=> $retry_interval,
												'max_check_attempts'	=> $max_check_attempts,
												'use' 					=> $wizard_name.'_cluster_vmotion',
												'_xiwizard' 			=> $wizard_name,
												);
											break; /* End case 'Cluster_vMotion_Info': */

										
										} /* End switch ($check_key) { */
									} /* End if (isset($vcenter_check_options[$check_key]['monitor_me'][$v])) { */
								} /* End foreach ($vcenter_checks as $check_key => $check_value) { */
							} /* End if (isset($vcenter_checkbox[$v])) { */
						} /* End for ($v = 1; $v < $vcenter_counter; $v++) { */


					/* Guest_Snapshot */
					if (isset($vcenter_check_options['Guest_Snapshot']['monitor_me'][0])) {
						$check_interval = $vcenter_check_options['Guest_Snapshot']['check_interval'][0];
						$retry_interval = $vcenter_check_options['Guest_Snapshot']['retry_interval'][0];
						$max_check_attempts = $vcenter_check_options['Guest_Snapshot']['number_retries'][0];

						/* Build the check command */
						$check_command = 'vmware_guest_snapshot!'.$vma_host_select.'!'.$vma_host_object_select;

						/* Determine if this is a Datacenter or Cluster */
						$snapshot_split = preg_split('/:/', $vcenter_check_options['Guest_Snapshot']['target'][0]);
						switch ($snapshot_split[0]) {
							case 'datacenter':
								$check_command .= '!--datacenter!'.$snapshot_split[1];
								$service_description = 'Guest Snapshots - Datacenter - '.$snapshot_split[1];
								break; /* End case 'datacenter': */

							case 'cluster':
								$check_command .= '!--cluster!'.$snapshot_split[1];
								$service_description = 'Guest Snapshots - Cluster - '.$snapshot_split[1];
								break; /* End case 'datacenter': */
							} /* End switch ($snapshot_split[0]) { */
						
						/* Determine if warning and critical have been defined and add to command*/
						$warning = '';
						$critical = '';
						list ($warning, $critical) = vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, 'Guest_Snapshot', 0, 'snapshot_age', $vcenter_check_options);
						$waoc = vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical);
						switch ($waoc) {
							case 'W':
								$check_command .= '!--warning!'.$warning;
								break; /* End case 'W': */
								
							case 'C':
								$check_command .= '!--critical!'.$critical;
								break; /* End case 'C': */
								
							case 'WAC':
								$check_command .= '!--warning!'.$warning.'!--critical!'.$critical;
								break; /* End case 'WAC': */
							} /* End switch ($waoc) { */
						
						$objs[] = array(
							'type' 					=> OBJECTTYPE_SERVICE,
							'host_name' 			=> $host_name,
							'service_description' 	=> $service_description,
							'check_command'			=> $check_command,
							'check_interval'		=> $check_interval,
							'retry_interval'		=> $retry_interval,
							'max_check_attempts'	=> $max_check_attempts,
							'use' 					=> $wizard_name.'_snapshot',
							'_xiwizard' 			=> $wizard_name,
							);
						} /* End if (isset($vcenter_check_options['Guest_Snapshot']['monitor_me'][0])) { */


					/* vCenter_License_Status */
					if (isset($vcenter_check_options['vCenter_License_Status']['monitor_me'][0])) {
						$check_interval = $vcenter_check_options['vCenter_License_Status']['check_interval'][0];
						$retry_interval = $vcenter_check_options['vCenter_License_Status']['retry_interval'][0];
						$max_check_attempts = $vcenter_check_options['vCenter_License_Status']['number_retries'][0];

						/* Build the check command */
						$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!vCenter_License_Status';

						/* Check for the hide_key argument */
						if (isset($vcenter_check_options['vCenter_License_Status']['hide_key'][0])) {
							$check_command .= '!--hide_key';
							} /* End if (isset($vcenter_check_options['vCenter_License_Status']['hide_key'][0])) { */
						
						$objs[] = array(
							'type' 					=> OBJECTTYPE_SERVICE,
							'host_name' 			=> $host_name,
							'service_description' 	=> 'License Status',
							'check_command'			=> $check_command,
							'check_interval'		=> $check_interval,
							'retry_interval'		=> $retry_interval,
							'max_check_attempts'	=> $max_check_attempts,
							'use' 					=> $wizard_name.'_license',
							'_xiwizard' 			=> $wizard_name,
							);
						} /* End if (isset($vcenter_check_options['vCenter_License_Status']['monitor_me'][0])) { */


					/* vCenter_Name_Version */
					if (isset($vcenter_check_options['vCenter_Name_Version']['monitor_me'][0])) {
						$check_interval = $vcenter_check_options['vCenter_Name_Version']['check_interval'][0];
						$retry_interval = $vcenter_check_options['vCenter_Name_Version']['retry_interval'][0];
						$max_check_attempts = $vcenter_check_options['vCenter_Name_Version']['number_retries'][0];

						/* Build the check command */
						$check_command = 'vmware_universal!'.$vma_host_select.'!'.$vma_host_object_select.'!vCenter_Name_Version';

						$objs[] = array(
							'type' 					=> OBJECTTYPE_SERVICE,
							'host_name' 			=> $host_name,
							'service_description' 	=> 'vCenter Server Version',
							'check_command'			=> $check_command,
							'check_interval'		=> $check_interval,
							'retry_interval'		=> $retry_interval,
							'max_check_attempts'	=> $max_check_attempts,
							'use' 					=> $wizard_name.'_version',
							'_xiwizard' 			=> $wizard_name,
							);
						} /* End if (isset($vcenter_check_options['vCenter_Name_Version']['monitor_me'][0])) { */
					break; /* End case 'vcenter': */
				} /* End switch ($vmware_check_type) { */

			
			/* The following three lines can be enabled for debugging purposes */
			//print_r('<br />Objects Array:<br />');
			//print_r($objs);
			//print_r('<br />');
			
			/* Return the object definitions to the wizard */
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS] = $objs;
			
			/* clear the session variables for this wizard run */
			unset ($_SESSION[$wizard_name]); 
			
			/* The next line ends CONFIGWIZARD_MODE_GETOBJECTS */
			break;
			
		default:
			break;			
		} /* End switch ($mode) { */
		
	return $output;
	} /* End function vmwarevirtualizationwizard_configwizard_func($mode = '',$inargs = null,&$outargs,&$result) { */


function vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $object_number, $threshold_key, $check_options) {
	switch ($check_key) {
		case 'Guest_CPU_Info':
		case 'Guest_Memory_Info':
			if (isset($check_options[$check_key][$threshold_key]['checkbox'][$object_number])) {
				switch ($check_options[$check_key][$threshold_key]['warning_or_critical'][$object_number]) {
					case 'warning':
						$warning_checkbox = 'warning';
						$warning_value = $check_options[$check_key][$threshold_key]['warning'][$object_number];
						break; /* End case 'warning': */

					case 'critical':
						$critical_checkbox = 'critical';
						$critical_value = $check_options[$check_key][$threshold_key]['critical'][$object_number];
						break; /* End case 'critical': */
					} /* End switch ($check_options[$check_key][$threshold_key]['warning_or_critical'][$object_number]) { */
				} /* End if (isset($check_options[$check_key][$threshold_key]['checkbox'][$object_number])) { */
			break; /* End case 'Guest_CPU_Info': case 'Guest_Memory_Info': */


		case 'Host_Datastore_Performance':
			$datastore = $object_number[1];
			if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['warning_checkbox'][$datastore])) {$warning_checkbox = $check_options[$check_key][$object_number[0]][$threshold_key]['warning_checkbox'][$datastore];}
			if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['warning'][$datastore])) {$warning_value = $check_options[$check_key][$object_number[0]][$threshold_key]['warning'][$datastore];}
			if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['critical_checkbox'][$datastore])) {$critical_checkbox = $check_options[$check_key][$object_number[0]][$threshold_key]['critical_checkbox'][$datastore];}
			if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['critical'][$datastore])) {$critical_value = $check_options[$check_key][$object_number[0]][$threshold_key]['critical'][$datastore];}
			break; /* End case 'Host_Datastore_Performance': */


		default:
			if (isset($check_options[$check_key][$threshold_key]['warning_checkbox'][$object_number])) {$warning_checkbox = $check_options[$check_key][$threshold_key]['warning_checkbox'][$object_number];}
			if (isset($check_options[$check_key][$threshold_key]['warning'][$object_number])) {$warning_value = $check_options[$check_key][$threshold_key]['warning'][$object_number];}
			if (isset($check_options[$check_key][$threshold_key]['critical_checkbox'][$object_number])) {$critical_checkbox = $check_options[$check_key][$threshold_key]['critical_checkbox'][$object_number];}
			if (isset($check_options[$check_key][$threshold_key]['critical'][$object_number])) {$critical_value = $check_options[$check_key][$threshold_key]['critical'][$object_number];}
			break; /* End default: */
		} /* End switch ($check_key) { */


	if (isset($warning_checkbox)) {
		if ($warning != '') {
			$warning .= ',';
			} /* End if ($warning != '') { */
		$warning .= $threshold_key.':'.$warning_value;
		} /* End if (isset($warning_checkbox)) { */
	
	if (isset($critical_checkbox)) {
		if ($critical != '') {
			$critical .= ',';
			} /* End if ($critical != '') { */
		$critical .= $threshold_key.':'.$critical_value;
		} /* End if (isset($critical_checkbox)) { */
	
	return array ($warning, $critical);
	} /* End function vmwarevirtualizationwizard_build_warning_or_critical($warning, $critical, $check_key, $object_number, $threshold_key, $check_options) { */


function vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical) {
	if ($warning != '') {
		if ($critical != '') {
			$result = 'WAC';
			} /* End if ($critical != '') { */
		else {
			$result = 'W';
			} /* End else { */
		} /* End if ($warning != '') { */
	else {
		if ($critical != '') {
			$result = 'C';
			} /* End if ($critical != '') { */
		else {
			$result = 'NONE';
			} /* End else { */
		} /* End else { */
	return $result;
	} /* End function vmwarevirtualizationwizard_determine_warning_or_critical($warning, $critical) { */


function vmwarevirtualizationwizard_option_check($type, $items, $object_number, $check_options, $default_value) {
	$value = '';
	if ($check_options != '') {

		/* First define the item */
		$item = '';
		switch (count($items)) {
			case '2':
				if(isset($check_options[$items[0]][$items[1]][$object_number])) {
					$item = $check_options[$items[0]][$items[1]][$object_number];
					} /* End if(isset($check_options[$items[0]][$items[1]][$object_number])) { */
				break; /* End case '2': */


			case '3':
				switch ($items[0]) {
					case 'Host_Datastore_Performance':
						if(isset($check_options[$items[0]][$object_number][$items[1]][$items[2]])) {
							$item = $check_options[$items[0]][$object_number][$items[1]][$items[2]];
							} /* End if(isset($check_options[$items[0]][$object_number][$items[1]][$items[2]])) { */
						break; /* End case 'Host_Datastore_Performance': */


					default:
						switch ($items[1]) {
							case 'hba_checkbox':
							case 'pnic_checkbox':
							case 'switch_checkbox':
							case 'vnic_checkbox':
								if(isset($check_options[$items[0]][$items[1]][$object_number][$items[2]])) {
									$item = $check_options[$items[0]][$items[1]][$object_number][$items[2]];
									} /* End if(isset($check_options[$items[0]][$items[1]][$object_number][$items[2]])) { */
								break; /* End case 'hba_checkbox': case 'pnic_checkbox': case 'switch_checkbox': case 'vnic_checkbox': */


							default:
								if(isset($check_options[$items[0]][$items[1]][$items[2]][$object_number])) {
									$item = $check_options[$items[0]][$items[1]][$items[2]][$object_number];
									} /* End if(isset($check_options[$items[0]][$items[1]][$items[2]][$object_number])) { */
								break; /* End default: */
							} /* End switch ([$items[1]]) { */
						break; /* End default: */
					} /* End switch ($items[0]) { */
				break; /* End case '3': */


			case '4':
				if(isset($check_options[$items[0]][$object_number][$items[1]][$items[2]][$items[3]])) {
					$item = $check_options[$items[0]][$object_number][$items[1]][$items[2]][$items[3]];
					} /* End if(isset($check_options[$items[0]][$object_number][$items[1]][$items[2]][$items[3]])) { */
				break; /* End case '4': */
			} /* End switch (count($items)) { */

		//print_r($item . '<br/>');

		/* Now get the value */
		switch ($type) {
			case 'checkbox':
				if ($item != '') {
					$value = ' checked';
					} /* End if ($item != '') { */
				break; /* End case 'checkbox': */


			case 'select':
				if ($item != '') {
					$value = $item;
					} /* End if ($item != '') { */
				break; /* End case 'select': */

			
			case 'text':
				if ($item != '') {
					$value = $item;
					} /* End if ($item != '') { */
				break; /* End case 'text': */

			
			} /* End switch ($type) { */
		} /* End if ($check_options != '') { */

	if ($value == '') {
		$value = $default_value;
		} /* End if ($value == '') { */

	return $value;
	} /* End function vmwarevirtualizationwizard_option_check($type, $item, $object_number, $check_options) { */


function vmwarevirtualizationwizard_interval_check($errmsg, $errors, $check, $object_name, $check_interval, $retry_interval, $number_retries) {
	//print_r('check_interval ' . $check_interval . '<br/>');
	//print_r('retry_interval ' . $retry_interval . '<br/>');
	//print_r('number_retries ' . $number_retries . '<br/>');

	if (!is_numeric($check_interval)) {
		$errmsg[$errors++] = "The '$check' CHECK INTERVAL '$check_interval' for '$object_name' is NOT valid !";
		} /* End if (!is_numeric($check_interval)) { */
	
	if (!is_numeric($retry_interval)) {
		$errmsg[$errors++] = "The '$check' RETRY INTERVAL '$retry_interval' for '$object_name' is NOT valid !";
		} /* End if (!is_numeric($retry_interval)) { */
	
	if (!is_numeric($number_retries)) {
		$errmsg[$errors++] = "The '$check' NUMBER RETRIES '$number_retries' for '$object_name' is NOT valid !";
		} /* End if (!is_numeric($number_retries)) { */
	
	return array ($errmsg, $errors);
	} /* End function vmwarevirtualizationwizard_interval_check($check_interval, $retry_interval, $number_retries) { */


function vmwarevirtualizationwizard_threshold_check($errmsg, $errors, $check_key, $check_value, $object_number, $object_name, $threshold_type, $threshold_name, $threshold_key, $check_options) {
	switch ($threshold_type) {
		case 'EXCLUDE':
			/* Check if the exclude checkbox was selected */
			if (isset($check_options[$check_key][$threshold_key.'_checkbox'][$object_number])) {
				/* Check to ensure some options were selected */
				$exclude_flag = 0;
				$exclude_issues = Array('ClusterOvercommittedEvent', 'DasClusterIsolatedEvent', 'DasHostFailedEvent', 'DasHostIsolatedEvent', 'HeartbeatDatastoreNotSufficient', 'HostNoRedundantManagementNetworkEvent', 'InsufficientFailoverResourcesEvent', 'LocalTSMEnabledEvent', 'RemoteTSMEnabledEvent');
				foreach ($exclude_issues as $issue) {
					if (isset($check_options[$check_key][$threshold_key][$issue][$object_number])) {
						$exclude_flag = 1;
						} /* End if (isset($check_options[$check_key][$threshold_key][$issue][$object_number])) { */
					} /* End foreach ($exclude_issues as $issue) { */
				if ($exclude_flag == 0) {
					$errmsg[$errors++] = "You did NOT select any ISSUES to EXCLUDE for '$check_value' -> '$threshold_name' for '$object_name' !";
					} /* End if ($exclude_flag == 0) { */
				} /* End if (isset($check_options[$check_key][$threshold_key.'_checkbox'][$object_number])) { */
			break; /* End case 'EXCLUDE': */


		case 'CHOOSE':
			/* Check if at least one item was selected */
			if (!isset($check_options[$check_key][$threshold_key][$object_number])) {
				$errmsg[$errors++] = "You did NOT select any '$threshold_name' to monitor for '$object_name' !";
				} /* End if (!isset($check_options[$check_key][$threshold_key][$object_number])) { */
			break; /* End case 'CHOOSE': */


		case 'WC':
		case 'CW':
			if ($check_key == 'Host_Datastore_Performance') {
				$datastore = $object_number[1];
				if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['warning_checkbox'][$datastore])) {$warning_checkbox = $check_options[$check_key][$object_number[0]][$threshold_key]['warning_checkbox'][$datastore];}
				if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['warning'][$datastore])) {$warning_value = $check_options[$check_key][$object_number[0]][$threshold_key]['warning'][$datastore];}
				if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['critical_checkbox'][$datastore])) {$critical_checkbox = $check_options[$check_key][$object_number[0]][$threshold_key]['critical_checkbox'][$datastore];}
				if (isset($check_options[$check_key][$object_number[0]][$threshold_key]['critical'][$datastore])) {$critical_value = $check_options[$check_key][$object_number[0]][$threshold_key]['critical'][$datastore];}
				} /* End if ($check_key == 'Host_Datastore_Performance') { */
			else {
				if (isset($check_options[$check_key][$threshold_key]['warning_checkbox'][$object_number])) {$warning_checkbox = $check_options[$check_key][$threshold_key]['warning_checkbox'][$object_number];}
				if (isset($check_options[$check_key][$threshold_key]['warning'][$object_number])) {$warning_value = $check_options[$check_key][$threshold_key]['warning'][$object_number];}
				if (isset($check_options[$check_key][$threshold_key]['critical_checkbox'][$object_number])) {$critical_checkbox = $check_options[$check_key][$threshold_key]['critical_checkbox'][$object_number];}
				if (isset($check_options[$check_key][$threshold_key]['critical'][$object_number])) {$critical_value = $check_options[$check_key][$threshold_key]['critical'][$object_number];}
				} /* End else { */
			/* Check if the warning checkbox was selected */
			if (isset($warning_checkbox)) {
					//print_r($warning_checkbox . "<br/>");
				/* Test the warning value */
				if (!is_numeric($warning_value)) {
					$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' WARNING VALUE '$warning_value' for '$object_name' is NOT valid !";
					} /* End if (!is_numeric($warning_value)) { */
				else {
					/* Check if the critical checkbox was selected */
					if (isset($critical_checkbox)) {
							//print_r($critical_checkbox . "<br/>");
						/* Test the critical value */
						if (!is_numeric($critical_value)) {
							$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' CRITICAL VALUE '$critical_value' for '$object_name' is NOT valid !";
							} /* End if (!is_numeric($critical_value)) { */
						else {
							switch ($threshold_type) {
								case 'WC':
									/* Warning value must be LESS that Critical value */
									if ($critical_value < $warning_value) {
										$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' WARNING VALUE '$warning_value' MUST be LESS than the CRITICAL VALUE '$critical_value' for '$object_name' !";
										} /* End if ($critical_value < $warning_value) { */
									elseif ($critical_value == $warning_value) {
										$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' WARNING VALUE '$warning_value' MUST be LESS than the CRITICAL VALUE '$critical_value' for '$object_name' !";
										} /* End elseif ($critical_value == $warning_value) { */
									break; /* End case 'WC': */
									
								case 'CW':
									/* Warning value must be MORE that Critical value */
									if ($critical_value > $warning_value) {
										$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' WARNING VALUE '$warning_value' MUST be MORE than the CRITICAL VALUE '$critical_value' for '$object_name' !";
										} /* End if ($critical_value > $warning_value) { */
									elseif ($critical_value == $warning_value) {
										$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' WARNING VALUE '$warning_value' MUST be MORE than the CRITICAL VALUE '$critical_value' for '$object_name' !";
										} /* End elseif ($critical_value == $warning_value) { */
									break; /* End case 'CW': */
								} /* End switch ($threshold_type) { */
							} /* End else { */
						} /* End if (isset($critical_checkbox)) { */
					} /* End else { */
				} /* End if (isset($warning_checkbox)) { */
			
			/* Check if the critical checkbox was selected */
			if (isset($critical_checkbox)) {
					//print_r($critical_value . "<br/>");
				/* Test the critical value */
				if (!is_numeric($critical_value)) {
					$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' CRITICAL VALUE '$critical_value' for '$object_name' is NOT valid !";
					} /* End if (!is_numeric($critical_value)) { */
				} /* End if (isset($critical_checkbox)) { */
			break; /* End case 'WC': case 'CW': */


		case 'WOC':
			/* Check if the Warning Or Critical checkbox was ticked */
			if (isset($check_options[$check_key][$threshold_key]['checkbox'][$object_number])) {
				$woc_select = $check_options[$check_key][$threshold_key]['warning_or_critical'][$object_number];
				/* Test the Warning Or Critical value */
				if (!is_numeric($check_options[$check_key][$threshold_key][$woc_select][$object_number])) {
					$errmsg[$errors++] = "The '$check_value' -> '$threshold_name' " . strtoupper($woc_select) . " VALUE '" . $check_options[$check_key][$threshold_key][$woc_select][$object_number] . "' for '$object_name' is NOT valid !";
					} /* End if (!is_numeric($check_options[$check_key][$threshold_key][$woc_select][$object_number])) { */
				} /* End if (isset($check_options[$check_key][$threshold_key]['checkbox'][$object_number])) { */
			break; /* End case 'WOC': */
		} /* End switch ($threshold_type) { */

	return array ($errmsg, $errors);
	} /* End function vmwarevirtualizationwizard_threshold_check() { */

?>
